<?php

$LANG = array(
    'organization' => 'Organisatie',
    'name' => 'Naam',
    'website' => 'Website',
    'work_phone' => 'Telefoon',
    'address' => 'Adres',
    'address1' => 'Straat',
    'address2' => 'Apt/Suite',
    'city' => 'Plaats',
    'state' => 'Provincie',
    'postal_code' => 'Postcode',
    'country_id' => 'Land',
    'contacts' => 'Contactpersonen',
    'first_name' => 'Voornaam',
    'last_name' => 'Achternaam',
    'phone' => 'Telefoon',
    'email' => 'E-mail',
    'additional_info' => 'Extra informatie',
    'payment_terms' => 'Betalingsvoorwaarden',
    'currency_id' => 'Valuta',
    'size_id' => 'Bedrijfs grootte',
    'industry_id' => 'Industrie',
    'private_notes' => 'Prive notities',
    'invoice' => 'Factuur',
    'client' => 'Klant',
    'invoice_date' => 'Factuurdatum',
    'due_date' => 'Vervaldatum',
    'invoice_number' => 'Factuurnummer',
    'invoice_number_short' => 'Factuur #',
    'po_number' => 'Bestelnummer',
    'po_number_short' => 'Bestel #',
    'frequency_id' => 'Frequentie',
    'discount' => 'Korting',
    'taxes' => 'Belastingen',
    'tax' => 'Belasting',
    'item' => 'Artikel',
    'description' => 'Omschrijving',
    'unit_cost' => 'Eenheidsprijs',
    'quantity' => 'Aantal',
    'line_total' => 'Totaal',
    'subtotal' => 'Subtotaal',
    'paid_to_date' => 'Reeds betaald',
    'balance_due' => 'Te voldoen',
    'invoice_design_id' => 'Ontwerp',
    'terms' => 'Voorwaarden',
    'your_invoice' => 'Jouw factuur',
    'remove_contact' => 'Verwijder contact',
    'add_contact' => 'Contact toevoegen',
    'create_new_client' => 'Nieuwe klant aanmaken',
    'edit_client_details' => 'Wijzig klantgegevens',
    'enable' => 'Activeer',
    'learn_more' => 'Kom meer te weten',
    'manage_rates' => 'Beheer prijzen',
    'note_to_client' => 'Bericht aan klant',
    'invoice_terms' => 'Factuur voorwaarden',
    'save_as_default_terms' => 'Bewaar als standaard voorwaarden',
    'download_pdf' => 'Download PDF',
    'pay_now' => 'Betaal nu',
    'save_invoice' => 'Bewaar factuur',
    'clone_invoice' => 'Dupliceer factuur',
    'archive_invoice' => 'Archiveer factuur',
    'delete_invoice' => 'Verwijder factuur',
    'email_invoice' => 'E-mail factuur',
    'enter_payment' => 'Voer betaling in',
    'tax_rates' => 'BTW-tarieven',
    'rate' => 'Tarief',
    'settings' => 'Instellingen',
    'enable_invoice_tax' => 'Het opgeven van <b>BTW op de volledige factuur</b> aanzetten',
    'enable_line_item_tax' => 'Het opgeven van <b>de BTW per regel</b> aanzetten',
    'dashboard' => 'Dashboard',
    'dashboard_totals_in_all_currencies_help' => 'Notitie: voeg een :link genaamd ":name" toe om het totaal in een enkele valuta weer te geven.',
    'clients' => 'Klanten',
    'invoices' => 'Facturen',
    'payments' => 'Betalingen',
    'credits' => 'Kredietnota\'s',
    'history' => 'Geschiedenis',
    'search' => 'Zoeken',
    'sign_up' => 'Aanmelden',
    'guest' => 'Gast',
    'company_details' => 'Bedrijfsdetails',
    'online_payments' => 'Online betalingen',
    'notifications' => 'Notificaties',
    'import_export' => 'Importeer/Exporteer',
    'done' => 'Klaar',
    'save' => 'Opslaan',
    'create' => 'Aanmaken',
    'upload' => 'Uploaden',
    'import' => 'Importeer',
    'download' => 'Download',
    'cancel' => 'Annuleren',
    'close' => 'Sluiten',
    'provide_email' => 'Geef een geldig emailadres aub.',
    'powered_by' => 'Factuur gemaakt via',
    'no_items' => 'Geen artikelen',
    'recurring_invoices' => 'Terugkerende facturen',
    'recurring_help' => '<p>Stuur klanten automatisch wekelijks, twee keer per maand, maandelijks, per kwartaal of jaarlijks dezelfde facturen.</p>
        <p>Gebruik :MONTH, :QUARTER of :YEAR voor dynamische datums. Eenvoudige wiskunde werkt ook, bijvoorbeeld :MONTH-1.</p>
        <p>Voorbeelden van dynamische factuur variabelen:</p>
        <ul>
          <li>"Fitnesslidmaatschap voor de maand :MONTH" >> "Fitnesslidmaatschap voor de maand juli"</li>
          <li>"Jaarlijks abonnement :YEAR+1" >> "Jaarlijks abonnement 2015"</li>
          <li>"Betaling voor :QUARTER+1" >> "Betaling voor Q2"</li>
        </ul>',
    'recurring_quotes' => 'Terugkerende offertes',
    'in_total_revenue' => 'totale inkomsten',
    'billed_client' => 'Gefactureerde klant',
    'billed_clients' => 'Gefactureerde klanten',
    'active_client' => 'Actieve klant',
    'active_clients' => 'Actieve klanten',
    'invoices_past_due' => 'Vervallen facturen',
    'upcoming_invoices' => 'Aankomende facturen',
    'average_invoice' => 'Gemiddelde factuur',
    'archive' => 'Archiveer',
    'delete' => 'Verwijder',
    'archive_client' => 'Archiveer klant',
    'delete_client' => 'Verwijder klant',
    'archive_payment' => 'Archiveer betaling',
    'delete_payment' => 'Verwijder betaling',
    'archive_credit' => 'Archiveer kredietnota',
    'delete_credit' => 'Verwijder kredietnota',
    'show_archived_deleted' => 'Toon gearchiveerde/verwijderde',
    'filter' => 'Filter',
    'new_client' => 'Nieuwe klant',
    'new_invoice' => 'Nieuwe factuur',
    'new_payment' => 'Nieuwe betaling',
    'new_credit' => 'Nieuwe kredietnota',
    'contact' => 'Contact',
    'date_created' => 'Aanmaakdatum',
    'last_login' => 'Laatste login',
    'balance' => 'Saldo',
    'action' => 'Actie',
    'status' => 'Status',
    'invoice_total' => 'Factuur totaal',
    'frequency' => 'Frequentie',
    'range' => 'Bereik',
    'start_date' => 'Startdatum',
    'end_date' => 'Einddatum',
    'transaction_reference' => 'Transactie referentie',
    'method' => 'Methode',
    'payment_amount' => 'Betalingsbedrag',
    'payment_date' => 'Betalingsdatum',
    'credit_amount' => 'Kredietbedrag',
    'credit_balance' => 'Kredietsaldo',
    'credit_date' => 'Kredietdatum',
    'empty_table' => 'Geen gegevens beschikbaar in de tabel',
    'select' => 'Selecteer',
    'edit_client' => 'Wijzig klant',
    'edit_invoice' => 'Wijzig factuur',
    'create_invoice' => 'Factuur aanmaken',
    'enter_credit' => 'Voer kredietnota in',
    'last_logged_in' => 'Laatste login',
    'details' => 'Details',
    'standing' => 'Openstaand',
    'credit' => 'Krediet',
    'activity' => 'Activiteit',
    'date' => 'Datum',
    'message' => 'Bericht',
    'adjustment' => 'Aanpassing',
    'are_you_sure' => 'Weet je het zeker?',
    'payment_type_id' => 'Betalingstype',
    'amount' => 'Bedrag',
    'work_email' => 'E-mailadres',
    'language_id' => 'Taal',
    'timezone_id' => 'Tijdzone',
    'date_format_id' => 'Datum opmaak',
    'datetime_format_id' => 'Datum/Tijd opmaak',
    'users' => 'Gebruikers',
    'localization' => 'Lokalisatie',
    'remove_logo' => 'Logo verwijderen',
    'logo_help' => 'Ondersteund: JPEG, GIF en PNG',
    'payment_gateway' => 'Betalingsprovider',
    'gateway_id' => 'provider',
    'email_notifications' => 'E-mailmeldingen',
    'email_sent' => 'E-mail mij wanneer een factuur is <b>verzonden</b>',
    'email_viewed' => 'E-mail mij wanneer een factuur is <b>bekeken</b>',
    'email_paid' => 'E-mail mij wanneer een factuur is <b>betaald</b>',
    'site_updates' => 'Site Aanpassingen',
    'custom_messages' => 'Aangepaste berichten',
    'default_email_footer' => 'Stel standaard e-mailhandtekening in',
    'select_file' => 'Selecteer een bestand',
    'first_row_headers' => 'Gebruik de eerste rij voor titelkoppen',
    'column' => 'Kolom',
    'sample' => 'Voorbeeld',
    'import_to' => 'Importeer naar',
    'client_will_create' => 'klant zal worden aangemaakt ',
    'clients_will_create' => 'klanten zullen worden aangemaakt ',
    'email_settings' => 'E-mailinstellingen',
    'client_view_styling' => 'Opmaak klantenportaal',
    'pdf_email_attachment' => 'Voeg een PDF toe',
    'custom_css' => 'Aangepaste CSS',
    'import_clients' => 'Importeer Klant Gegevens',
    'csv_file' => 'Selecteer CSV bestand',
    'export_clients' => 'Exporteer Klant Gegevens',
    'created_client' => 'De klant is aangemaakt',
    'created_clients' => 'succesvol :count klant(en) aangemaakt',
    'updated_settings' => 'De instellingen zijn gewijzigd',
    'removed_logo' => 'Het logo is verwijderd',
    'sent_message' => 'Het bericht is verzonden',
    'invoice_error' => 'Selecteer een klant alsjeblieft en verbeter eventuele fouten',
    'limit_clients' => 'Sorry, dit zal de limiet van :count klanten overschrijden',
    'payment_error' => 'Er was een fout bij het verwerken van de betaling. Probeer het later alsjeblieft opnieuw.',
    'registration_required' => 'Meld u aan om een factuur te mailen',
    'confirmation_required' => 'Bevestig het e-mailadres, :link om de bevestigingsmail opnieuw te ontvangen.',
    'updated_client' => 'De klant is bijgewerkt',
    'archived_client' => 'De klant is gearchiveerd',
    'archived_clients' => 'Succesvol  :count klanten gearchiveerd',
    'deleted_client' => 'De klant is verwijderd',
    'deleted_clients' => 'Succesvol :count klanten verwijderd',
    'updated_invoice' => 'De factuur is gewijzigd',
    'created_invoice' => 'De factuur is aangemaakt',
    'cloned_invoice' => 'De factuur is gedupliceerd',
    'emailed_invoice' => 'De factuur is gemaild',
    'and_created_client' => 'en klant aangemaakt',
    'archived_invoice' => 'De factuur is gearchiveerd',
    'archived_invoices' => 'Succesvol :count facturen gearchiveerd',
    'deleted_invoice' => 'De factuur is verwijderd',
    'deleted_invoices' => 'De :count facturen zijn verwijderd',
    'created_payment' => 'De betaling is aangemaakt',
    'created_payments' => 'Succesvol :count betaling(en) aangemaakt',
    'archived_payment' => 'De betaling is gearchiveerd',
    'archived_payments' => 'Succesvol :count betalingen gearchiveerd',
    'deleted_payment' => 'De betaling is verwijderd',
    'deleted_payments' => 'Succesvol :count betalingen verwijderd',
    'applied_payment' => 'De betaling is toegepast',
    'created_credit' => 'De kredietnota is aangemaakt',
    'archived_credit' => 'De kredietnota is gearchiveerd',
    'archived_credits' => 'Succesvol :count kredietnota\'s gearchiveerd',
    'deleted_credit' => 'De kredietnota is verwijderd',
    'deleted_credits' => 'Succesvol :count kredietnota\'s verwijderd',
    'imported_file' => 'Het bestand is geïmporteerd',
    'updated_vendor' => 'De leverancier is gewijzigd',
    'created_vendor' => 'De leverancier is aangemaakt',
    'archived_vendor' => 'De leverancier is gearchiveerd',
    'archived_vendors' => 'Succesvol :count leveranciers gearchiveerd',
    'deleted_vendor' => 'De leverancier is verwijderd',
    'deleted_vendors' => 'Succesvol :count leveranciers verwijderd',
    'confirmation_subject' => 'InvoiceNinja Accountbevestiging',
    'confirmation_header' => 'Bevestiging Account',
    'confirmation_message' => 'Klik op onderstaande link om uw account te bevestigen.',
    'invoice_subject' => 'Nieuwe Factuur :number van :account',
    'invoice_message' => 'Klik op onderstaande link om uw factuur van :amount in te zien.',
    'payment_subject' => 'Betaling ontvangen',
    'payment_message' => 'Bedankt voor uw betaling van :amount.',
    'email_salutation' => 'Beste :name,',
    'email_signature' => 'Met vriendelijke groeten,',
    'email_from' => 'Het Invoice Ninja Team',
    'invoice_link_message' => 'Klik op volgende link om de factuur van uw klant te bekijken:',
    'notification_invoice_paid_subject' => 'Factuur :invoice is betaald door :client',
    'notification_invoice_sent_subject' => 'Factuur :invoice is verstuurd naar :client',
    'notification_invoice_viewed_subject' => 'Factuur :invoice is bekeken door :client',
    'notification_invoice_paid' => 'Een betaling voor :amount is gemaakt door klant :client voor Factuur :invoice.',
    'notification_invoice_sent' => 'Factuur :invoice ter waarde van :amount is per e-mail naar :client verstuurd.',
    'notification_invoice_viewed' => ':client heeft factuur :invoice ter waarde van :amount bekeken.',
    'reset_password' => 'U kunt het wachtwoord van uw account resetten door op de volgende link te klikken:',
    'secure_payment' => 'Beveiligde betaling',
    'card_number' => 'Kaartnummer',
    'expiration_month' => 'Verval maand',
    'expiration_year' => 'Verval jaar',
    'cvv' => 'CVV',
    'logout' => 'Afmelden',
    'sign_up_to_save' => 'Registreer om het werk op te kunnen slaan',
    'agree_to_terms' => 'Ik ga akkoord met de :terms',
    'terms_of_service' => 'Gebruiksvoorwaarden',
    'email_taken' => 'Dit e-mailadres is al geregistreerd',
    'working' => 'Werkend',
    'success' => 'Succes',
    'success_message' => 'Je bent nu geregistreerd. Klik op de link in de zojuist ontvangen bevestigingsmail om je e-mailadres te verifi&euml;ren.',
    'erase_data' => 'Dit account is niet geregistreerd, de opgegeven data zal permanent worden verwijderd.',
    'password' => 'Wachtwoord',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'Bedankt voor het aanmelden! Zodra uw factuur betaald is zal uw Pro Plan lidmaatschap beginnen.',
    'unsaved_changes' => 'Er zijn wijzigingen aangebracht die nog niet zijn opgeslagen',
    'custom_fields' => 'Aangepaste velden',
    'company_fields' => 'Bedrijfsvelden',
    'client_fields' => 'Klantvelden',
    'field_label' => 'Labelvelden',
    'field_value' => 'Waardevelden',
    'edit' => 'Bewerk',
    'set_name' => 'Bedrijfsnaam instellen',
    'view_as_recipient' => 'Bekijk als ontvanger',
    'product_library' => 'Productbibliotheek',
    'product' => 'Product',
    'products' => 'Producten',
    'fill_products' => 'Producten Automatisch aanvullen',
    'fill_products_help' => 'Een product selecteren zal automatisch <b>de beschrijving en kosten instellen</b>',
    'update_products' => 'Producten automatisch wijzigen',
    'update_products_help' => 'Het wijzigen van een factuur zal automatisch <b>de producten aanpassen</b>',
    'create_product' => 'Product maken',
    'edit_product' => 'Wijzig product',
    'archive_product' => 'Product archiveren',
    'updated_product' => 'Het product is gewijzigd',
    'created_product' => 'Het product is aangemaakt',
    'archived_product' => 'Het product is gearchiveerd',
    'pro_plan_custom_fields' => ':link om aangepaste velden in te schakelen door het Pro Plan te nemen',
    'advanced_settings' => 'Geavanceerde instellingen',
    'pro_plan_advanced_settings' => ':link om de geavanceerde instellingen te activeren door het Pro Plan te nemen',
    'invoice_design' => 'Factuurontwerp',
    'specify_colors' => 'Kies kleuren',
    'specify_colors_label' => 'Kies de kleuren die in de factuur gebruikt worden',
    'chart_builder' => 'Grafiekbouwer',
    'ninja_email_footer' => 'Gemaakt door :site | Aanmaken. Verzenden. Betaald krijgen.',
    'go_pro' => 'Go Pro',
    'quote' => 'Offerte',
    'quotes' => 'Offertes',
    'quote_number' => 'Offertenummer',
    'quote_number_short' => 'Offerte #',
    'quote_date' => 'Offertedatum',
    'quote_total' => 'Offertetotaal',
    'your_quote' => 'Uw offerte',
    'total' => 'Totaal',
    'clone' => 'Dupliceer',
    'new_quote' => 'Nieuwe offerte',
    'create_quote' => 'Maak offerte aan',
    'edit_quote' => 'Bewerk offerte',
    'archive_quote' => 'Archiveer offerte',
    'delete_quote' => 'Verwijder offerte',
    'save_quote' => 'Bewaar offerte',
    'email_quote' => 'E-mail offerte',
    'clone_quote' => 'Dupliceer offerte',
    'convert_to_invoice' => 'Zet om naar factuur',
    'view_invoice' => 'Bekijk factuur',
    'view_client' => 'Bekijk klant',
    'view_quote' => 'Bekijk offerte',
    'updated_quote' => 'De offerte is gewijzigd',
    'created_quote' => 'De offerte is aangemaakt',
    'cloned_quote' => 'De offerte is gedupliceerd',
    'emailed_quote' => 'De offerte is gemaild',
    'archived_quote' => 'De offerte is gearchiveerd',
    'archived_quotes' => 'Succesvol :count offertes gearchiveerd',
    'deleted_quote' => 'De offerte is verwijderd',
    'deleted_quotes' => 'Succesvol :count offertes verwijderd',
    'converted_to_invoice' => 'De offerte is omgezet naar een factuur',
    'quote_subject' => 'Nieuwe offerte :number van :account',
    'quote_message' => 'Om uw offerte voor :amount te bekijken, klik op de link hieronder.',
    'quote_link_message' => 'Klik op de link hieronder om de offerte te bekijken:',
    'notification_quote_sent_subject' => 'Offerte :invoice is verstuurd naar :client',
    'notification_quote_viewed_subject' => 'Offerte :invoice is bekeken door :client',
    'notification_quote_sent' => 'Offerte :invoice ter waarde van :amount is per e-mail naar :client verstuurd.',
    'notification_quote_viewed' => 'Klant :client heeft offerte :invoice voor :amount bekeken.',
    'session_expired' => 'Uw sessie is verlopen.',
    'invoice_fields' => 'Factuurvelden',
    'invoice_options' => 'Factuuropties',
    'hide_paid_to_date' => 'Verberg "Reeds betaald"',
    'hide_paid_to_date_help' => 'Toon alleen het "Reeds betaald" gebied op je facturen als er een betaling gemaakt is.',
    'charge_taxes' => 'BTW berekenen',
    'user_management' => 'Gebruikersbeheer',
    'add_user' => 'Nieuwe gebruiker',
    'send_invite' => 'Uitnodiging versturen',
    'sent_invite' => 'De uitnodiging is verzonden',
    'updated_user' => 'De gebruiker is gewijzigd',
    'invitation_message' => 'U bent uitgenodigd door :invitor. ',
    'register_to_add_user' => 'Meld u aan om een gebruiker toe te voegen',
    'user_state' => 'Status',
    'edit_user' => 'Bewerk gebruiker',
    'delete_user' => 'Verwijder gebruiker',
    'active' => 'Actief',
    'pending' => 'In afwachting',
    'deleted_user' => 'De gebruiker is verwijderd',
    'confirm_email_invoice' => 'Weet u zeker dat u deze factuur wilt e-mailen?',
    'confirm_email_quote' => 'Weet u zeker dat u deze offerte wilt e-mailen?',
    'confirm_recurring_email_invoice' => 'Terugkeren (herhalen) staat aan, weet u zeker dat u deze factuur wilt e-mailen?',
    'confirm_recurring_email_invoice_not_sent' => 'Weet je zeker dat je de herhaling wilt starten?',
    'cancel_account' => 'Account verwijderen',
    'cancel_account_message' => 'Waarschuwing: Dit zal uw account verwijderen. Er is geen manier om dit ongedaan te maken.',
    'go_back' => 'Ga Terug',
    'data_visualizations' => 'Datavisualisaties',
    'sample_data' => 'Voorbeelddata getoond',
    'hide' => 'Verbergen',
    'new_version_available' => 'Een nieuwe versie van :releases_link is beschikbaar. U gebruikt nu v:user_version, de laatste versie is v:latest_version',
    'invoice_settings' => 'Factuurinstellingen',
    'invoice_number_prefix' => 'Factuurnummer voorvoegsel',
    'invoice_number_counter' => 'Factuurnummerteller',
    'quote_number_prefix' => 'Offertenummer voorvoegsel',
    'quote_number_counter' => 'Offertenummerteller',
    'share_invoice_counter' => 'Deel factuur teller',
    'invoice_issued_to' => 'Factuur uitgegeven aan',
    'invalid_counter' => 'Stel een factuurnummervoorvoegsel of offertenummervoorvoegsel in om een mogelijk conflict te voorkomen.',
    'mark_sent' => 'Markeer als verzonden',
    'gateway_help_1' => ':link om in te schrijven voor Authorize.net.',
    'gateway_help_2' => ':link om in te schrijven voor Authorize.net.',
    'gateway_help_17' => ':link om uw PayPal API signature te krijgen.',
    'gateway_help_27' => ':link om aan te melden voor 2Checkout.com. Om te verzekeren dat betalingen gevolgd worden stel :complete_link in als de redirect URL onder Account > Site Management in het 2Checkout portaal.',
    'gateway_help_60' => ':link om WePay account aan te maken.',
    'more_designs' => 'Meer ontwerpen',
    'more_designs_title' => 'Aanvullende factuurontwerpen',
    'more_designs_cloud_header' => 'Neem Pro Plan voor meer factuurontwerpen',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Kopen',
    'bought_designs' => 'Aanvullende factuurontwerpen zijn toegevoegd',
    'sent' => 'Verzonden',
    'vat_number' => 'BTW-nummer',
    'timesheets' => 'Urenverantwoordingen',
    'payment_title' => 'Geef het betalingsadres en de creditcardgegevens op',
    'payment_cvv' => '*Dit is het cijfer van 3-4 tekens op de achterkant van de creditcard',
    'payment_footer1' => '*Betalingsadres moet overeenkomen met het adres dat aan uw kaart gekoppeld is.',
    'payment_footer2' => '*Klik alsjeblieft slechts &eacute;&eacute;n keer op "PAY NOW"  - deze verwerking kan tot 1 minuut duren.',
    'id_number' => 'Identificatienummer',
    'white_label_link' => 'White label',
    'white_label_header' => 'White label',
    'bought_white_label' => 'White label licentie is geactiveerd',
    'white_labeled' => 'White labeled',
    'restore' => 'Herstel',
    'restore_invoice' => 'Herstel factuur',
    'restore_quote' => 'Herstel offerte',
    'restore_client' => 'Herstel klant',
    'restore_credit' => 'Herstel kredietnota',
    'restore_payment' => 'Herstel betaling',
    'restored_invoice' => 'De factuur is hersteld',
    'restored_quote' => 'De offerte is hersteld',
    'restored_client' => 'De klant is hersteld',
    'restored_payment' => 'De betaling is hersteld',
    'restored_credit' => 'De kredietnota is hersteld',
    'reason_for_canceling' => 'Help ons om onze site te verbeteren door ons te vertellen waarom u weggaat.',
    'discount_percent' => 'Percentage',
    'discount_amount' => 'Bedrag',
    'invoice_history' => 'Factuurgeschiedenis',
    'quote_history' => 'Offertegeschiedenis',
    'current_version' => 'Huidige versie',
    'select_version' => 'Selecteer versie',
    'view_history' => 'Bekijk geschiedenis',
    'edit_payment' => 'Bewerk betaling',
    'updated_payment' => 'De betaling is gewijzigd',
    'deleted' => 'Verwijderd',
    'restore_user' => 'Herstel gebruiker',
    'restored_user' => 'De gebruiker is hersteld',
    'show_deleted_users' => 'Toon verwijderde gebruikers',
    'email_templates' => 'E-mailsjablonen',
    'invoice_email' => 'Factuurmail',
    'payment_email' => 'Betalingsmail',
    'quote_email' => 'Offertemail',
    'reset_all' => 'Reset alles',
    'approve' => 'Goedkeuren',
    'token_billing_type_id' => 'Betalingstoken',
    'token_billing_help' => 'Bewaar betaalgegevens met WePay, Stripe, Braintree of GoCardless.',
    'token_billing_1' => 'Inactief',
    'token_billing_2' => 'Opt-in - selectiebox is getoond maar niet geselecteerd',
    'token_billing_3' => 'Opt-out - selectiebox is getoond en geselecteerd',
    'token_billing_4' => 'Altijd',
    'token_billing_checkbox' => 'Sla carditcard gegevens op',
    'view_in_gateway' => 'In :gateway bekijken',
    'use_card_on_file' => 'Gebruik opgeslagen kaart',
    'edit_payment_details' => 'Wijzig betalingsgegevens',
    'token_billing' => 'Kaartgegevens opslaan',
    'token_billing_secure' => 'Kaartgegevens worden veilig opgeslagen door :link',
    'support' => 'Ondersteuning',
    'contact_information' => 'Contact informatie',
    '256_encryption' => '256-bit versleuteling',
    'amount_due' => 'Te betalen bedrag',
    'billing_address' => 'Factuuradres',
    'billing_method' => 'Betaalmethode',
    'order_overview' => 'Orderoverzicht',
    'match_address' => '*Adres moet overeenkomen met adres van creditcard.',
    'click_once' => '*Klik alstublieft maar &eacute;&eacute;n keer; het kan een minuut duren om de betaling te verwerken.',
    'invoice_footer' => 'Factuurvoettekst',
    'save_as_default_footer' => 'Bewaar als standaard voettekst',
    'token_management' => 'Tokenbeheer',
    'tokens' => 'Tokens',
    'add_token' => 'Voeg token toe',
    'show_deleted_tokens' => 'Toon verwijderde tokens',
    'deleted_token' => 'Het token is verwijderd',
    'created_token' => 'Het token is aangemaakt',
    'updated_token' => 'Het token is gewijzigd',
    'edit_token' => 'Wijzig token',
    'delete_token' => 'Verwijder token',
    'token' => 'Token',
    'add_gateway' => 'Gateway toevoegen',
    'delete_gateway' => 'Gateway verwijderen',
    'edit_gateway' => 'Wijzig gateway',
    'updated_gateway' => 'De gateway is gewijzigd',
    'created_gateway' => 'De gateway is aangemaakt',
    'deleted_gateway' => 'De gateway is verwijderd',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Creditcard',
    'change_password' => 'Verander wachtwoord',
    'current_password' => 'Huidig wachtwoord',
    'new_password' => 'Nieuw wachtwoord',
    'confirm_password' => 'Bevestig wachtwoord',
    'password_error_incorrect' => 'Het huidige wachtwoord is niet juist.',
    'password_error_invalid' => 'Het nieuwe wachtwoord is ongeldig.',
    'updated_password' => 'Het wachtwoord is gewijzigd',
    'api_tokens' => 'API Tokens',
    'users_and_tokens' => 'Gebruikers en tokens',
    'account_login' => 'Accountlogin',
    'recover_password' => 'Wachtwoord vergeten?',
    'forgot_password' => 'Wachtwoord vergeten?',
    'email_address' => 'E-mailadres',
    'lets_go' => 'Let’s go',
    'password_recovery' => 'Wachtwoord Herstel',
    'send_email' => 'Verstuur e-mail',
    'set_password' => 'Stel wachtwoord in',
    'converted' => 'Omgezet',
    'email_approved' => 'E-mail mij wanneer een offerte is <b>goedgekeurd</b>',
    'notification_quote_approved_subject' => 'Offerte :invoice is goedgekeurd door :client',
    'notification_quote_approved' => ':client heeft offerte :invoice goedgekeurd voor :amount.',
    'resend_confirmation' => 'Verstuurd bevestingsmail opnieuw',
    'confirmation_resent' => 'De bevestigingsmail is opnieuw verstuurd',
    'gateway_help_42' => ':link om te registreren voor BitPay.<br/>Opmerking: gebruik een Legacy API Key, niet een API token.',
    'payment_type_credit_card' => 'Creditcard',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Kennisbank',
    'partial' => 'Voorschot',
    'partial_remaining' => ':partial / :balance',
    'more_fields' => 'Meer velden',
    'less_fields' => 'Minder velden',
    'client_name' => 'Klantnaam',
    'pdf_settings' => 'PDF-instellingen',
    'product_settings' => 'Productinstellingen',
    'auto_wrap' => 'Automatisch regel afbreken',
    'duplicate_post' => 'Opgelet: de volgende pagina is twee keer doorgestuurd. De tweede verzending is genegeerd.',
    'view_documentation' => 'Bekijk documentatie',
    'app_title' => 'Gratis Open-Source Online Facturatie',
    'app_description' => 'Invoice Ninja is een gratis, open-source oplossing voor het maken en versturen van facturen aan klanten. Met Invoice Ninja, kun je gemakkelijk mooie facturen maken en verzenden vanaf elk apparaat met internettoegang. Je klanten kunnen je facturen afdrukken, downloaden als pdf bestand en je zelfs online betalen vanuit het systeem.',
    'rows' => 'rijen',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomein',
    'provide_name_or_email' => 'Gelieve een naam of e-mail op te geven',
    'charts_and_reports' => 'Grafieken en rapporten',
    'chart' => 'Grafiek',
    'report' => 'Rapport',
    'group_by' => 'Groepeer per',
    'paid' => 'Betaald',
    'enable_report' => 'Rapport',
    'enable_chart' => 'Grafiek',
    'totals' => 'Totalen',
    'run' => 'Uitvoeren',
    'export' => 'Exporteer',
    'documentation' => 'Documentatie',
    'zapier' => 'Zapier',
    'recurring' => 'Terugkerend',
    'last_invoice_sent' => 'Laatste factuur verzonden :date',
    'processed_updates' => 'De update is uitgevoerd',
    'tasks' => 'Taken',
    'new_task' => 'Nieuwe taak',
    'start_time' => 'Starttijd',
    'created_task' => 'De taak is aangemaakt',
    'updated_task' => 'De taak is gewijzigd',
    'edit_task' => 'Wijzig taak',
    'clone_task' => 'Dupliceer taak',
    'archive_task' => 'Archiveer taak',
    'restore_task' => 'Herstel taak',
    'delete_task' => 'Verwijder taak',
    'stop_task' => 'Stop taak',
    'time' => 'Tijd',
    'start' => 'Start',
    'stop' => 'Stop',
    'now' => 'Nu',
    'timer' => 'Timer',
    'manual' => 'Manueel',
    'date_and_time' => 'Datum en tijd',
    'second' => 'Seconde',
    'seconds' => 'Seconden',
    'minute' => 'Minuut',
    'minutes' => 'Minuten',
    'hour' => 'Uur',
    'hours' => 'Uren',
    'task_details' => 'Taakdetails',
    'duration' => 'Duur',
    'time_log' => 'Tijdschema',
    'end_time' => 'Eindtijd',
    'end' => 'Einde',
    'invoiced' => 'Gefactureerd',
    'logged' => 'Gelogd',
    'running' => 'Lopend',
    'task_error_multiple_clients' => 'Taken kunnen niet tot meerdere klanten behoren',
    'task_error_running' => 'Stop a.u.b. de lopende taken eerst',
    'task_error_invoiced' => 'Deze taken zijn al gefactureerd',
    'restored_task' => 'De taak is hersteld',
    'archived_task' => 'De taak is gearchiveerd',
    'archived_tasks' => 'Succesvol :count taken gearchiveerd',
    'deleted_task' => 'De taak is verwijderd',
    'deleted_tasks' => 'Succesvol :count taken verwijderd',
    'create_task' => 'Taak aanmaken',
    'stopped_task' => 'De taak is gestopt',
    'invoice_task' => 'Factureer taak',
    'invoice_labels' => 'Factuurlabels',
    'prefix' => 'Voorvoegsel',
    'counter' => 'Teller',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link om in te schrijven voor Dwolla.',
    'partial_value' => 'Moet groter zijn dan nul en minder dan het totaal',
    'more_actions' => 'Meer acties',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Nu upgraden!',
    'pro_plan_feature1' => 'Ongelimiteerd klanten aanmaken',
    'pro_plan_feature2' => 'Toegang tot 10 mooie factuur ontwerpen',
    'pro_plan_feature3' => 'Aangepaste URLs - "UwMerk.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Verwijder "Aangemaakt door Invoice Ninja"',
    'pro_plan_feature5' => 'Multi-user toegang & Activeit Tracking',
    'pro_plan_feature6' => 'Maak offertes & Pro-forma facturen aan',
    'pro_plan_feature7' => 'Pas factuur veld titels & nummering aan',
    'pro_plan_feature8' => 'Optie om PDFs toe te voegen aan de emails naar klanten',
    'resume' => 'Doorgaan',
    'break_duration' => 'Pauze',
    'edit_details' => 'Wijzig details',
    'work' => 'Werk',
    'timezone_unset' => ':link om uw tijdszone aan te passen',
    'click_here' => 'Klik hier',
    'email_receipt' => 'Mail betalingsbewijs naar de klant',
    'created_payment_emailed_client' => 'De betaling is toegevoegd en per mail verstuurd naar de klant',
    'add_company' => 'Bedrijf toevoegen',
    'untitled' => 'Zonder titel',
    'new_company' => 'Nieuw bedrijf',
    'associated_accounts' => 'Accounts gekoppeld',
    'unlinked_account' => 'Accounts losgekoppeld',
    'login' => 'Login',
    'or' => 'of',
    'email_error' => 'Er was een probleem met versturen van de e-mail',
    'confirm_recurring_timing' => 'Opmerking: e-mails worden aan het begin van het uur verzonden.',
    'confirm_recurring_timing_not_sent' => 'Opmerking: facturen worden aan het begin van het uur gemaakt.',
    'payment_terms_help' => 'Stel de standaard <b>factuurvervaldatum</b> in.',
    'unlink_account' => 'Koppel account los',
    'unlink' => 'Koppel los',
    'show_address' => 'Toon Adres',
    'show_address_help' => 'Verplicht de klant om zijn factuuradres op te geven',
    'update_address' => 'Adres aanpassen',
    'update_address_help' => 'Pas het adres van de klant aan met de ingevulde gegevens',
    'times' => 'Tijden',
    'set_now' => 'Start nu',
    'dark_mode' => 'Donkere modus',
    'dark_mode_help' => 'Gebruik een donkere achtergrond voor de zijbalk',
    'add_to_invoice' => 'Toevoegen aan factuur :invoice',
    'create_new_invoice' => 'Maak een nieuwe factuur',
    'task_errors' => 'Pas overlappende tijden aan a.u.b..',
    'from' => 'Van',
    'to' => 'Aan',
    'font_size' => 'Tekstgrootte',
    'primary_color' => 'Primaire kleur',
    'secondary_color' => 'Secundaire kleur',
    'customize_design' => 'Wijzig ontwerp',
    'content' => 'Inhoud',
    'styles' => 'Stijlen',
    'defaults' => 'Standaardwaarden',
    'margins' => 'Marges',
    'header' => 'Koptekst',
    'footer' => 'Voettekst',
    'custom' => 'Aangepast',
    'invoice_to' => 'Factuur aan',
    'invoice_no' => 'Factuur nr.',
    'quote_no' => 'Offerte nr.',
    'recent_payments' => 'Recente betalingen',
    'outstanding' => 'Uitstaand',
    'manage_companies' => 'Beheer bedrijven',
    'total_revenue' => 'Totale inkomsten',
    'current_user' => 'Huidige gebruiker',
    'new_recurring_invoice' => 'Nieuwe terugkerende factuur',
    'recurring_invoice' => 'Terugkerende factuur',
    'new_recurring_quote' => 'Nieuwe terugkerende offerte',
    'recurring_quote' => 'Terugkerende offerte',
    'recurring_too_soon' => 'Het is te vroeg om de volgende terugkerende factuur aan te maken, dit is gepland voor :date',
    'created_by_invoice' => 'Aangemaakt door :invoice',
    'primary_user' => 'Primaire gebruiker',
    'help' => 'Help',
    'customize_help' => '<p>We gebruiken :pdfmake_link om de factuurontwerpen declaratief te definieren. De pdfmake :playground_link biedt een interessante manier om de library in actie te zien.</p>
                        <p>Als je ergens hulp bij nodig hebt, stel dan een vraag op ons support forum met het design dat je gebruikt.</p>',
    'playground' => 'playground',
    'support_forum' => 'Support Forum',
    'invoice_due_date' => 'Vervaldatum',
    'quote_due_date' => 'Geldig tot',
    'valid_until' => 'Geldig tot',
    'reset_terms' => 'Reset voorwaarden',
    'reset_footer' => 'Voettekst resetten',
    'invoice_sent' => ':count factuur verzonden',
    'invoices_sent' => 'facturen verzonden',
    'status_draft' => 'Concept',
    'status_sent' => 'Verstuurd',
    'status_viewed' => 'Bekeken',
    'status_partial' => 'Gedeeltelijk',
    'status_paid' => 'Betaald',
    'status_unpaid' => 'Onbetaald',
    'status_all' => 'Alles',
    'show_line_item_tax' => '<b>BTW-tarieven per regel</b> tonen',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'Kopieer de volgende code naar een pagina op uw site.',
    'iframe_url_help2' => 'U kunt de functionaliteit testen door te klikken op \'Bekijk als ontvanger\' bij een factuur.',
    'auto_bill' => 'Automatische incasso',
    'military_time' => '24-uurs klok',
    'last_sent' => 'Laatst verstuurd',
    'reminder_emails' => 'Herinneringsmails',
    'quote_reminder_emails' => 'Offerte Herinneringsmails',
    'templates_and_reminders' => 'Sjablonen en herinneringen',
    'subject' => 'Onderwerp',
    'body' => 'Tekst',
    'first_reminder' => 'Eerste herinnering',
    'second_reminder' => 'Tweede herinnering',
    'third_reminder' => 'Derde herinnering',
    'num_days_reminder' => 'Dagen na vervaldatum',
    'reminder_subject' => 'Herinnering: Factuur :invoice van :account',
    'reset' => 'Reset',
    'invoice_not_found' => 'De opgevraagde factuur is niet beschikbaar',
    'referral_program' => 'Referral Program',
    'referral_code' => 'Referral Code',
    'last_sent_on' => 'Laatst verstuurd op :date',
    'page_expire' => 'Deze pagina verloopt binnenkort, :click_here om verder te kunnen werken',
    'upcoming_quotes' => 'Eerstvolgende offertes',
    'expired_quotes' => 'Verlopen offertes',
    'sign_up_using' => 'Meld u aan met',
    'invalid_credentials' => 'Deze inloggegevens zijn niet bij ons bekend',
    'show_all_options' => 'Alle opties tonen',
    'user_details' => 'Gebruikersgegevens',
    'oneclick_login' => 'Koppel een account',
    'disable' => 'Uitzetten',
    'invoice_quote_number' => 'Factuur- en offertenummers',
    'invoice_charges' => 'Facturatiekosten',
    'notification_invoice_bounced' => 'We konden factuur :invoice niet afleveren bij :contact.',
    'notification_invoice_bounced_subject' => 'Factuur :invoice kon niet worden afgeleverd',
    'notification_quote_bounced' => 'We konden offerte :invoice niet afleveren bij :contact.',
    'notification_quote_bounced_subject' => 'Offerte :invoice kon niet worden afgeleverd',
    'custom_invoice_link' => 'Eigen factuurlink',
    'total_invoiced' => 'Totaal gefactureerd',
    'open_balance' => 'Openstaand bedrag',
    'verify_email' => 'Klik alstublieft op de link in de accountbevestigings-e-mail om uw e-mailadres te bevestigen.',
    'basic_settings' => 'Basisinstellingen',
    'pro' => 'Pro',
    'gateways' => 'Betalingsverwerkers',
    'next_send_on' => 'Verstuur volgende: :date',
    'no_longer_running' => 'Deze factuur is niet ingepland',
    'general_settings' => 'Algemene instellingen',
    'customize' => 'Aanpassen',
    'oneclick_login_help' => 'Koppel een account om zonder wachtwoord in te kunnen loggen',
    'referral_code_help' => 'Verdien geld door onze applicatie online te delen',
    'enable_with_stripe' => 'Aanzetten | Vereist Stripe',
    'tax_settings' => 'BTW-instellingen',
    'create_tax_rate' => 'Voeg een tarief toe',
    'updated_tax_rate' => 'Het tarief is bijgewerkt',
    'created_tax_rate' => 'Het tarief is aangemaakt',
    'edit_tax_rate' => 'Bewerk tarief',
    'archive_tax_rate' => 'Archiveer tarief',
    'archived_tax_rate' => 'Het tarief is gearchiveerd',
    'default_tax_rate_id' => 'Standaard BTW-tarief',
    'tax_rate' => 'BTW-tarief',
    'recurring_hour' => 'Uur van de dag voor het aanmaken van terugkerende facturen',
    'pattern' => 'Patroon',
    'pattern_help_title' => 'Help bij patroon',
    'pattern_help_1' => 'Maak aangepaste factuur- en offertenummers op basis van een patroon',
    'pattern_help_2' => 'Beschikbare variabelen:',
    'pattern_help_3' => 'Bijvoorbeeld, :example wordt omgezet naar :value',
    'see_options' => 'Zie opties',
    'invoice_counter' => 'Factuurteller',
    'quote_counter' => 'Offerteteller',
    'type' => 'Type',
    'activity_1' => ':user heeft klant :client aangemaakt',
    'activity_2' => ':user heeft klant :client gearchiveerd',
    'activity_3' => ':user heeft klant :client verwijderd',
    'activity_4' => ':user heeft factuur :invoice aangemaakt',
    'activity_5' => ':user heeft factuur :invoice bijgewerkt',
    'activity_6' => ':user heeft factuur :invoice voor :client naar :contact verstuurd',
    'activity_7' => ':contact heeft factuur :invoice voor :client bekeken',
    'activity_8' => ':user heeft factuur :invoice gearchiveerd',
    'activity_9' => ':user heeft factuur :invoice verwijderd',
    'activity_10' => ':contact heeft betaling :payment van :payment_amount ingevoerd voor factuur :invoice voor :client',
    'activity_11' => ':user heeft betaling :payment bijgewerkt',
    'activity_12' => ':user heeft betaling :payment gearchiveerd',
    'activity_13' => ':user heeft betaling :payment verwijderd',
    'activity_14' => ':user heeft :credit krediet ingevoerd',
    'activity_15' => ':user heeft :credit krediet bijgewerkt',
    'activity_16' => ':user heeft :credit krediet gearchiveerd',
    'activity_17' => ':user heeft :credit krediet verwijderd',
    'activity_18' => ':user heeft offerte :quote aangemaakt',
    'activity_19' => ':user heeft offerte :quote bijgewerkt',
    'activity_20' => ':user heeft offerte :quote voor :client verstuurd naar :contact',
    'activity_21' => ':contact heeft offerte :quote bekeken',
    'activity_22' => ':user heeft offerte :quote gearchiveerd',
    'activity_23' => ':user heeft offerte :quote verwijderd',
    'activity_24' => ':user heeft offerte :quote hersteld',
    'activity_25' => ':user heeft factuur :invoice hersteld',
    'activity_26' => ':user heeft klant :client hersteld',
    'activity_27' => ':user heeft betaling :payment hersteld',
    'activity_28' => ':user heeft :credit krediet hersteld',
    'activity_29' => ':contact heeft offerte :quote goedgekeurd voor :client',
    'activity_30' => ':user heeft leverancier :vendor aangemaakt',
    'activity_31' => ':user heeft leverancier :vendor gearchiveerd',
    'activity_32' => ':user heeft leverancier :vendor verwijderd',
    'activity_33' => ':user heeft leverancier :vendor hersteld',
    'activity_34' => ':user heeft uitgave :expense aangemaakt',
    'activity_35' => ':user heeft uitgave :expense gearchiveerd',
    'activity_36' => ':user heeft uitgave :expense verwijderd',
    'activity_37' => ':user heeft uitgave :expense hersteld',
    'activity_42' => ':user heeft taak :task aangemaakt',
    'activity_43' => ':user heeft taak :task bijgewerkt',
    'activity_44' => ':user heeft taak :task gearchiveerd',
    'activity_45' => ':user heeft taak :task verwijderd',
    'activity_46' => ':user heeft taak :task hersteld',
    'activity_47' => ':user heeft uitgave :expense bijgewerkt',
    'activity_48' => ':user heeft ticket :ticket bijgewerkt',
    'activity_49' => ':user heeft ticket :ticket gesloten',
    'activity_50' => ':user heeft ticket :ticket samengevoegd',
    'activity_51' => ':user heeft ticket :ticket gesplitst',
    'activity_52' => ':contact heeft ticket :ticket geopend',
    'activity_53' => ':contact heeft ticket :ticket heropend',
    'activity_54' => ':user heeft ticket :ticket heropend',
    'activity_55' => ':contact heeft op ticket :ticket gereageerd',
    'activity_56' => ':user heeft ticket :ticket bekeken',

    'payment' => 'Betaling',
    'system' => 'Systeem',
    'signature' => 'E-mailhandtekening',
    'default_messages' => 'Standaardberichten',
    'quote_terms' => 'Offertevoorwaarden',
    'default_quote_terms' => 'Standaard offertevoorwaarden',
    'default_invoice_terms' => 'Stel standaard factuurvoorwaarden in',
    'default_invoice_footer' => 'Stel standaard factuurfvoettekst in',
    'quote_footer' => 'Offertevoettekst',
    'free' => 'Gratis',
    'quote_is_approved' => 'Akkoord',
    'apply_credit' => 'Gebruik krediet',
    'system_settings' => 'Systeeminstellingen',
    'archive_token' => 'Archiveer token',
    'archived_token' => 'Het token is gearchiveerd',
    'archive_user' => 'Archiveer gebruiker',
    'archived_user' => 'De gebruiker is gearchiveerd',
    'archive_account_gateway' => 'Gateway verwijderen',
    'archived_account_gateway' => 'De betalingsverwerker is gearchiveerd',
    'archive_recurring_invoice' => 'Archiveer terugkerende factuur',
    'archived_recurring_invoice' => 'De terugkerende factuur is gearchiveerd',
    'delete_recurring_invoice' => 'Verwijder terugkerende factuur',
    'deleted_recurring_invoice' => 'De terugkerende factuur is verwijderd',
    'restore_recurring_invoice' => 'Herstel terugkerende factuur',
    'restored_recurring_invoice' => 'De terugkerende factuur is hersteld',
    'archive_recurring_quote' => 'Archiveer terugkerende offerte',
    'archived_recurring_quote' => 'De terugkerende is offerte gearchiveerd',
    'delete_recurring_quote' => 'Verwijder terugkerende offerte',
    'deleted_recurring_quote' => 'De terugkerende offerte is verwijderd',
    'restore_recurring_quote' => 'Herstel terugkerende offerte',
    'restored_recurring_quote' => 'De terugkerende offerte is hersteld',
    'archived' => 'Gearchiveerd',
    'untitled_account' => 'Naamloos bedrijf',
    'before' => 'Voor',
    'after' => 'Na',
    'reset_terms_help' => 'Herstel de standaardvoorwaarden',
    'reset_footer_help' => 'Herstel de standaard voettekst',
    'export_data' => 'Exporteer data',
    'user' => 'Gebruiker',
    'country' => 'Land',
    'include' => 'Voeg in',
    'logo_too_large' => 'Je logo is :size groot, voor betere PDF prestaties raden we je aan om een afbeelding kleiner dan 200KB te uploaden.',
    'import_freshbooks' => 'Importeren van FreshBooks',
    'import_data' => 'Importeer data',
    'source' => 'Bron',
    'csv' => 'CSV',
    'client_file' => 'Klantenbestand',
    'invoice_file' => 'Factuurbestand',
    'task_file' => 'Urenbestand',
    'no_mapper' => 'Geen geldige mapping voor bestand',
    'invalid_csv_header' => 'Ongeldige CSV kop',
    'client_portal' => 'Klantenportaal',
    'admin' => 'Admin',
    'disabled' => 'Uitgeschakeld',
    'show_archived_users' => 'Toon gearchiveerde gebruikers',
    'notes' => 'Notities',
    'invoice_will_create' => 'Factuur zal worden aangemaakt',
    'invoices_will_create' => 'factuur zal worden aangemaakt',
    'failed_to_import' => 'De volgende regels konden niet worden ge&iuml;mporteerd, ze bestaan al of missen verplichte velden.',
    'publishable_key' => 'Publishable Key',
    'secret_key' => 'Secret Key',
    'missing_publishable_key' => 'Set your Stripe publishable key for an improved checkout process',
    'email_design' => 'E-mail Ontwerp',
    'due_by' => 'Vervaldatum :date',
    'enable_email_markup' => 'Opmaak inschakelen',
    'enable_email_markup_help' => 'Maak het gemakkelijker voor uw klanten om te betalen door scherma.org opmaak toe te voegen aan uw e-mails.',
    'template_help_title' => 'Hulp bij sjablonen',
    'template_help_1' => 'Beschikbare variabelen:',
    'email_design_id' => 'E-mailstijl',
    'email_design_help' => 'Geef uw e-mails een professionele uitstraling met HTML ontwerpen.',
    'plain' => 'Platte tekst',
    'light' => 'Licht',
    'dark' => 'Donker',
    'industry_help' => 'Wordt gebruikt om een vergelijking te kunnen maken met de gemiddelden van andere bedrijven uit dezelfde sector en van dezelfde grootte.',
    'subdomain_help' => 'Stel het subdomein in of toon de factuur op uw eigen website.',
    'website_help' => 'Toon de factuur in een iFrame op uw eigen website',
    'invoice_number_help' => 'Kies een voorvoegsel of gebruik een patroon om het factuurnummer dynamisch te genereren.',
    'quote_number_help' => 'Kies een voorvoegsel of gebruik een patroon om het offertenummer dynamisch te genereren.',
    'custom_client_fields_helps' => 'Voeg een veld toe bij het creëren van een klant en toon het label en de waarde op de PDF.',
    'custom_account_fields_helps' => 'Plaatst een tekstveld op de bedrijven aanmaak-/bewerkpagina en toont het gekozen label op de PDF.',
    'custom_invoice_fields_helps' => 'Voeg een veld toe bij het creëren van een factuur en toon het label en de waarde op de PDF.',
    'custom_invoice_charges_helps' => 'Plaatst een tekstveld op de factuur aanmaak-/bewerkpagina en verwerkt de facturatiekosten in het subtotaal.',
    'token_expired' => 'De validatie token is verlopen. Probeer het opnieuw.',
    'invoice_link' => 'Factuur Link',
    'button_confirmation_message' => 'Klik om uw e-mailadres te bevestigen.',
    'confirm' => 'Bevestigen',
    'email_preferences' => 'E-mailvoorkeuren',
    'created_invoices' => 'Succesvol :count factuur(en) aangemaakt',
    'next_invoice_number' => 'Het volgende factuurnummer is :number.',
    'next_quote_number' => 'Het volgende offertenummer is :number.',
    'days_before' => 'dagen voor de',
    'days_after' => 'dagen na de',
    'field_due_date' => 'vervaldatum',
    'field_invoice_date' => 'factuurdatum',
    'schedule' => 'Schema',
    'email_designs' => 'E-mail Ontwerpen',
    'assigned_when_sent' => 'Toegewezen zodra verzonden',
    'white_label_purchase_link' => 'Koop een whitelabel licentie',
    'expense' => 'Uitgave',
    'expenses' => 'Uitgaven',
    'new_expense' => 'Nieuwe uitgave',
    'enter_expense' => 'Voer uitgave in',
    'vendors' => 'Leveranciers',
    'new_vendor' => 'Nieuwe leverancier',
    'payment_terms_net' => 'Betaaltermijn',
    'vendor' => 'Leverancier',
    'edit_vendor' => 'Bewerk leverancier',
    'archive_vendor' => 'Archiveer leverancier',
    'delete_vendor' => 'Verwijder leverancier',
    'view_vendor' => 'Bekijk leverancier',
    'deleted_expense' => 'De uitgave is verwijderd',
    'archived_expense' => 'De uitgave is gearchiveerd',
    'deleted_expenses' => 'De uitgaven zijn verwijderd',
    'archived_expenses' => 'De uitgaven zijn gearchiveerd',
    'expense_amount' => 'Uitgave bedrag',
    'expense_balance' => 'Uitgave saldo',
    'expense_date' => 'Uitgave datum',
    'expense_should_be_invoiced' => 'Moet deze uitgave worden gefactureerd?',
    'public_notes' => 'Publieke opmerkingen',
    'invoice_amount' => 'Factuurbedrag',
    'exchange_rate' => 'Wisselkoers',
    'yes' => 'Ja',
    'no' => 'Nee',
    'should_be_invoiced' => 'Moet worden gefactureerd',
    'view_expense' => 'Bekijk uitgave #:expense',
    'edit_expense' => 'Bewerk uitgave',
    'archive_expense' => 'Archiveer uitgave',
    'delete_expense' => 'Verwijder uitgave',
    'view_expense_num' => 'Uitgave #:expense',
    'updated_expense' => 'De uitgave is gewijzigd',
    'created_expense' => 'De uitgave is aangemaakt',
    'enter_expense' => 'Voer uitgave in',
    'view' => 'Bekijken',
    'restore_expense' => 'Herstel uitgave',
    'invoice_expense' => 'Factureer uitgave',
    'expense_error_multiple_clients' => 'De uitgaven kunnen niet bij verschillende klanten horen',
    'expense_error_invoiced' => 'Uitgave is al gefactureerd',
    'convert_currency' => 'Reken valuta om',
    'num_days' => 'Aantal dagen',
    'create_payment_term' => 'Betalingstermijn aanmaken',
    'edit_payment_terms' => 'Bewerk betalingstermijnen',
    'edit_payment_term' => 'Bewerk betalingstermijn',
    'archive_payment_term' => 'Archiveer betalingstermijn',
    'recurring_due_dates' => 'Vervaldatums van terugkerende facturen',
    'recurring_due_date_help' => '<p>Stelt automatisch een vervaldatum in voor de factuur.</p>
        <p>Facturen die maandelijks of jaarlijks terugkeren en ingesteld zijn om te vervallen op of voor de datum waarop ze gemaakt zijn zullen de volgende maand vervallen. Facturen die ingesteld zijn te vervallen op de 29e of 30e van een maand die deze dag niet heeft zullen vervallen op de laatste dag van die maand.</p>
        <p>Facturen die wekelijks terugkeren en ingesteld zijn om te vervallen op de dag van de week dat ze gemaakt zijn zullen de volgende week vervallen.</p>
        <p>Bijvoorbeeld:</p>
        <ul>
          <li>Vandaag is het de 15e, de vervaldatum is ingesteld op de eerste dag van de maand. De vervaldatum zal de eerste dag van de volgende maand zijn.</li>
          <li>Vandaag is het de 15e, de vervaldatum is ingesteld op de laatste dag van de maand. De vervaldatum zal de laatste dag van deze maand zijn.</li>
          <li>Vandaag is het de 15e, de vervaldatum is ingesteld op de 15e dag van de maand. De vervaldatum zal de 15e dag van de <strong>volgende</strong> maand zijn.</li>
          <li>Vandaag is het vrijdag, de vervaldatum is ingesteld op de 1e vrijdag erna. De vervaldatum zal volgende week vrijdag zijn, niet vandaag.</li>
        </ul>',
    'due' => 'Vervaldatum',
    'next_due_on' => 'Vervaldatum volgende: :date',
    'use_client_terms' => 'Gebruik betalingsvoorwaarden klant',
    'day_of_month' => ':ordinal dag van de maand',
    'last_day_of_month' => 'Laatste dag van de maand',
    'day_of_week_after' => ':ordinal :day erna',
    'sunday' => 'Zondag',
    'monday' => 'Maandag',
    'tuesday' => 'Dinsdag',
    'wednesday' => 'Woensdag',
    'thursday' => 'Donderdag',
    'friday' => 'Vrijdag',
    'saturday' => 'Zaterdag',
    'header_font_id' => 'Header lettertype',
    'body_font_id' => 'Body lettertype',
    'color_font_help' => 'Opmerking: de primaire kleuren en lettertypen wordt ook gebruikt in het klantenportaal en in aangepaste e-mailontwerpen.',
    'live_preview' => 'Live Voorbeeld',
    'invalid_mail_config' => 'Kon de e-mail niet verzenden, controleer of de e-mailinstellingen kloppen.',
    'invoice_message_button' => 'Klik op de onderstaande link om uw factuur van :amount te bekijken.',
    'quote_message_button' => 'Klik op de onderstaande link om uw offerte van :amount te bekijken.',
    'payment_message_button' => 'Bedankt voor uw betaling van :amount.',
    'payment_type_direct_debit' => 'Automatisch incasso',
    'bank_accounts' => 'Bankrekeningen',
    'add_bank_account' => 'Bankrekening toevoegen',
    'setup_account' => 'Rekening instellen',
    'import_expenses' => 'Uitgaven importeren',
    'bank_id' => 'Bank',
    'integration_type' => 'Integratietype',
    'updated_bank_account' => 'De bankrekening is gewijzigd',
    'edit_bank_account' => 'Bewerk bankrekening',
    'archive_bank_account' => 'Archiveer bankrekening',
    'archived_bank_account' => 'De bankrekening is gearchiveerd',
    'created_bank_account' => 'Bankrekening toegevoegd',
    'validate_bank_account' => 'Bankrekening valideren',
    'bank_password_help' => 'Opmerking: uw wachtwoord wordt beveiligd verstuurd en wordt nooit op onze servers opgeslagen.',
    'bank_password_warning' => 'Waarschuwing: uw wachtwoord wordt mogelijk als leesbare tekst verzonden, overweeg HTTPS in te schakelen.',
    'username' => 'Gebruikersnaam',
    'account_number' => 'Rekeningnummer',
    'account_name' => 'Rekeninghouder',
    'bank_account_error' => 'Het ophalen van accountgegevens is mislukt, controleer uw inloggegevens.',
    'status_approved' => 'Goedgekeurd',
    'quote_settings' => 'Offerte-instellingen',
    'auto_convert_quote' => 'Automatisch omzetten',
    'auto_convert_quote_help' => 'Zet een offerte automatisch om in een factuur zodra deze door een klant wordt goedgekeurd.',
    'validate' => 'Valideren',
    'info' => 'Informatie',
    'imported_expenses' => 'Er zijn :count_vendors leverancier(s) en :count_expenses uitgave(n) aangemaakt.',
    'iframe_url_help3' => 'Opmerking: als u van plan bent om creditcard betalingen te accepteren raden wij u dringend aan om HTTPS in te schakelen op uw website.',
    'expense_error_multiple_currencies' => 'De uitgaven kunnen geen verschillende munteenheden hebben.',
    'expense_error_mismatch_currencies' => 'De munteenheid van de klant komt niet overeen met de munteenheid van de uitgave.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Koptekst/voettekst',
    'first_page' => 'eerste pagina',
    'all_pages' => 'alle pagina\'s',
    'last_page' => 'laatste pagina',
    'all_pages_header' => 'Toon header op',
    'all_pages_footer' => 'Toon footer op',
    'invoice_currency' => 'Factuur valuta',
    'enable_https' => 'We raden u dringend aan om HTTPS te gebruiken om creditcard informatie digitaal te accepteren.',
    'quote_issued_to' => 'Offerte uitgeschreven voor',
    'show_currency_code' => 'Valutacode',
    'free_year_message' => 'Uw account is gratis geüpgraded naar een pro account voor één jaar.',
    'trial_message' => 'Uw account zal een gratis twee weken durende probeerversie van ons pro plan krijgen.',
    'trial_footer' => 'Uw gratis probeerversie duurt nog :count dagen, :link om direct te upgraden.',
    'trial_footer_last_day' => 'Dit is de laatste dag van uw gratis probeerversie, :link om direct te upgraden.',
    'trial_call_to_action' => 'Start gratis probeerversie',
    'trial_success' => 'De gratis twee weken durende probeerversie van het pro plan is geactiveerd.',
    'overdue' => 'Verlopen',


    'white_label_text' => 'Koop een white label licentie voor één jaar voor $:price om de Invoice Ninja reclame te verwijderen van facturen en het klantenportaal.',
    'user_email_footer' => 'Ga alstublieft naar :link om uw e-mail notificatie instellingen aan te passen',
    'reset_password_footer' => 'Neem a.u.b. contact op met onze helpdesk indien u deze wachtwoordreset niet heeft aangevraagd. Het e-mailadres van de helpdesk is :email',
    'limit_users' => 'Sorry, dit zou de limiet van :limit gebruikers overschrijden',
    'more_designs_self_host_header' => 'Krijg 6 extra factuurontwerpen voor maar $:price',
    'old_browser' => 'Gelieve een :link te gebruiken',
    'newer_browser' => 'nieuwere browser',
    'white_label_custom_css' => ':link voor $:price om eigen opmaak te gebruiken en ons project te ondersteunen.',
    'bank_accounts_help' => 'Koppel een bankrekening om automatisch uitgaven en leveranciers te importeren. Ondersteund American Express en :link.',
    'us_banks' => '400+ US banken',

    'pro_plan_remove_logo' => ':link om het InvoiceNinja logo te verwijderen door het pro plan te nemen',
    'pro_plan_remove_logo_link' => 'Klik hier',
    'invitation_status_sent' => 'Verzonden',
    'invitation_status_opened' => 'Geopend',
    'invitation_status_viewed' => 'Bekenen',
    'email_error_inactive_client' => 'E-mails kunnen niet worden verstuurd naar inactieve klanten',
    'email_error_inactive_contact' => 'E-mails kunnen niet worden verstuurd naar inactieve contactpersonen',
    'email_error_inactive_invoice' => 'E-mails kunnen niet worden verstuurd naar inactieve facturen',
    'email_error_inactive_proposal' => 'Emails kunnen niet verzonden worden naar inactieve voorstellen',
    'email_error_user_unregistered' => 'Registreer een account om e-mails te kunnen versturen',
    'email_error_user_unconfirmed' => 'Bevestig uw account om e-mails te kunnen versturen',
    'email_error_invalid_contact_email' => 'Ongeldig e-mailadres van contactpersoon',

    'navigation' => 'Navigatie',
    'list_invoices' => 'Toon Facturen',
    'list_clients' => 'Toon Klanten',
    'list_quotes' => 'Toon Offertes',
    'list_tasks' => 'Toon Taken',
    'list_expenses' => 'Toon Uitgaven',
    'list_recurring_invoices' => 'Toon Terugkerende Facturen',
    'list_payments' => 'Toon Betalingen',
    'list_credits' => 'Toon Kredieten',
    'tax_name' => 'Belasting naam',
    'report_settings' => 'Rapport instellingen',
    'search_hotkey' => 'Snelkoppeling is /',

    'new_user' => 'Nieuwe Gebruiker',
    'new_product' => 'Nieuw product',
    'new_tax_rate' => 'Nieuw BTW-tarief',
    'invoiced_amount' => 'Gefactureerd bedrag',
    'invoice_item_fields' => 'Factuurregels',
    'custom_invoice_item_fields_help' => 'Voeg een veld toe bij het aanmaken van een factuurregel en toon het label met de waarde op de PDF.',
    'recurring_invoice_number' => 'Terugkerend nummer',
    'recurring_invoice_number_prefix_help' => 'Kies een voorvoegsel voor het factuurnummer van terugkerende facturen.',

    // Client Passwords
    'enable_portal_password' => 'Facturen beveiligen met een wachtwoord',
    'enable_portal_password_help' => 'Geeft u de mogelijkheid om een wachtwoord in te stellen voor elke contactpersoon. Als er een wachtwoord is ingesteld moet de contactpersoon het wachtwoord invoeren voordat deze facturen kan bekijken.',
    'send_portal_password' => 'Automatische generatie',
    'send_portal_password_help' => 'Als er geen wachtwoord is ingesteld zal deze automatisch worden gegenereerd en verzonden bij de eerste factuur.',

    'expired' => 'Verlopen',
    'invalid_card_number' => 'Het creditcardnummer is niet geldig.',
    'invalid_expiry' => 'De verloopdatum is niet geldig.',
    'invalid_cvv' => 'Het CVV-nummer is niet geldig.',
    'cost' => 'Kosten',
    'create_invoice_for_sample' => 'Opmerking: maak uw eerste factuur om hier een voorbeeld te zien.',

    // User Permissions
    'owner' => 'Eigenaar',
    'administrator' => 'Beheerder',
    'administrator_help' => 'Geef gebruiker de toestemming om andere gebruikers te beheren, instellingen te wijzigen en alle regels te bewerken.',
    'user_create_all' => 'Aanmaken van klanten, facturen, enz.',
    'user_view_all' => 'Bekijken van klanten, facturen, enz.',
    'user_edit_all' => 'Bewerken van alle klanten, facturen, enz.',
    'gateway_help_20' => ':link om aan te melden voor Sage Pay.',
    'gateway_help_21' => ':link om aan te melden voor Sage Pay.',
    'partial_due' => 'Te betalen voorschot',
    'restore_vendor' => 'Herstel leverancier',
    'restored_vendor' => 'De leverancier is hersteld',
    'restored_expense' => 'De uitgave is hersteld',
    'permissions' => 'Rechten',
    'create_all_help' => 'Gebruiker toestemming geven om nieuwe regels aan te maken en te bewerken',
    'view_all_help' => 'Gebruiker toestemming geven om regels te bekijken die hij niet heeft gemaakt',
    'edit_all_help' => 'Gebruiker toestemming geven om regels te bewerken die hij niet heeft gemaakt',
    'view_payment' => 'Bekijk betaling',

    'january' => 'januari',
    'february' => 'februari',
    'march' => 'maart',
    'april' => 'april',
    'may' => 'mei',
    'june' => 'juni',
    'july' => 'juli',
    'august' => 'augustus',
    'september' => 'september',
    'october' => 'oktober',
    'november' => 'november',
    'december' => 'december',

    // Documents
    'documents_header' => 'Documenten:',
    'email_documents_header' => 'Documenten:',
    'email_documents_example_1' => 'Widgets Kwitantie.pdf',
    'email_documents_example_2' => 'Definitieve Levering.zip',
    'quote_documents' => 'Offerte documenten',
    'invoice_documents' => 'Factuur documenten',
    'expense_documents' => 'Uitgave documenten',
    'invoice_embed_documents' => 'Documenten invoegen',
    'invoice_embed_documents_help' => 'Bijgevoegde afbeeldingen weergeven in de factuur.',
    'document_email_attachment' => 'Documenten bijvoegen',
    'ubl_email_attachment' => 'Voeg UBL toe',
    'download_documents' => 'Documenten downloaden (:size)',
    'documents_from_expenses' => 'Van uitgaven:',
    'dropzone_default_message' => 'Sleep bestanden hierheen of klik om te uploaden',
    'dropzone_default_message_disabled' => 'Uploads uitgeschakeld',
    'dropzone_fallback_message' => 'Je browser ondersteunt het slepen van bestanden niet.',
    'dropzone_fallback_text' => 'Gebruik de onderstaande optie om je bestanden te uploaden.',
    'dropzone_file_too_big' => 'Het bestand is te groot ({{filesize}}MiB). Maximale grootte: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Je kan geen bestanden van dit type uploaden.',
    'dropzone_response_error' => 'De server gaf foutcode {{statusCode}} terug.',
    'dropzone_cancel_upload' => 'Upload annuleren',
    'dropzone_cancel_upload_confirmation' => 'Weet je zeker dat je deze upload wilt annuleren?',
    'dropzone_remove_file' => 'Bestand verwijderen',
    'documents' => 'Documenten',
    'document_date' => 'Documentdatum',
    'document_size' => 'Grootte',

    'enable_client_portal' => 'Dashboard',
    'enable_client_portal_help' => 'Toon/verberg het klantenportaal.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Toon/verberg de dashboard pagina in het klantenportaal.',

    // Plans
    'account_management' => 'Accountbeheer',
    'plan_status' => 'Status abonnement',

    'plan_upgrade' => 'Upgraden',
    'plan_change' => 'Abonnement wijzigen',
    'pending_change_to' => 'Veranderd naar',
    'plan_changes_to' => ':plan op :date',
    'plan_term_changes_to' => ':plan (:term) op :date',
    'cancel_plan_change' => 'Wijziging annuleren',
    'plan' => 'Abonnement',
    'expires' => 'Verloopt',
    'renews' => 'Verlengt',
    'plan_expired' => ':plan abonnement verlopen',
    'trial_expired' => ':plan proefabonnement afgelopen',
    'never' => 'Nooit',
    'plan_free' => 'Gratis',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Zakelijk',
    'plan_white_label' => 'Zelf gehost (White label)',
    'plan_free_self_hosted' => 'Zelf gehost (Gratis)',
    'plan_trial' => 'Proefabonnement',
    'plan_term' => 'Duur',
    'plan_term_monthly' => 'Maandelijks',
    'plan_term_yearly' => 'Jaarlijks',
    'plan_term_month' => 'Maand',
    'plan_term_year' => 'Jaar',
    'plan_price_monthly' => '$:price/maand',
    'plan_price_yearly' => '$:price/jaar',
    'updated_plan' => 'Bijgewerkte abonnement instellingen',
    'plan_paid' => 'Termijn gestart',
    'plan_started' => 'Abonnement gestart',
    'plan_expires' => 'Abonnement verloopt',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'Jaarabonnement op Invoice Ninja Pro.',
    'pro_plan_month_description' => 'Maandabonnement op Invoice Ninja Pro.',
    'enterprise_plan_product' => 'Zakelijk abonnement',
    'enterprise_plan_year_description' => 'Jaarabonnement op Invoice Ninja zakelijk.',
    'enterprise_plan_month_description' => 'Maandabonnement op Invoice Ninja zakelijk.',
    'plan_credit_product' => 'Krediet',
    'plan_credit_description' => 'Krediet voor ongebruikte tijd',
    'plan_pending_monthly' => 'Zal omgezet wordt in maandelijks op :date',
    'plan_refunded' => 'Een terugbetaling is toegekend.',

    'live_preview' => 'Live Voorbeeld',
    'page_size' => 'Paginagrootte',
    'live_preview_disabled' => 'Live voorbeeld weergave is uitgeschakeld om het geselecteerde lettertype te ondersteunen.',
    'invoice_number_padding' => 'Marge',
    'preview' => 'Voorbeeld',
    'list_vendors' => 'Toon leveranciers',
    'add_users_not_supported' => 'Upgrade naar het zakelijke abonnement om extra gebruikers toe te voegen aan uw account.',
    'enterprise_plan_features' => 'Het zakelijke abonnement voegt ondersteuning toe voor meerdere gebruikers en bijlagen, :link om een volledige lijst van de mogelijkheden te bekijken.',
    'return_to_app' => 'Terug naar de app',


    // Payment updates
    'refund_payment' => 'Terugbetalen',
    'refund_max' => 'Max:',
    'refund' => 'Terugbetaling',
    'are_you_sure_refund' => 'Geselecteerde betalingen terugbetalen?',
    'status_pending' => 'In afwachting',
    'status_completed' => 'Voltooid',
    'status_failed' => 'Mislukt',
    'status_partially_refunded' => 'Deels terugbetaald',
    'status_partially_refunded_amount' => ':amount terugbetaald',
    'status_refunded' => 'Gecrediteerd',
    'status_voided' => 'Geannuleerd',
    'refunded_payment' => 'Gecrediteerde betaling',
    'activity_39' => ':user heeft een a :payment_amount betaling geannuleerd :payment',
    'activity_40' => ':user heeft :adjustment van een :payment_amount betaling :payment',
    'card_expiration' => 'Verloopt:',

    'card_creditcardother' => 'Onbekend',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accepteer US bank transacties',
    'stripe_ach_help' => 'ACH ondersteuning moet ook ingeschakeld zijn in :link.',
    'ach_disabled' => 'Er is al een andere gateway geconfigureerd voor directe afschrijving.',

    'plaid' => 'Plaid',
    'client_id' => 'Klantnummer',
    'secret' => 'Secret',
    'public_key' => 'Public Key',
    'plaid_optional' => '(optioneel)',
    'plaid_environment_help' => 'Wanneer een Stripe-testsleutel wordt gegeven, wordt de ontwikkelomgeving (tartan) van Plaid gebruikt.',
    'other_providers' => 'Andere leveranciers',
    'country_not_supported' => 'Dat land wordt niet ondersteund.',
    'invalid_routing_number' => 'Het banknummer is niet juist.',
    'invalid_account_number' => 'Het rekeningnummer is niet juist.',
    'account_number_mismatch' => 'De rekeningnummers komen niet overeen.',
    'missing_account_holder_type' => 'Kies alstublieft een persoonlijke rekening of een bedrijfsrekening.',
    'missing_account_holder_name' => 'Voer alstublieft de rekeninghouder in.',
    'routing_number' => 'Banknummer',
    'confirm_account_number' => 'Bevestig rekeningnummer',
    'individual_account' => 'Persoonlijke rekening',
    'company_account' => 'Bedrijfsrekening',
    'account_holder_name' => 'Rekeninghouder',
    'add_account' => 'Rekening toevoegen',
    'payment_methods' => 'Betalingsmethode',
    'complete_verification' => 'Verificatie voltooien',
    'verification_amount1' => 'Bedrag 1',
    'verification_amount2' => 'Bedrag 2',
    'payment_method_verified' => 'Verificatie voltooid',
    'verification_failed' => 'Verificatie mislukt',
    'remove_payment_method' => 'Betalingsmethode verwijderen',
    'confirm_remove_payment_method' => 'Weet u zeker dat u deze betalingsmethode wilt verwijderen?',
    'remove' => 'Verwijderen',
    'payment_method_removed' => 'Betalingsmethode verwijderd.',
    'bank_account_verification_help' => 'We hebben twee bedragen met de omschrijving "VERIFICATION" overgeboekt naar uw rekening. Het duurt 1 à 2 werkdagen voordat deze overschrijvingen zichtbaar zijn op uw afschriften. Voer de bedragen hieronder in.',
    'bank_account_verification_next_steps' => 'We hebben twee bedragen met de omschrijving "VERIFICATION" overgeboekt naar uw rekening. Het duurt 1 à 2 werkdagen voordat deze overschrijvingen zichtbaar zijn op uw afschriften.
Kom terug naar deze betalingsmethode pagina zodra u de bedragen heeft ontvangen en klik op "Verificatie voltooien" direct naast de rekening.',
    'unknown_bank' => 'Onbekende bank',
    'ach_verification_delay_help' => 'U kunt de rekening gebruiken na het voltooien van de verificatie. Verificatie duurt doorgaans 1 à 2 werkdagen.',
    'add_credit_card' => 'Creditcard toevoegen',
    'payment_method_added' => 'Betalingsmethode toegevoegd.',
    'use_for_auto_bill' => 'Gebruiken voor Autobill',
    'used_for_auto_bill' => 'Autobill betalingsmethode',
    'payment_method_set_as_default' => 'Autobill betalingsmethode instellen.',
    'activity_41' => 'Betaling van :payment_amount mislukt (:payment)',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'U moet :link.',
    'stripe_webhook_help_link_text' => 'deze URL toevoegen als een endpoint in Stripe',
    'gocardless_webhook_help_link_text' => 'deze URL toevoegen als een endpoint in GoCardless',
    'payment_method_error' => 'Er is een fout opgetreden bij het toevoegen van de betalingsmethode. Probeer het later opnieuw.',
    'notification_invoice_payment_failed_subject' => 'Betaling mislukt voor factuur :invoice',
    'notification_invoice_payment_failed' => 'Een betaling van :client voor factuur :invoice is mislukt. De betaling is gemarkeerd als mislukt en het :amount is toegevoegd aan het krediet van de klant.',
    'link_with_plaid' => 'Rekening direct koppelen met Plaid',
    'link_manually' => 'Handmatig koppelen',
    'secured_by_plaid' => 'Beveiligd met Plaid',
    'plaid_linked_status' => 'Uw bankrekening bij :bank',
    'add_payment_method' => 'Betalingsmethode toevoegen',
    'account_holder_type' => 'Type rekeninghouder',
    'ach_authorization' => 'Ik geef :company toestemming om mijn bankrekening te gebruiken voor toekomstige betalingen en, indien nodig, te crediteren op mijn rekening om foutieve afschrijvingen te corrigeren. I begrijp dat ik deze toestemming te allen tijde mag annuleren door de betalingsmethode te verwijderen of door contact op te nemen via :email.',
    'ach_authorization_required' => 'U moet toestemming geven voor ACH overschrijvingen.',
    'off' => 'Uit',
    'opt_in' => 'Meedoen',
    'opt_out' => 'Terugtrekken',
    'always' => 'Altijd',
    'opted_out' => 'Teruggetrokken',
    'opted_in' => 'Meegedaan',
    'manage_auto_bill' => 'Beheer Autobill',
    'enabled' => 'Ingeschakeld',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'PayPal betalingen via BrainTree inschakelen',
    'braintree_paypal_disabled_help' => 'De PayPal gateway verwerkt PayPal betalingen',
    'braintree_paypal_help' => 'U moet ook :link.',
    'braintree_paypal_help_link_text' => 'PayPal koppelen aan uw BrainTree account',
    'token_billing_braintree_paypal' => 'Betalingsgegevens opslaan',
    'add_paypal_account' => 'PayPal rekening toevoegen',


    'no_payment_method_specified' => 'Geen betalingsmethode gespecificeerd',
    'chart_type' => 'Grafiektype',
    'format' => 'Formaat',
    'import_ofx' => 'OFX importeren',
    'ofx_file' => 'OFX-bestand',
    'ofx_parse_failed' => 'OFX-bestand kon niet worden verwerkt',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Aanmelden met WePay',
    'use_another_provider' => 'Gebruik een andere leverancier',
    'company_name' => 'Bedrijfsnaam',
    'wepay_company_name_help' => 'Dit wordt zichtbaar op de creditcard afschriften van de klant.',
    'wepay_description_help' => 'De reden van deze account.',
    'wepay_tos_agree' => 'Ik ga akkoord met de :link.',
    'wepay_tos_link_text' => 'WePay servicevoorwaarden',
    'resend_confirmation_email' => 'Bevestigings-e-mail opnieuw versturen',
    'manage_account' => 'Account beheren',
    'action_required' => 'Actie vereist',
    'finish_setup' => 'Installatie voltooien',
    'created_wepay_confirmation_required' => 'Controleer uw e-mail en bevestig uw e-mailadres met WePay.',
    'switch_to_wepay' => 'Overschakelen naar WePay',
    'switch' => 'Overschakelen',
    'restore_account_gateway' => 'Herstel gateway',
    'restored_account_gateway' => 'De gateway is hersteld',
    'united_states' => 'Verenigde Staten',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accepteer betaalkaart',
    'debit_cards' => 'Betaalkaarten',

    'warn_start_date_changed' => 'Het volgende factuur zal verzonden worden op de nieuwe startdatum.',
    'warn_start_date_changed_not_sent' => 'Het volgende factuur zal aangemaakt worden op de nieuwe startdatum.',
    'original_start_date' => 'Oorspronkelijke startdatum',
    'new_start_date' => 'Nieuwe startdatum',
    'security' => 'Beveiliging',
    'see_whats_new' => 'Bekijk wat veranderde in v:version',
    'wait_for_upload' => 'Gelieve te wachten tot de upload van het document compleet is.',
    'upgrade_for_permissions' => 'Upgrade naar het zakelijke abonnement om machtigingen in te schakelen.',
    'enable_second_tax_rate' => 'Het opgeven van een <b>tweede extra belastingregel </b> aanzetten',
    'payment_file' => 'Betalingsbestand',
    'expense_file' => 'Uitgavenbestand',
    'product_file' => 'Productbestand',
    'import_products' => 'Producten importeren',
    'products_will_create' => 'producten zullen aangemaakt worden',
    'product_key' => 'Product',
    'created_products' => 'Succesvol :count product(en) aangemaakt/bijgewerkt',
    'export_help' => 'Gebruik JSON als u van plan bent om de gegevens te importeren in Invoice Ninja.<br/>Het bestand omvat klanten, producten, facturen, offertes en betalingen.',
    'selfhost_export_help' => '<br/>We raden mysqldump aan om een volledige backup te maken.',
    'JSON_file' => 'JSON bestand',

    'view_dashboard' => 'Bekijk dashboard',
    'client_session_expired' => 'Sessie verlopen',
    'client_session_expired_message' => 'Uw sessie is verlopen. Gelieve de link in de e-mail opnieuw te openen.',

    'auto_bill_notification' => 'Deze factuur zal automatisch worden gefactureerd aan uw opgeslagen betalingsmethode op de vervaldag.',
    'auto_bill_payment_method_bank_transfer' => 'Bankrekening',
    'auto_bill_payment_method_credit_card' => 'creditcard',
    'auto_bill_payment_method_paypal' => 'PayPal account',
    'auto_bill_notification_placeholder' => 'Deze factuur zal automatisch worden gefactureerd aan uw creditcard op de vervaldag.',
    'payment_settings' => 'Betalingsinstellingen',

    'on_send_date' => 'Op verzendingsdatum',
    'on_due_date' => 'Op vervaldatum',
    'auto_bill_ach_date_help' => 'ACH automatische facturatie zal atijd uitgevoerd worden op de vervaldag',
    'warn_change_auto_bill' => 'Vanwege NACHA regels kunnen aanpassingen aan dit factuur ACH automatische facturatie voorkomen.',

    'bank_account' => 'Bankrekening',
    'payment_processed_through_wepay' => 'ACH betalingen zullen verwerkt worden met WePay.',
    'wepay_payment_tos_agree' => 'Ik ga akkoord met de WePay :terms en :privacy_policy.',
    'privacy_policy' => 'Privacybeleid',
    'wepay_payment_tos_agree_required' => 'U moet akkoord gaan met de WePay voorwaarden en privacybeleid.',
    'ach_email_prompt' => 'Gelieve uw e-maildres in te vullen:',
    'verification_pending' => 'Verificatie in afwachting',

    'update_font_cache' => 'Forceer het vernieuwen van de pagina om de font cache bij te werken.',
    'more_options' => 'Meer opties',
    'credit_card' => 'Creditcard',
    'bank_transfer' => 'Overschrijving',
    'no_transaction_reference' => 'We ontvingen geen betalingstransactie referentie van de gateway.',
    'use_bank_on_file' => 'Gebruik opgeslagen bank',
    'auto_bill_email_message' => 'Deze factuur zal automatisch worden gefactureerd aan uw opgeslagen betalingsmethode op de vervaldag.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Toegevoegd op :date',
    'failed_remove_payment_method' => 'Verwijderen van betalingsmethode mislukt',
    'gateway_exists' => 'Deze gateway bestaat reeds',
    'manual_entry' => 'Manuele invoer',
    'start_of_week' => 'Eerste dag van de week',

    // Frequencies
    'freq_inactive' => 'Inactief',
    'freq_daily' => 'Dagelijks',
    'freq_weekly' => 'Wekelijks',
    'freq_biweekly' => 'Tweewekelijks',
    'freq_two_weeks' => 'Twee weken',
    'freq_four_weeks' => 'Vier weken',
    'freq_monthly' => 'Maandelijks',
    'freq_three_months' => 'Drie maanden',
    'freq_four_months' => 'Vier maanden',
    'freq_six_months' => 'Zes maanden',
    'freq_annually' => 'Jaarlijks',
    'freq_two_years' => 'Twee jaar',

    // Payment types
    'payment_type_Apply Credit' => 'Krediet toepassen',
    'payment_type_Bank Transfer' => 'Overschrijving',
    'payment_type_Cash' => 'Contant',
    'payment_type_Debit' => 'Debet',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visakaart',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Andere creditcard',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Cheque',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Automatisch incasso',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Boekhouding & juridisch',
    'industry_Advertising' => 'Adverteren',
    'industry_Aerospace' => 'Ruimtevaart',
    'industry_Agriculture' => 'Landbouw',
    'industry_Automotive' => 'Automobiel',
    'industry_Banking & Finance' => 'Bank & financiën',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Omroep',
    'industry_Business Services' => 'Zakelijke diensten',
    'industry_Commodities & Chemicals' => 'Koopwaar & chemicaliën',
    'industry_Communications' => 'Communicatie',
    'industry_Computers & Hightech' => 'Computers & hoogtechnologisch',
    'industry_Defense' => 'Defensie',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Overheid',
    'industry_Healthcare & Life Sciences' => 'Gezondheid & levenswetenschappen',
    'industry_Insurance' => 'Verzekering',
    'industry_Manufacturing' => 'Fabricage',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Non-profit & hoger onderwijs',
    'industry_Pharmaceuticals' => 'Farmaceutisch',
    'industry_Professional Services & Consulting' => 'Professionele diensten & raadgeving',
    'industry_Real Estate' => 'Onroerend goed',
    'industry_Restaurant & Catering' => 'Restaurant & Catering',
    'industry_Retail & Wholesale' => 'Klein- & groothandel',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Vervoer',
    'industry_Travel & Luxury' => 'Reizen & luxe',
    'industry_Other' => 'Andere',
    'industry_Photography' => 'Fotografie',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albanië',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algerije',
    'country_American Samoa' => 'Amerikaans-Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua en Barbuda',
    'country_Azerbaijan' => 'Azerbeidzjan',
    'country_Argentina' => 'Argentinië',
    'country_Australia' => 'Australië',
    'country_Austria' => 'Oostenrijk',
    'country_Bahamas' => 'Bahama\'s',
    'country_Bahrain' => 'Bahrein',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenië',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'België',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia',
    'country_Bosnia and Herzegovina' => 'Bosnië en Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouveteiland',
    'country_Brazil' => 'Brazilië',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'Brits Indische Oceaanterritorium',
    'country_Solomon Islands' => 'Salomonseilanden',
    'country_Virgin Islands, British' => 'Britse Maagdeneilanden',
    'country_Brunei Darussalam' => 'Brunei',
    'country_Bulgaria' => 'Bulgarije',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Wit-Rusland',
    'country_Cambodia' => 'Cambodja',
    'country_Cameroon' => 'Kameroen',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Kaapverdië',
    'country_Cayman Islands' => 'Kaaimaneilanden',
    'country_Central African Republic' => 'Centraal-Afrikaanse Republiek',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Tsjaad',
    'country_Chile' => 'Chili',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan',
    'country_Christmas Island' => 'Christmaseiland',
    'country_Cocos (Keeling) Islands' => 'Cocoseilanden',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoren',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo-Kinshasa',
    'country_Congo, the Democratic Republic of the' => 'Congo',
    'country_Cook Islands' => 'Cookeilanden',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Kroatië',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Tsjechië',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denemarken',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominicaanse Republiek',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatoriaal-Guinea',
    'country_Ethiopia' => 'Ethiopië',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estland',
    'country_Faroe Islands' => 'Faeröer',
    'country_Falkland Islands (Malvinas)' => 'Falklandeilanden',
    'country_South Georgia and the South Sandwich Islands' => 'Zuid-Georgia en de Zuidelijke Sandwicheilanden',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland',
    'country_France' => 'Frankrijk',
    'country_French Guiana' => 'Frans-Guyana',
    'country_French Polynesia' => 'Frans-Polynesië',
    'country_French Southern Territories' => 'Franse Zuidelijke en Antarctische Gebieden',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgië',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Westelijke Jordaanoever',
    'country_Germany' => 'Duitsland',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Griekenland',
    'country_Greenland' => 'Groenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinee',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haïti',
    'country_Heard Island and McDonald Islands' => 'Heard en McDonaldeilanden',
    'country_Holy See (Vatican City State)' => 'Heilige Stoel',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hongkong',
    'country_Hungary' => 'Hongarije',
    'country_Iceland' => 'IJsland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesië',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Ierland',
    'country_Israel' => 'Israël',
    'country_Italy' => 'Italië',
    'country_Côte d\'Ivoire' => 'Ivoorkust',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazachstan',
    'country_Jordan' => 'Jordanië',
    'country_Kenya' => 'Kenia',
    'country_Korea, Democratic People\'s Republic of' => 'Noord-Korea',
    'country_Korea, Republic of' => 'Zuid-Korea',
    'country_Kuwait' => 'Koeweit',
    'country_Kyrgyzstan' => 'Kirgizië',
    'country_Lao People\'s Democratic Republic' => 'Laos',
    'country_Lebanon' => 'Libanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Letland',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libië',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Litouwen',
    'country_Luxembourg' => 'Luxemburg',
    'country_Macao' => 'Macau',
    'country_Madagascar' => 'Madagaskar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Maleisië',
    'country_Maldives' => 'Maldiven',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritanië',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolië',
    'country_Moldova, Republic of' => 'Moldavië',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Marokko',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibië',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Nederland',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten',
    'country_Bonaire, Sint Eustatius and Saba' => 'Caribisch Nederland',
    'country_New Caledonia' => 'Nieuw-Caledonië',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nieuw-Zeeland',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Nigeria',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk',
    'country_Norway' => 'Noorwegen',
    'country_Northern Mariana Islands' => 'Noordelijke Marianen',
    'country_United States Minor Outlying Islands' => 'Kleine afgelegen eilanden van de Verenigde Staten',
    'country_Micronesia, Federated States of' => 'Micronesia',
    'country_Marshall Islands' => 'Marshalleilanden',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papoea-Nieuw-Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Filipijnen',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polen',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinee-Bissau',
    'country_Timor-Leste' => 'Oost-Timor',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Roemenië',
    'country_Russian Federation' => 'Rusland',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint-Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Sint-Helena, Ascension en Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts en Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin',
    'country_Saint Pierre and Miquelon' => 'Saint-Pierre en Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent en de Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tomé en Principe',
    'country_Saudi Arabia' => 'Saoedi-Arabië',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Servië',
    'country_Seychelles' => 'Seychellen',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slowakije',
    'country_Viet Nam' => 'Vietnam',
    'country_Slovenia' => 'Slovenië',
    'country_Somalia' => 'Somalië',
    'country_South Africa' => 'Zuid-Afrika',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spanje',
    'country_South Sudan' => 'Zuid-Soedan',
    'country_Sudan' => 'Soedan',
    'country_Western Sahara' => 'Westelijke Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Spitsbergen en Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Zweden',
    'country_Switzerland' => 'Zwitserland',
    'country_Syrian Arab Republic' => 'Syrië',
    'country_Tajikistan' => 'Tadzjikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad en Tobago',
    'country_United Arab Emirates' => 'Verenigde Arabische Emiraten',
    'country_Tunisia' => 'Tunesië',
    'country_Turkey' => 'Turkije',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks- en Caicoseilanden',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Oeganda',
    'country_Ukraine' => 'Oekraïne',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonië',
    'country_Egypt' => 'Egypte',
    'country_United Kingdom' => 'Verenigd Koninkrijk',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Man',
    'country_Tanzania, United Republic of' => 'Tanzania',
    'country_United States' => 'Verenigde Staten',
    'country_Virgin Islands, U.S.' => 'Amerikaanse Maagdeneilanden',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Oezbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela',
    'country_Wallis and Futuna' => 'Wallis en Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Jemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Braziliaans Portugees',
    'lang_Croatian' => 'Kroatië',
    'lang_Czech' => 'Tsjechië',
    'lang_Danish' => 'Deens',
    'lang_Dutch' => 'Nederlands',
    'lang_English' => 'Engels',
    'lang_French' => 'Frans',
    'lang_French - Canada' => 'Frans - Canada',
    'lang_German' => 'Duits',
    'lang_Italian' => 'Italiaans',
    'lang_Japanese' => 'Japans',
    'lang_Lithuanian' => 'Litouws',
    'lang_Norwegian' => 'Noors',
    'lang_Polish' => 'Pools
',
    'lang_Spanish' => 'Spaans',
    'lang_Spanish - Spain' => 'Spaans - Spanje',
    'lang_Swedish' => 'Zweeds',
    'lang_Albanian' => 'Albanees',
    'lang_Greek' => 'Grieks',
    'lang_English - United Kingdom' => 'Engels - Verenigd Koninkrijk',
    'lang_English - Australia' => 'Australië',
    'lang_Slovenian' => 'Sloveens',
    'lang_Finnish' => 'Fins',
    'lang_Romanian' => 'Roemeens',
    'lang_Turkish - Turkey' => 'Turks - Turkije',
    'lang_Portuguese - Brazilian' => 'Portugees - Braziliaans',
    'lang_Portuguese - Portugal' => 'Portugees - Portugal',
    'lang_Thai' => 'Thais',
    'lang_Macedonian' => 'Macedonisch',
    'lang_Chinese - Taiwan' => 'Chinees - Taiwan',
    'lang_Serbian' => 'Servisch',
    'lang_Bulgarian' => 'Bulgaars',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Boekhouding & juridisch',
    'industry_Advertising' => 'Adverteren',
    'industry_Aerospace' => 'Ruimtevaart',
    'industry_Agriculture' => 'Landbouw',
    'industry_Automotive' => 'Automobiel',
    'industry_Banking & Finance' => 'Bank & financiën',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Omroep',
    'industry_Business Services' => 'Zakelijke diensten',
    'industry_Commodities & Chemicals' => 'Koopwaar & chemicaliën',
    'industry_Communications' => 'Communicatie',
    'industry_Computers & Hightech' => 'Computers & hoogtechnologisch',
    'industry_Defense' => 'Defensie',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Overheid',
    'industry_Healthcare & Life Sciences' => 'Gezondheid & levenswetenschappen',
    'industry_Insurance' => 'Verzekering',
    'industry_Manufacturing' => 'Fabricage',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Non-profit & hoger onderwijs',
    'industry_Pharmaceuticals' => 'Farmaceutisch',
    'industry_Professional Services & Consulting' => 'Professionele diensten & raadgeving',
    'industry_Real Estate' => 'Onroerend goed',
    'industry_Retail & Wholesale' => 'Klein- & groothandel',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Vervoer',
    'industry_Travel & Luxury' => 'Reizen & luxe',
    'industry_Other' => 'Andere',
    'industry_Photography' => 'Fotografie',

    'view_client_portal' => 'Toon klantportaal',
    'view_portal' => 'Toon portaal',
    'vendor_contacts' => 'Leveranciercontacten',
    'all' => 'Alles',
    'selected' => 'Geselecteerd',
    'category' => 'Categorie',
    'categories' => 'Categorieën',
    'new_expense_category' => 'Nieuwe uitgavecategorie',
    'edit_category' => 'Wijzig categorie',
    'archive_expense_category' => 'Archiveer categorie',
    'expense_categories' => 'Uitgavecategorie',
    'list_expense_categories' => 'Toon uitgavecategorieën',
    'updated_expense_category' => 'De uitgaven categorie is gewijzigd',
    'created_expense_category' => 'De uitgaven categorie is aangemaakt',
    'archived_expense_category' => 'De uitgaven categorie is gearchiveerd',
    'archived_expense_categories' => ':count uitgave-categorieën gearchiveerd',
    'restore_expense_category' => 'Herstel uitgavecategorie',
    'restored_expense_category' => 'De uitgaven categorie hersteld',
    'apply_taxes' => 'Pas belasting toe',
    'min_to_max_users' => ':min tot :max gebruikers',
    'max_users_reached' => 'Het maximale aantal gebruikers is bereikt.',
    'buy_now_buttons' => 'Koop nu knoppen',
    'landing_page' => 'Landingspagina',
    'payment_type' => 'Betalingswijze',
    'form' => 'Formulier',
    'link' => 'Link',
    'fields' => 'Velden',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Opmerking: de klant en factuur worden aangemaakt ook al is de transactie niet afgerond.',
    'buy_now_buttons_disabled' => 'Deze functie vereist dat een product is aangemaakt en een betalingsgateway is geconfigureerd.',
    'enable_buy_now_buttons_help' => 'Ondersteuning inschakelen voor koop nu knoppen',
    'changes_take_effect_immediately' => 'Opmerking: wijzigingen zijn onmiddelijk van kracht',
    'wepay_account_description' => 'Betalingsgateway voor Invoice Ninja',
    'payment_error_code' => 'Er trad een fout op tijdens het verwerken van uw betaling [:code]. Gelieve het later opnieuw te proberen.',
    'standard_fees_apply' => 'Toeslag: 2.9%/1.2% [kredietkaart/overschijving] + $0.30 per succesvolle aanrekening.',
    'limit_import_rows' => 'Data dient geïmporteerd te worden in delen van :count rijen of minder',
    'error_title' => 'Er ging iets mis',
    'error_contact_text' => 'Indien u hulp wenst gelieve ons te contacteren op :mailaddress',
    'no_undo' => 'Waarschuwing: dit kan niet ongedaan gemaakt worden.',
    'no_contact_selected' => 'Gelieve een contact te selecteren',
    'no_client_selected' => 'Gelieve een klant te selecteren',

    'gateway_config_error' => 'Het kan helpen om nieuwe wachtwoorden in te stellen of nieuwe API sleutels te genereren.',
    'payment_type_on_file' => ':type opgeslagen',
    'invoice_for_client' => 'Factuur :invoice voor :client',
    'intent_not_found' => 'Sorry, ik weet niet goed wat u vraagt.',
    'intent_not_supported' => 'Sorry, ik ben niet in staat om dat te doen.',
    'client_not_found' => 'Ik was niet in staat om de klant te vinden',
    'not_allowed' => 'Sorry, u heeft niet de benodigde machtigingen',
    'bot_emailed_invoice' => 'Uw factuur is verzonden.',
    'bot_emailed_notify_viewed' => 'Ik e-mail u als het bekeken is.',
    'bot_emailed_notify_paid' => 'Ik e-mail u als het betaald is.',
    'add_product_to_invoice' => 'Voeg 1 :product toe',
    'not_authorized' => 'U bent niet gemachtigd',
    'bot_get_email' => 'Hallo! (wave)<br/>Bedankt om de Invoice Ninja Bot uit te proberen.<br/>Je moet een gratis account aanmaken om de bot te kunnen gebruiken.<br/>Stuur me uw e-mailadres om van start te gaan.',
    'bot_get_code' => 'Bedankt! Ik heb u een e-mail gestuurd met uw beveiligingscode.',
    'bot_welcome' => 'Dat was het, uw account is geverifieerd.<br/>',
    'email_not_found' => 'Ik was niet in staat om een beschikbaar account te vinden voor :email',
    'invalid_code' => 'De code is niet correct',
    'security_code_email_subject' => 'Beveiligingscode voor Invoice Ninja Bot',
    'security_code_email_line1' => 'Dit is uw Invoice Ninja Bot beveiligingscode.',
    'security_code_email_line2' => 'Opmerking: deze zal over 10 minuten vervallen.',
    'bot_help_message' => 'Momenteel ondersteun ik:<br/>• Aanmaken\bewerken\emailen van facturene<br/>• Producten tonen<br/>Bijvoorbeeld:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'Toon producten',

    'include_item_taxes_inline' => 'Gebruik <b>de belasting per regel in het lijntotaal</b>',
    'created_quotes' => 'Succesvol :count offerte(s) aangemaakt',
    'limited_gateways' => 'Opmerking: we ondersteunen één creditcard gateway per bedrijf.',

    'warning' => 'Waarschuwing',
    'self-update' => 'Update',
    'update_invoiceninja_title' => 'Invoice Ninja bijwerken',
    'update_invoiceninja_warning' => 'Maak een backup van de database en bestanden vóór het upgraden van Invoice Ninja!',
    'update_invoiceninja_available' => 'Een nieuwe versie van Invoice Ninja is beschikbaar.',
    'update_invoiceninja_unavailable' => 'Er is geen nieuwe versie van Invoice Ninja beschikbaar.',
    'update_invoiceninja_instructions' => 'Gelieve de nieuwe versie <strong>:version</strong> te installeren door op onderstaande <em>Nu updaten</em> knop te klikken. Nadien wordt u doorgestuurd naar het dashboard.',
    'update_invoiceninja_update_start' => 'Nu bijwerken',
    'update_invoiceninja_download_start' => 'Download :version',
    'create_new' => 'Nieuwe aanmaken',

    'toggle_navigation' => 'Toon/verberg navigatie',
    'toggle_history' => 'Toon/verberg geschiedenis',
    'unassigned' => 'Niet toegewezen',
    'task' => 'Taak',
    'contact_name' => 'Contactnaam',
    'city_state_postal' => 'Postcode',
    'custom_field' => 'Aangepast veld',
    'account_fields' => 'Velden bedrijf',
    'facebook_and_twitter' => 'Facebook en Twitter',
    'facebook_and_twitter_help' => 'Volg onze feeds om ons te helpen met het project',
    'reseller_text' => 'Opmerking: de white-label licentie is bedoeld voor persoonlijk gebruik, gelieve ons te contacteren op :email indien u de app door wilt verkopen.',
    'unnamed_client' => 'Onbenoemde klant',

    'day' => 'Dag',
    'week' => 'Week',
    'month' => 'Maand',
    'inactive_logout' => 'U bent uitgelogd vanwege inactiviteit',
    'reports' => 'Rapporten',
    'total_profit' => 'Totale winst',
    'total_expenses' => 'Totale uitgaven',
    'quote_to' => 'Offerte aan',

    // Limits
    'limit' => 'Limiet',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Geen limieten',
    'set_limits' => 'Stel :gateway_type limieten in',
    'enable_min' => 'Min inschakelen',
    'enable_max' => 'Max inschakelen',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Dit factuur voldoet niet aan de limieten voor die betalingsmethode.',

    'date_range' => 'Datumbereik',
    'raw' => 'Onbewerkt',
    'raw_html' => 'Onbewerkte HTML',
    'update' => 'Update',
    'invoice_fields_help' => 'Versleep de velden om de volgorde en de locatie te wijzigen',
    'new_category' => 'Nieuwe categorie',
    'restore_product' => 'Herstel product',
    'blank' => 'Blanco',
    'invoice_save_error' => 'Er was een fout bij het opslaan van uw factuur',
    'enable_recurring' => 'Terugkerend inschakelen',
    'disable_recurring' => 'Terugkerend uitschakelen',
    'text' => 'Tekst',
    'expense_will_create' => 'uitgave zal aangemaakt worden',
    'expenses_will_create' => 'uitgaven zullen aangemaakt worden',
    'created_expenses' => 'Succesvol :count uitgave(n) aangemaakt',

    'translate_app' => 'Help onze vertalingen te verbeteren met :link',
    'expense_category' => 'Uitgavecategorie',

    'go_ninja_pro' => 'Ga Ninja Pro!',
    'go_enterprise' => 'Ga zakelijk!',
    'upgrade_for_features' => 'Upgrade voor meer mogelijkheden',
    'pay_annually_discount' => 'Betaal jaarlijks voor 10 maanden en krijg er 2 gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'UwMerk.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Pas elk aspect van uw factuur aan!',
    'enterprise_upgrade_feature1' => 'Stel machtigingen in voor meerdere gebruikers',
    'enterprise_upgrade_feature2' => 'Voeg externe documenten toe aan facturen & uitgaven',
    'much_more' => 'Veel meer!',
    'all_pro_fetaures' => 'Plus alle pro functies!',

    'currency_symbol' => 'Symbool',
    'currency_code' => 'Code',

    'buy_license' => 'Koop licentie',
    'apply_license' => 'Activeer licentie',
    'submit' => 'Opslaan',
    'white_label_license_key' => 'Licentiesleutel',
    'invalid_white_label_license' => 'De whitelabel-licentie is niet geldig',
    'created_by' => 'Aangemaakt door :name',
    'modules' => 'Modules',
    'financial_year_start' => 'Eerste maand van het jaar',
    'authentication' => 'Authenticatie',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Handtekening',
    'show_accept_invoice_terms' => 'Factuurvoorwaarden checkbox',
    'show_accept_invoice_terms_help' => 'Verplicht de klant om akkoord te gaan met de factuurvoorwaarden.',
    'show_accept_quote_terms' => 'Offertevoorwaarden checkbox',
    'show_accept_quote_terms_help' => 'Verplicht de klant om akkoord te gaan met de offertevoorwaarden.',
    'require_invoice_signature' => 'Factuur handtekening',
    'require_invoice_signature_help' => 'Verplicht de klant om zijn handtekening te zetten.',
    'require_quote_signature' => 'Offerte handtekening',
    'require_quote_signature_help' => 'Verplicht de klant zijn handtekening te zetten.',
    'i_agree' => 'Ik ga akkoord met de voorwaarden',
    'sign_here' => 'Gelieve hier te tekenen:',
    'authorization' => 'Autorisatie',
    'signed' => 'Getekend',

    // BlueVine
    'bluevine_promo' => 'Krijg flexibele zakelijke kredietlijnen en factuur factoring met BlueVine.',
    'bluevine_modal_label' => 'Aanmelden met BlueVine',
    'bluevine_modal_text' => '<h3>Snelle financiering voor uw bedrijf. Geen papierwerk.</h3>
<ul><i>Flexibele zakelijke kredietlijnen en factuur factoring.</li></ul>',
    'bluevine_create_account' => 'Account aanmaken',
    'quote_types' => 'Ontvang een offerte voor',
    'invoice_factoring' => 'Factuur factoring',
    'line_of_credit' => 'Kredietlijn',
    'fico_score' => 'Uw FICO score',
    'business_inception' => 'Zakelijke startdatum',
    'average_bank_balance' => 'Gemiddelde balans bankrekening',
    'annual_revenue' => 'Jaarlijkse inkomsten',
    'desired_credit_limit_factoring' => 'Gewenste factuur factoring limiet',
    'desired_credit_limit_loc' => 'Gewenste kredietlijn limiet',
    'desired_credit_limit' => 'Gewenste krediet limiet',
    'bluevine_credit_line_type_required' => 'Gelieve er minstens één te selecteren',
    'bluevine_field_required' => 'Dit veld is vereist',
    'bluevine_unexpected_error' => 'Er is een onverwachte fout opgetreden.',
    'bluevine_no_conditional_offer' => 'Er is meer informatie nodig om een offerte te verkrijgen. Klik op verdergaan hieronder.',
    'bluevine_invoice_factoring' => 'Factuur factoring',
    'bluevine_conditional_offer' => 'Voorwaardelijk aanbod',
    'bluevine_credit_line_amount' => 'Kredietlijn',
    'bluevine_advance_rate' => 'Voorschot tarief',
    'bluevine_weekly_discount_rate' => 'Wekelijks kortingspercentage',
    'bluevine_minimum_fee_rate' => 'Minimale kosten',
    'bluevine_line_of_credit' => 'Kredietlijn',
    'bluevine_interest_rate' => 'Rente',
    'bluevine_weekly_draw_rate' => 'Wekelijks treksnelheid',
    'bluevine_continue' => 'Ga verder naar BlueVine',
    'bluevine_completed' => 'BlueVine aanmelding voltooid',

    'vendor_name' => 'Leverancier',
    'entity_state' => 'Staat',
    'client_created_at' => 'Aanmaakdatum',
    'postmark_error' => 'Er was een probleem met het versturen van de e-mail via Postmark :link',
    'project' => 'Project',
    'projects' => 'Projecten',
    'new_project' => 'Nieuw project',
    'edit_project' => 'Wijzig project',
    'archive_project' => 'Archiveer project',
    'list_projects' => 'Toon Projecten',
    'updated_project' => 'Het project is gewijzigd',
    'created_project' => 'Het project is aangemaakt',
    'archived_project' => 'Het project is gearchiveerd',
    'archived_projects' => 'Succesvol :count projecten gearchiveerd',
    'restore_project' => 'Herstel project',
    'restored_project' => 'Het project is hersteld',
    'delete_project' => 'Verwijder project',
    'deleted_project' => 'Het project is verwijderd',
    'deleted_projects' => 'Succesvol :count projecten verwijderd',
    'delete_expense_category' => 'Verwijderen categorie',
    'deleted_expense_category' => 'De categorie is verwijderd',
    'delete_product' => 'Verwijder product',
    'deleted_product' => 'Het product is verwijderd',
    'deleted_products' => 'Succesvol :count producten verwijderd',
    'restored_product' => 'Het product is hersteld',
    'update_credit' => 'Krediet bijwerken',
    'updated_credit' => 'Het krediet is gewijzigd',
    'edit_credit' => 'Wijzig krediet',
    'realtime_preview' => 'Realtime Voorbeeld',
    'realtime_preview_help' => 'Toon een realtime PDF voorbeeld op de factuur pagina bij het bewerken van facturen.<br/>Schakel dit uit om de prestaties te verbeteren tijdens het bewerken van facturen.',
    'live_preview_help' => 'Toon een live PDF voorbeeld op de factuur pagina.',
    'force_pdfjs_help' => 'Vervang de ingebouwde PDF viewer in :chrome_link en :firefox_link.<br/>Schakel dit in als je browser de PDF automatisch download.',
    'force_pdfjs' => 'Download voorkomen',
    'redirect_url' => 'Redirect URL',
    'redirect_url_help' => 'Optioneel kan een URL opgegeven worden om naar door te verwijzen nadat een betaling is ingevoerd.',
    'save_draft' => 'Concept opslaan',
    'refunded_credit_payment' => 'Gecrediteerde krediet betaling',
    'keyboard_shortcuts' => 'Toetsenbord sneltoetsen',
    'toggle_menu' => 'Toggle menu',
    'new_...' => 'Nieuw...',
    'list_...' => 'Lijst...',
    'created_at' => 'Aanmaakdatum',
    'contact_us' => 'Contacteer ons',
    'user_guide' => 'Gebruikershandleiding',
    'promo_message' => 'Upgrade voor :expires en krijg :amount korting op je eerste jaar met onze Pro en Enterprise pakketten.',
    'discount_message' => ':amount korting vervalt :expires',
    'mark_paid' => 'Markeer als betaald',
    'marked_sent_invoice' => 'De factuur is gemarkeerd als verzonden',
    'marked_sent_invoices' => 'De facturen zijn gemarkeerd als verzonden',
    'invoice_name' => 'Factuur',
    'product_will_create' => 'product zal worden aangemaakt',
    'contact_us_response' => 'Bedankt voor uw bericht! We proberen om zo snel mogelijk te reageren.',
    'last_7_days' => 'Laatste 7 dagen',
    'last_30_days' => 'Laatste 30 dagen',
    'this_month' => 'Deze maand',
    'last_month' => 'Vorige maand',
    'current_quarter' => 'Huidig Kwartaal',
    'last_quarter' => 'Laatste Kwartaal',
    'last_year' => 'Vorig jaar',
    'custom_range' => 'Aangepast bereik',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Vereis',
    'license_expiring' => 'Opmerking: uw licentie zal vervallen in :count dagen, :link om het te verlengen.',
    'security_confirmation' => 'Uw e-mailadres is bevestigd.',
    'white_label_expired' => 'Uw white label licentie is verlopen, gelieve te overwegen om dit te vernieuwen om zo ons project mee te helpen ondersteunen.',
    'renew_license' => 'Licentie vernieuwen',
    'iphone_app_message' => 'Overweeg onze :link te downloaden',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Aangemeld',
    'switch_to_primary' => 'Schakel over naar uw primair bedrijf (:name) om uw abonnement te beheren.',
    'inclusive' => 'Inclusief',
    'exclusive' => 'Exclusief',
    'postal_city_state' => 'Provincie',
    'phantomjs_help' => 'In sommige gevallen gebruikt de app :link_phantom om het PDF-bestand te genereren, installeer :link_docs om het lokaal te genereren.',
    'phantomjs_local' => 'Lokaal PhantomJS gebruiken',
    'client_number' => 'Klantnummer',
    'client_number_help' => 'Geef een voorvoegsel of een aangepast patroon om klantnummers dynamisch te genereren.',
    'next_client_number' => 'Het volgende klantnummer is :number.',
    'generated_numbers' => 'Gegenereerde nummers',
    'notes_reminder1' => 'Eerste herinnering',
    'notes_reminder2' => 'Tweede herinnering',
    'notes_reminder3' => 'Derde herinnering',
    'notes_reminder4' => 'Herinnering',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'BTW offerte',
    'tax_invoice' => 'BTW factuur',
    'emailed_invoices' => 'De facturen zijn gemaild',
    'emailed_quotes' => 'De offertes zijn gemaild',
    'website_url' => 'Website URL',
    'domain' => 'Domein',
    'domain_help' => 'Wordt gebruikt in het klantenportaal en bij het versturen van e-mails.',
    'domain_help_website' => 'Wordt gebruikt bij het versturen van e-mails.',
    'import_invoices' => 'Facturen importeren',
    'new_report' => 'Nieuw rapport',
    'edit_report' => 'Wijzig rapport',
    'columns' => 'Kolommen',
    'filters' => 'Filters',
    'sort_by' => 'Sorteren op',
    'draft' => 'Concept',
    'unpaid' => 'Onbetaald',
    'aging' => 'Toekomst',
    'age' => 'Leeftijd',
    'days' => 'Dagen',
    'age_group_0' => '0 - 30 dagen',
    'age_group_30' => '30 - 60 dagen',
    'age_group_60' => '60 - 90 dagen',
    'age_group_90' => '90 - 120 dagen',
    'age_group_120' => '120+ dagen',
    'invoice_details' => 'Factuur details',
    'qty' => 'Hoeveelheid',
    'profit_and_loss' => 'Winst en verlies',
    'revenue' => 'Inkomsten',
    'profit' => 'Winst',
    'group_when_sorted' => 'Sorteer op groep',
    'group_dates_by' => 'Datums groeperen op',
    'year' => 'Jaar',
    'view_statement' => 'Toon overzicht',
    'statement' => 'Overzicht',
    'statement_date' => 'Overzicht datum',
    'mark_active' => 'Markeer als actief',
    'send_automatically' => 'Automatisch versturen',
    'initial_email' => 'Initiële e-mail',
    'invoice_not_emailed' => 'Dit factuur is niet gemaild.',
    'quote_not_emailed' => 'Deze offerte is niet gemaild.',
    'sent_by' => 'Verzonden door :user',
    'recipients' => 'Ontvangers',
    'save_as_default' => 'Bewaar als standaard',
    'start_of_week_help' => 'Gebruikt door <b>datum</b> selecties',
    'financial_year_start_help' => 'Gebruikt door <b>datumbereik</b> selecties',
    'reports_help' => 'Shift + klik om op meerdere kolommen te sorteren, Ctrl + klik om de groepering te wissen.',
    'this_year' => 'Dit jaar',

    // Updated login screen
    'ninja_tagline' => 'Creëren. Sturen. Betaald worden.',
    'login_or_existing' => 'Of log in met een verbonden account.',
    'sign_up_now' => 'Meld nu aan',
    'not_a_member_yet' => 'Nog geen lid?',
    'login_create_an_account' => 'Maak een account aan!',

    // New Client Portal styling
    'invoice_from' => 'Facturen van:',
    'email_alias_message' => 'Let op: het is vereist dat iedere gebruiker een uniek e-mailadres gebruikt.<br/>Overweeg een alias te gebruiken, bv. email+label@example.com',
    'full_name' => 'Volledige naam',
    'month_year' => 'Maand/jaar',
    'valid_thru' => 'Geldig tot',

    'product_fields' => 'Productvelden',
    'custom_product_fields_help' => 'Voeg een tekstveld toe bij het creëren van een product of factuur en toon het gekozen label op de PDF.',
    'freq_two_months' => 'Twee maanden',
    'freq_yearly' => 'Jaarlijks',
    'profile' => 'Profiel',
    'payment_type_help' => 'Stel de standaard <b>manuele betalingsmethode</b> in.',
    'industry_Construction' => 'Bouw',
    'your_statement' => 'Uw overzicht',
    'statement_issued_to' => 'Overzicht uitgeschreven aan',
    'statement_to' => 'Overschift voor',
    'customize_options' => 'Opties aanpassen',
    'created_payment_term' => 'De betalingstermijn is aangemaakt',
    'updated_payment_term' => 'De betalingstermijn is gewijzigd',
    'archived_payment_term' => 'De betalingstermijn is gearchiveerd',
    'resend_invite' => 'Uitnodiging opnieuw versturen',
    'credit_created_by' => 'Krediet aangemaakt door betaling :transaction_reference',
    'created_payment_and_credit' => 'De betaling en het krediet zijn aangemaakt',
    'created_payment_and_credit_emailed_client' => 'De betaling en het krediet zijn aangemaakt en verstuurd naar de klant',
    'create_project' => 'Project aanmaken',
    'create_vendor' => 'Leverancier aanmaken',
    'create_expense_category' => 'Categorie aanmaken',
    'pro_plan_reports' => ':link om rapporten te activeren door te abonneren op het Pro Plan',
    'mark_ready' => 'Markeer als gereed',

    'limits' => 'Limieten',
    'fees' => 'Transactiekosten',
    'fee' => 'Transactiekosten',
    'set_limits_fees' => 'Stel :gateway_type limieten/toeslag in',
    'fees_tax_help' => 'Schakel regelitem belastingen in om belastingstoeslag in te stellen.',
    'fees_sample' => 'De toeslag voor een :amount factuur is :total.',
    'discount_sample' => 'De korting voor een :amount factuur is :total.',
    'no_fees' => 'Geen transactiekosten',
    'gateway_fees_disclaimer' => 'Waarschuwing: niet alle staten/betalingsgateways laten het toe om kosten toe te voegen, gelieve lokale wetten/servicevoorwaarden te raadplegen.',
    'percent' => 'Procent',
    'location' => 'Locatie',
    'line_item' => 'Regelitem',
    'surcharge' => 'Toeslag',
    'location_first_surcharge' => 'Ingeschakeld - Eerste toeslag',
    'location_second_surcharge' => 'Ingeschakeld - Tweede toeslag',
    'location_line_item' => 'Ingeschakeld - Regelitem',
    'online_payment_surcharge' => 'Online betalingstoeslag',
    'gateway_fees' => 'Transactiekosten Gateway',
    'fees_disabled' => 'Transactiekosten zijn uitgeschakeld',
    'gateway_fees_help' => 'Online betalingstoeslag/korting automatisch toevoegen.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'Als er onbetaalde facturen met transactiekosten zijn, moeten die handmatig bijgewerkt worden.',
    'fees_surcharge_help' => 'Toeslag aanpassen :link.',
    'label_and_taxes' => 'label en belastingen',
    'billable' => 'Factureerbare uren',
    'logo_warning_too_large' => 'Het afbeeldingsbestand is te groot.',
    'logo_warning_fileinfo' => 'Waarschuwing: Om GIF-bestanden te ondersteunen moet de fileinfo PHP-extensie ingeschakeld zijn.',
    'logo_warning_invalid' => 'Er was een probleem tijdens het lezen van het afbeeldingsbestand, gelieve een anders formaat te proberen.',

    'error_refresh_page' => 'Er trad een fout op, gelieve de pagina te vernieuwen en opnieuw te proberen.',
    'data' => 'Data',
    'imported_settings' => 'De instellingen zijn geïmporteerd',
    'reset_counter' => 'Teller resetten',
    'next_reset' => 'Volgende reset',
    'reset_counter_help' => 'De factuur en offerte tellers automatisch resetten.',
    'auto_bill_failed' => 'Autofacturatie voor factuur :invoice_number mislukt',
    'online_payment_discount' => 'Online betalingskorting',
    'created_new_company' => 'Nieuw bedrijf succesfol aangemaakt',
    'fees_disabled_for_gateway' => 'Transactiekosten zijn uitgeschakeld voor deze gateway.',
    'logout_and_delete' => 'Uitloggen/account opzeggen',
    'tax_rate_type_help' => 'Inbegrepen belastingstarieven passen de kosten van het regelitem aan wanneer deze worden geselecteerd.<br/>Alleen de niet inbegrepen belastingtarieven kunnen als standaard worden gebruikt.',
    'invoice_footer_help' => 'Gebruik $pageNumber en $pageCount om de pagina informatie weer te geven.',
    'credit_note' => 'Kredietnota',
    'credit_issued_to' => 'Krediet afgegeven aan',
    'credit_to' => 'Krediet aan',
    'your_credit' => 'Uw krediet',
    'credit_number' => 'Kredietnummer',
    'create_credit_note' => 'Kredietnota aanmaken',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Fout: De gateway tabel heeft foutieve id\'s.',
    'purge_data' => 'Wis gegevens',
    'delete_data' => 'Verwijder gegevens',
    'purge_data_help' => 'Alle gegevens permanent verwijderen, maar behoud het account en instellingen.',
    'cancel_account_help' => 'Verwijder het account inclusief alle gegevens en instellingen.',
    'purge_successful' => 'De bedrijfsgegevens zijn gewist',
    'forbidden' => 'Verboden',
    'purge_data_message' => 'Waarschuwing: Dit zal uw gegevens verwijderen. Er is geen manier om dit ongedaan te maken.',
    'contact_phone' => 'Contact telefoon',
    'contact_email' => 'Contact e-mail',
    'reply_to_email' => 'Antwoord naar e-mail',
    'reply_to_email_help' => 'Geef het antwoord-aan adres voor klant e-mails.',
    'bcc_email_help' => 'Dit adres heimelijk gebruiken met klant e-mails.',
    'import_complete' => 'Het importeren is uitgevoerd.',
    'confirm_account_to_import' => 'Gelieve uw account te bevestigen om de gegevens te importeren.',
    'import_started' => 'Het importeren is gestart, we sturen u een e-mail van zodra het proces afgerond is.',
    'listening' => 'Luisteren...',
    'microphone_help' => 'Zeg "nieuw factuur voor [client]" of "toon me [client]\'s gearchiveerde betalingen".',
    'voice_commands' => 'Stemcommando\'s',
    'sample_commands' => 'Voorbeeldcommando\'s',
    'voice_commands_feedback' => 'We werken actief aan deze feature, als er een commando is waarvan u wilt dat wij dat ondersteunen, mail ons dan op :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Succesvol :count producten gearchiveerd',
    'recommend_on' => 'We raden aan deze instellingen <b>in te schakelen</b>.',
    'recommend_off' => 'We raden aan deze instellingen <b>uit te schakelen</b>.',
    'notes_auto_billed' => 'Automatische geïncasseerd',
    'surcharge_label' => 'Toeslag label',
    'contact_fields' => 'Contact velden',
    'custom_contact_fields_help' => 'Voeg een veld toe bij het creëren van een contact en toon het label en de waarde op de PDF.',
    'datatable_info' => ':start tot :end van :total items worden getoond',
    'credit_total' => 'Totaal krediet',
    'mark_billable' => 'Markeer als factureerbaar',
    'billed' => 'Gefactureerd',
    'company_variables' => 'Bedrijfsvariabelen',
    'client_variables' => 'Klant variabelen',
    'invoice_variables' => 'Factuur variabelen',
    'navigation_variables' => 'Navigatie variabelen',
    'custom_variables' => 'Aangepaste variabelen',
    'invalid_file' => 'Ongeldig bestandstype',
    'add_documents_to_invoice' => 'Voeg documenten toe aan factuur',
    'mark_expense_paid' => 'Markeer als betaald',
    'white_label_license_error' => 'Validatie van de licentie mislukt, controleer storage/logs/laravel-error.log voor meer informatie.',
    'plan_price' => 'Plan prijs',
    'wrong_confirmation' => 'Incorrecte bevestigingscode',
    'oauth_taken' => 'Het account is al geregistreerd',
    'emailed_payment' => 'De betaling is per mail verstuurd',
    'email_payment' => 'E-mail betaling',
    'invoiceplane_import' => 'Gebruik :link om uw data te migreren van InvoicePlane.',
    'duplicate_expense_warning' => 'Waarschuwing: Deze :link kan een duplicaat zijn',
    'expense_link' => 'uitgave',
    'resume_task' => 'Hervat taak',
    'resumed_task' => 'Taak hervat',
    'quote_design' => 'Offerte ontwerp',
    'default_design' => 'Standaard ontwerp',
    'custom_design1' => 'Aangepast ontwerp 1',
    'custom_design2' => 'Aangepast ontwerp 2',
    'custom_design3' => 'Aangepast ontwerp 3',
    'empty' => 'Leegmaken',
    'load_design' => 'Laad ontwerp',
    'accepted_card_logos' => 'Geaccepteerde kaart logo\'s',
    'phantomjs_local_and_cloud' => 'PhantomJS gebruiken, terugvallen naar phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Betalingen traceren met :link',
    'start_date_required' => 'De startdatum is vereist',
    'application_settings' => 'Applicatie instellingen',
    'database_connection' => 'Databaseverbinding',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Verbinding testen',
    'from_name' => 'Van naam',
    'from_address' => 'Van adres',
    'port' => 'Poort',
    'encryption' => 'Encryptie',
    'mailgun_domain' => 'Mailgun domein',
    'mailgun_private_key' => 'Mailgun privésleutel',
    'send_test_email' => 'Verstuur test-e-mail',
    'select_label' => 'Selecteer label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Betalingsdetails bijwerken',
    'updated_payment_details' => 'De betalingsdetails zijn gewijzigd',
    'update_credit_card' => 'Krediet kaart bijwerken',
    'recurring_expenses' => 'Terugkerende uitgaven',
    'recurring_expense' => 'Terugkerende uitgave',
    'new_recurring_expense' => 'Nieuwe terugkerende uitgave',
    'edit_recurring_expense' => 'Terugkerende uitgave bewerken',
    'archive_recurring_expense' => 'Terugkerende uitgave archiveren',
    'list_recurring_expense' => 'Toon terugkerende uitgaven',
    'updated_recurring_expense' => 'De terugkerende uitgave is gewijzigd',
    'created_recurring_expense' => 'De terugkerende uitgave is aangemaakt',
    'archived_recurring_expense' => 'De terugkerende uitgave is gearchiveerd',
    'restore_recurring_expense' => 'Herstel terugkerende uitgave',
    'restored_recurring_expense' => 'De terugkerende uitgave is hersteld',
    'delete_recurring_expense' => 'Terugkerende uitgave verwijderen',
    'deleted_recurring_expense' => 'Het project is verwijderd',
    'view_recurring_expense' => 'Terugkerende uitgave tonen',
    'taxes_and_fees' => 'Belastingen en heffingen',
    'import_failed' => 'Importeren mislukt',
    'recurring_prefix' => 'Terugkerend voorvoegsel',
    'options' => 'Opties',
    'credit_number_help' => 'Geef een voorvoegsel of een aangepast patroon om kredietnummers dynamisch te genereren.',
    'next_credit_number' => 'Het volgende kredietnummer is :number.',
    'padding_help' => 'Het aantal nullen om het nummer op te vullen.',
    'import_warning_invalid_date' => 'Waarschuwing: het datumformaat lijkt ongeldig te zijn.',
    'product_notes' => 'Productopmerkingen',
    'app_version' => 'App versie',
    'ofx_version' => 'OFX versie',
    'gateway_help_23' => ':link om uw Stripe API sleutels te krijgen.',
    'error_app_key_set_to_default' => 'Error: APP_KEY staat op een standaardwaarde, om te updaten dient u uw database te backuppen en vervolgens het volgende uit te voeren: <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Late vergoeding aanrekenen',
    'late_fee_amount' => 'Late vergoedingsbedrag',
    'late_fee_percent' => 'Late vergoedingspercentage',
    'late_fee_added' => 'late vergoeding toegevoegd op :date',
    'download_invoice' => 'Download factuur',
    'download_quote' => 'Download offerte',
    'invoices_are_attached' => 'Uw factuur PDF\'s zijn bijgevoegd.',
    'downloaded_invoice' => 'Een e-mail zal verstuurd worden met de factuur PDF',
    'downloaded_quote' => 'Een e-mail zal verstuurd worden met de offerte PDF',
    'downloaded_invoices' => 'Een e-mail zal verstuurd worden met de factuur PDF\'s',
    'downloaded_quotes' => 'Een e-mail zal verstuurd worden met de offerte PDF\'s',
    'clone_expense' => 'Uitgave kopiëren',
    'default_documents' => 'Standaard documenten',
    'send_email_to_client' => 'Verzend e-mail naar de klant',
    'refund_subject' => 'Terugbetaling verwerkt',
    'refund_body' => 'U hebt een terugbetaling gekregen van :amount voor factuur  invoice_number.',

    'currency_us_dollar' => 'Amerikaanse dollar',
    'currency_british_pound' => 'Britse pond',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'Zuid-Afrikaanse Rand',
    'currency_danish_krone' => 'Deense Krone',
    'currency_israeli_shekel' => 'Israëlische Shekel',
    'currency_swedish_krona' => 'Zweedse kroon',
    'currency_kenyan_shilling' => 'Keniaanse Shilling',
    'currency_canadian_dollar' => 'Canadese dollar',
    'currency_philippine_peso' => 'Filippijnse Peso',
    'currency_indian_rupee' => 'Indiase Roepie',
    'currency_australian_dollar' => 'Australische dollar',
    'currency_singapore_dollar' => 'Singapore dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'Nieuw-Zeelandse Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Zwitserse frank',
    'currency_guatemalan_quetzal' => 'Guatemalaanse Quetzal',
    'currency_malaysian_ringgit' => 'Maleisische Ringgit',
    'currency_brazilian_real' => 'Braziliaanse Real',
    'currency_thai_baht' => 'Thaise Baht',
    'currency_nigerian_naira' => 'Nigeriaanse Naira',
    'currency_argentine_peso' => 'Argentijnse Peso',
    'currency_bangladeshi_taka' => 'Bangladesh Taka',
    'currency_united_arab_emirates_dirham' => 'Verenigde Arabische Emiraten Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong dollar',
    'currency_indonesian_rupiah' => 'Indonesische Rupiah',
    'currency_mexican_peso' => 'Mexicaanse Peso',
    'currency_egyptian_pound' => 'Egyptisch Pond',
    'currency_colombian_peso' => 'Colombiaanse Peso',
    'currency_west_african_franc' => 'West-Afrikaanse Frank',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandese Frank',
    'currency_tanzanian_shilling' => 'Tanzaniaanse Shilling',
    'currency_netherlands_antillean_guilder' => 'Nederlandse Antilliaanse Gulden',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad en Tobago Dollar',
    'currency_east_caribbean_dollar' => 'Oost-Caribische Dollar',
    'currency_ghanaian_cedi' => 'Ghanaanse Cedi',
    'currency_bulgarian_lev' => 'Bulgaarse Lev',
    'currency_aruban_florin' => 'Arubaanse Florin',
    'currency_turkish_lira' => 'Turkse Lira',
    'currency_romanian_new_leu' => 'Roemeense Nieuwe Leu',
    'currency_croatian_kuna' => 'Kroatische Kuna',
    'currency_saudi_riyal' => 'Saoedi-Riyal',
    'currency_japanese_yen' => 'Japanse Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Ricaanse Colón',
    'currency_pakistani_rupee' => 'Pakistaanse Roepie',
    'currency_polish_zloty' => 'Poolse Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankaanse Roepie',
    'currency_czech_koruna' => 'Tsjechische Koruna',
    'currency_uruguayan_peso' => 'Uruguayaanse Peso',
    'currency_namibian_dollar' => 'Namibische Dollar',
    'currency_tunisian_dinar' => 'Tunesische Dinar',
    'currency_russian_ruble' => 'Russische Roebel',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Oekraïense hryvnia',
    'currency_macanese_pataca' => 'Macaanse Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan Nieuwe Dollar',
    'currency_dominican_peso' => 'Dominicaanse Peso',
    'currency_chilean_peso' => 'Chileense Peso',
    'currency_icelandic_krona' => 'IJslandse kroon',
    'currency_papua_new_guinean_kina' => 'Papoea-Nieuw-Guinee-China',
    'currency_jordanian_dinar' => 'Jordaanse Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruaanse Sol',
    'currency_botswana_pula' => 'Botswaanse pula',
    'currency_hungarian_forint' => 'Hongaarse forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadiaanse dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgische Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Hondurese Lempira',
    'currency_surinamese_dollar' => 'Surinaamse Dollar',
    'currency_bahraini_dinar' => 'Bahrein Dinar',
    'currency_venezuelan_bolivars' => 'Venezolaanse bolivar',
    'currency_south_korean_won' => 'Zuid-Koreaanse Won',
    'currency_moroccan_dirham' => 'Marokkaanse Dirham',
    'currency_jamaican_dollar' => 'Jamaicaanse Dollar',
    'currency_angolan_kwanza' => 'Angolese kwanza',
    'currency_haitian_gourde' => 'Haïtiaanse Gourde',
    'currency_zambian_kwacha' => 'Zambiaanse Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Roepie',
    'currency_cfp_franc' => 'CFP Frank',
    'currency_mauritian_rupee' => 'Mauritiaanse Roepie',
    'currency_cape_verdean_escudo' => 'Kaapverdisch Escudo',
    'currency_kuwaiti_dinar' => 'Koeweitse Dinar',
    'currency_algerian_dinar' => 'Algerijnse Dinar',
    'currency_macedonian_denar' => 'Macedonische Denar',
    'currency_fijian_dollar' => 'Fijische Dollar',
    'currency_bolivian_boliviano' => 'Boliviaanse Boliviano',
    'currency_albanian_lek' => 'Albanese Lek',
    'currency_serbian_dinar' => 'Servische Dinar',
    'currency_lebanese_pound' => 'Libanese Pond',
    'currency_armenian_dram' => 'Armeense Dram',
    'currency_azerbaijan_manat' => 'Azerbeidzjaanse Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnië en Herzegovina Inwisselbare Mark',
    'currency_belarusian_ruble' => 'Wit-Russische Roebel',
    'currency_moldovan_leu' => 'Moldavische Leu',
    'currency_kazakhstani_tenge' => 'Kazachse Tenge',
    'currency_gibraltar_pound' => 'Gibraltarese Pond',

    'review_app_help' => 'We hopen dat je het leuk vindt om de app te gebruiken.<br/> Als je zou overwegen :link, zouden we dat zeer op prijs stellen!',
    'writing_a_review' => 'een recensie schrijven',

    'use_english_version' => 'Zorg ervoor dat u de Engelse versie van de bestanden gebruikt.<br/>We gebruiken de kolomkoppen om de velden aan te passen.',
    'tax1' => 'Eerste belasting',
    'tax2' => 'Tweede belasting',
    'fee_help' => 'Gateway vergoedingen zijn de kosten die gelden voor toegang tot de financiële netwerken die de verwerking van online betalingen behandelen.',
    'format_export' => 'Uitvoerformaat',
    'custom1' => 'Eerste aangepaste',
    'custom2' => 'Tweede aangepaste',
    'contact_first_name' => 'Contact voornaam',
    'contact_last_name' => 'Contact achternaam',
    'contact_custom1' => 'Eerste contact aangepaste',
    'contact_custom2' => 'Tweede contact aangepaste',
    'currency' => 'Munteenheid',
    'ofx_help' => 'Ga als volgt te werk om te controleren of er opmerkingen zijn over :ofxhome_link en test met :ofxget_link.',
    'comments' => 'opmerkingen',

    'item_product' => 'Artikel product',
    'item_notes' => 'Artikel notities',
    'item_cost' => 'Artikel kost',
    'item_quantity' => 'Artikel hoeveelheid',
    'item_tax_rate' => 'Artikel BTW-tarief',
    'item_tax_name' => 'Artikel belasting naam',
    'item_tax1' => 'Artikel belasting 1',
    'item_tax2' => 'Artikel belasting 2',

    'delete_company' => 'Verwijder bedrijf',
    'delete_company_help' => 'Permanent je bedrijf verwijderen inclusief alle gegevens en instellingen.',
    'delete_company_message' => 'Waarschuwing: Hiermee verwijder je permanent je bedrijf, dit kan niet worden ontdaan.',

    'applied_discount' => 'De kortingscode is toegevoegd, de prijs van het gekozen plan is verlaagd met :discount%.',
    'applied_free_year' => 'De kortingsbon is toegepast, uw account is gedurende een jaar geüpgraded naar pro.',

    'contact_us_help' => 'Als u een fout meldt, voeg dan alle relevante logs toe van storage/logs/laravel-error.log',
    'include_errors' => 'Inclusief fouten',
    'include_errors_help' => 'Inclusief :link van storage/logs/laravel-error.log',
    'recent_errors' => 'recente foutmeldingen',
    'customer' => 'Klant',
    'customers' => 'Klanten',
    'created_customer' => 'De klant is aangemaakt',
    'created_customers' => 'Succesvol :count klanten aangemaakt',

    'purge_details' => 'De gegevens in het account (:account) zijn gewist',
    'deleted_company' => 'Het bedrijf is verwijderd',
    'deleted_account' => 'Account geannuleerd',
    'deleted_company_details' => 'Je bedrijf (:account) is verwijderd',
    'deleted_account_details' => 'Je account (:account) is verwijderd',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Automatisch incasso',
    'enable_alipay' => 'Accepteer Alipay',
    'enable_sofort' => 'Accepteer Europese banktransacties',
    'stripe_alipay_help' => 'Deze gateways moeten ook worden geactiveerd in :link.',
    'calendar' => 'Kalender',
    'pro_plan_calendar' => ':link om de kalender in te schakelen door lid te worden van het Pro Plan',

    'what_are_you_working_on' => 'Waar werk je aan?',
    'time_tracker' => 'Tijdregistratie',
    'refresh' => 'Verversen',
    'filter_sort' => 'Filter/Sorteer',
    'no_description' => 'Geen Beschrijving',
    'time_tracker_login' => 'Inloggen Tijdregistratie',
    'save_or_discard' => 'Sla  wijzigingen op of wis deze',
    'discard_changes' => 'Wis Wijzigingen',
    'tasks_not_enabled' => 'Taken staan niet aan',
    'started_task' => 'De taak is gestart',
    'create_client' => 'Klant aanmaken',

    'download_desktop_app' => 'Download de dekstop app',
    'download_iphone_app' => 'Download de iPhone app',
    'download_android_app' => 'Download de Android app',
    'time_tracker_mobile_help' => 'Dubbel tap een taak om deze te selecteren',
    'stopped' => 'Gestopt',
    'ascending' => 'Oplopend',
    'descending' => 'Aflopend',
    'sort_field' => 'Sorteren op',
    'sort_direction' => 'Richting',
    'discard' => 'Wissen',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'minuten',
    'time_hr' => 'uur',
    'time_hrs' => 'uren',
    'clear' => 'Wis',
    'warn_payment_gateway' => 'Opmerking: voor het accepteren van online betalingen is een betalingsgateway vereist. :link om er een toe te voegen.',
    'task_rate' => 'Taak tarief',
    'task_rate_help' => 'Stel het standaardtarief in voor gefactureerde taken.',
    'past_due' => 'Verlopen',
    'document' => 'Document',
    'invoice_or_expense' => 'Factuur/Kosten',
    'invoice_pdfs' => 'Factuur PDF\'s',
    'enable_sepa' => 'Accepteer SEPA',
    'enable_bitcoin' => 'Accepteer Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Door uw IBAN te verstrekken en deze betaling te bevestigen, machtigt u :company en Stripe, onze betalingsdienstaanbieder, om instructies naar uw bank te sturen om uw rekening en uw bank te debiteren om uw rekening af te schrijven overeenkomstig met die instructies. U hebt recht op terugbetaling van uw bank onder de voorwaarden van uw overeenkomst met uw bank. Een terugbetaling moet binnen 8 weken worden gerekend vanaf de datum waarop uw account is afgeschreven.',
    'recover_license' => 'Herstel licentie',
    'purchase' => 'Aankoop',
    'recover' => 'Herstel',
    'apply' => 'Toepassen',
    'recover_white_label_header' => 'Herstel whitelabel-licentie',
    'apply_white_label_header' => 'Whitelabel licentie toepassen',
    'videos' => 'Video\'s',
    'video' => 'Video',
    'return_to_invoice' => 'Terug naar factuur',
    'gateway_help_13' => 'Als u ITN wilt gebruiken, laat u het veld PDT Key leeg.',
    'partial_due_date' => 'Gedeeltelijke vervaldatum',
    'task_fields' => 'Taak velden',
    'product_fields_help' => 'Versleep de velden om hun volgorde te wijzigen',
    'custom_value1' => 'Aangepaste waarde',
    'custom_value2' => 'Aangepaste waarde',
    'enable_two_factor' => 'Tweestaps-authenticatie',
    'enable_two_factor_help' => 'Gebruik je telefoon om je identiteit te bevestigen bij het inloggen',
    'two_factor_setup' => 'Tweestaps-authenticatie instellen',
    'two_factor_setup_help' => 'Scan de streepjescode met een :link compatibele app.',
    'one_time_password' => 'Eenmalig wachtwoord',
    'set_phone_for_two_factor' => 'Stel uw telefoonnummer in als backup.',
    'enabled_two_factor' => 'Tweestaps-authenticatie ingeschakeld',
    'add_product' => 'Product toevoegen',
    'email_will_be_sent_on' => 'Let op: de e-mail zal worden verstuurd op :date.',
    'invoice_product' => 'Factureer product',
    'self_host_login' => 'Self-Host login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Fout: lokale opslag is niet beschikbaar.',
    'your_password_reset_link' => 'Uw wachtwoord reset koppeling',
    'subdomain_taken' => 'Het subdomein is al in gebruik',
    'client_login' => 'Klantenlogin',
    'converted_amount' => 'Omgezet bedrag',
    'default' => 'Standaard',
    'shipping_address' => 'Leveringsadres',
    'bllling_address' => 'Factuuradres',
    'billing_address1' => 'Facturatie straat',
    'billing_address2' => 'Facturatie Apt/Suite',
    'billing_city' => 'Facturatiestad',
    'billing_state' => 'Facturatie Staat/Provincie',
    'billing_postal_code' => 'Facturatie Postcode',
    'billing_country' => 'Facturatieland',
    'shipping_address1' => 'Leveringsstraat',
    'shipping_address2' => 'Leverings Apt/Suite',
    'shipping_city' => 'Leveringsstad',
    'shipping_state' => 'Leverings Staat/Provincie',
    'shipping_postal_code' => 'Leverings Postcode',
    'shipping_country' => 'Leveringsland',
    'classify' => 'Classificeren',
    'show_shipping_address_help' => 'Vereisen dat de klant zijn leveringsadres opgeeft',
    'ship_to_billing_address' => 'Verzend naar factuuradres',
    'delivery_note' => 'Afleveringsbon',
    'show_tasks_in_portal' => 'Toon taken in het klantenportaal',
    'cancel_schedule' => 'Annuleer schema',
    'scheduled_report' => 'Gepland rapport',
    'scheduled_report_help' => 'E-mail het :report rapport als :format naar :email',
    'created_scheduled_report' => 'Rapport ingepland',
    'deleted_scheduled_report' => 'Het ingeplande rapport is geannuleerd',
    'scheduled_report_attached' => 'Uw gepland :type rapport is bijgevoegd.',
    'scheduled_report_error' => 'Kan gepland rapport niet maken',
    'invalid_one_time_password' => 'Eenmalig wachtwoord ongeldig',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accepteer Apple Pay en Pay met Google',
    'requires_subdomain' => 'Deze betalingsmethode vereist dat een :link.',
    'subdomain_is_set' => 'subdomein is ingesteld',
    'verification_file' => 'Verificatiebestand',
    'verification_file_missing' => 'Het verificatiebestand is nodig om betalingen te accepteren.',
    'apple_pay_domain' => 'Gebruik <code>:domain</code> als het domein in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay wordt niet ondersteund door uw browser',
    'optional_payment_methods' => 'Optionele betalingsmethodes',
    'add_subscription' => 'Abonnement toevoegen',
    'target_url' => 'Doel',
    'target_url_help' => 'Wanneer de geselecteerde gebeurtenis plaatsvindt, zal de app de entiteit op de doel-URL posten.',
    'event' => 'Gebeurtenis',
    'subscription_event_1' => 'Klant aangemaakt',
    'subscription_event_2' => 'Factuur aangemaakt',
    'subscription_event_3' => 'Offerte aangemaakt',
    'subscription_event_4' => 'Betaling aangemaakt',
    'subscription_event_5' => 'Leverancier aangemaakt',
    'subscription_event_6' => 'Offerte bijgewerkt',
    'subscription_event_7' => 'Offerte verwijderd',
    'subscription_event_8' => 'Factuur bijgewerkt',
    'subscription_event_9' => 'Factuur verwijderd',
    'subscription_event_10' => 'Klant bijgewerkt',
    'subscription_event_11' => 'Klant verwijderd',
    'subscription_event_12' => 'Betaling verwijderd',
    'subscription_event_13' => 'Verkoper bijgewerkt',
    'subscription_event_14' => 'Verkoper verwijderd',
    'subscription_event_15' => 'Uitgave aangemaakt',
    'subscription_event_16' => 'Uitgave bijgewerkt',
    'subscription_event_17' => 'Uitgave verwijderen',
    'subscription_event_18' => 'Taak aangemaakt',
    'subscription_event_19' => 'Taak bijgewerkt',
    'subscription_event_20' => 'Taak verwijderd',
    'subscription_event_21' => 'Offerte goedgekeurd',
    'subscriptions' => 'Abonnementen',
    'updated_subscription' => 'Het abonnement is gewijzigd',
    'created_subscription' => 'Het abonnement is aangemaakt',
    'edit_subscription' => 'Abonnement wijzigen',
    'archive_subscription' => 'Abonnement archiveren',
    'archived_subscription' => 'Het abonnement is gearchiveerd',
    'project_error_multiple_clients' => 'De projecten kunnen niet tot meerdere klanten behoren',
    'invoice_project' => 'Factureer project',
    'module_recurring_invoice' => 'Terugkerende facturen',
    'module_credit' => 'Kredietnota\'s',
    'module_quote' => 'Offertes & voorstellen',
    'module_task' => 'Taken & projecten',
    'module_expense' => 'Uitgaven & leveranciers',
    'module_ticket' => 'Tickets',
    'reminders' => 'Herinneringen',
    'send_client_reminders' => 'Verzend e-mailherinneringen',
    'can_view_tasks' => 'Taken zijn zichtbaar in de portaal',
    'is_not_sent_reminders' => 'Herinneringen worden niet verzonden',
    'promotion_footer' => 'Uw promotie verloopt binnenkort, :link om nu te upgraden.',
    'unable_to_delete_primary' => 'Opmerking: om dit bedrijf te verwijderen, verwijdert u eerst alle gekoppelde bedrijven.',
    'please_register' => 'Gelieve uw account te registreren',
    'processing_request' => 'Aanvraag wordt verwerkt',
    'mcrypt_warning' => 'Waarschuwing: Mcrypt is verouderd, voer :command uit om uw cipher te updaten.',
    'edit_times' => 'Wijzig tijden',
    'inclusive_taxes_help' => 'Neem <b>belastingen op in de uitgave</b>',
    'inclusive_taxes_notice' => 'Deze instelling kan niet worden gewijzigd nadat een factuur is aangemaakt.',
    'inclusive_taxes_warning' => 'Waarschuwing: bestaande facturen moeten opnieuw worden opgeslagen',
    'copy_shipping' => 'Levering kopiëren',
    'copy_billing' => 'Facturatie kopiëren',
    'quote_has_expired' => 'De offerte is verlopen, neem contact op met de verkoper.',
    'empty_table_footer' => '0 tot 0 van 0 vermeldingen tonen',
    'do_not_trust' => 'Dit apparaat niet onthouden',
    'trust_for_30_days' => 'Vertrouw voor 30 dagen',
    'trust_forever' => 'Vertrouw voor altijd',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Klaar om te doen',
    'in_progress' => 'Bezig',
    'add_status' => 'Status toevoegen',
    'archive_status' => 'Status archiveren',
    'new_status' => 'Nieuwe status',
    'convert_products' => 'Producten omzetten',
    'convert_products_help' => 'Productprijzen automatisch converteren naar het valuta van de klant',
    'improve_client_portal_link' => 'Stel een subdomein in om de link naar het klantenportaal in te korten.',
    'budgeted_hours' => 'Begrote uren',
    'progress' => 'Vooruitgang',
    'view_project' => 'Toon project',
    'summary' => 'Overzicht',
    'endless_reminder' => 'Eindeloze taak',
    'signature_on_invoice_help' => 'Voeg de volgende code toe om de handtekening van de klant op de PDF weer te geven.',
    'signature_on_pdf' => 'Weergeven op PDF',
    'signature_on_pdf_help' => 'Toon de handtekening van de klant op de factuur/offerte PDF.',
    'expired_white_label' => 'De whitelabel licentie is verlopen',
    'return_to_login' => 'Terug naar login',
    'convert_products_tip' => 'Opmerking: voeg een :link met de naam ":name" toe om de wisselkoers te zien.',
    'amount_greater_than_balance' => 'Het bedrag is groter dan het factuursaldo, er wordt een creditfactuur aangemaakt met het resterende bedrag.',
    'custom_fields_tip' => 'Gebruik <code>Label|Option1,Option2</code> om een selectievak weer te geven.',
    'client_information' => 'Klantinformatie',
    'updated_client_details' => 'De klantgegevens zijn gewijzigd',
    'auto' => 'Auto',
    'tax_amount' => 'BTW',
    'tax_paid' => 'Betaalde Belasting',
    'none' => 'Geen',
    'proposal_message_button' => 'Om het voorstel voor :amount te bekijken, klik op de knop hieronder.',
    'proposal' => 'Voorstel',
    'proposals' => 'Voorstellen',
    'list_proposals' => 'Voorstel lijst',
    'new_proposal' => 'Nieuw voorstel',
    'edit_proposal' => 'Bewerk voorstel',
    'archive_proposal' => 'Archiveer voorstel',
    'delete_proposal' => 'Verwijder voorstel',
    'created_proposal' => 'Voorstel aangemaakt',
    'updated_proposal' => 'Het voorstel is gewijzigd',
    'archived_proposal' => 'Het voorstel is gearchiveerd',
    'deleted_proposal' => 'Het voorstel is  verwijderd',
    'archived_proposals' => 'Succesvol :count voorstellen gearchiveerd',
    'deleted_proposals' => 'Succesvol :count voorstellen verwijderd',
    'restored_proposal' => 'Het voorstel is hersteld',
    'restore_proposal' => 'Herstel voorstel',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'Nieuw snippet',
    'edit_proposal_snippet' => 'Wijzig snippet',
    'archive_proposal_snippet' => 'Archiveer snippet',
    'delete_proposal_snippet' => 'Verwijder snippet',
    'created_proposal_snippet' => 'De snippet is aangemaakt',
    'updated_proposal_snippet' => 'De snippet is gewijzigd',
    'archived_proposal_snippet' => 'De snippet is gearchiveerd',
    'deleted_proposal_snippet' => 'De snippet is verwijderd',
    'archived_proposal_snippets' => 'Succesvol :count snippets gearchiveerd',
    'deleted_proposal_snippets' => 'Succesvol :count snippets verwijderd',
    'restored_proposal_snippet' => 'De snippet is hersteld',
    'restore_proposal_snippet' => 'Herstel snippet',
    'template' => 'Sjabloon',
    'templates' => 'Sjablonen',
    'proposal_template' => 'Sjabloon',
    'proposal_templates' => 'Sjablonen',
    'new_proposal_template' => 'Nieuw sjabloon',
    'edit_proposal_template' => 'Wijzig sjabloon',
    'archive_proposal_template' => 'Archiveer sjabloon',
    'delete_proposal_template' => 'Verwijder sjabloon',
    'created_proposal_template' => 'Het sjabloon is aangemaakt',
    'updated_proposal_template' => 'Het sjabloon is gewijzigd',
    'archived_proposal_template' => 'Het sjabloon is gearchiveerd',
    'deleted_proposal_template' => 'Het sjabloon is verwijderd',
    'archived_proposal_templates' => 'Succesvol :count sjablonen gearchiveerd',
    'deleted_proposal_templates' => 'Succesvol :count sjablonen verwijderd',
    'restored_proposal_template' => 'Het sjabloon is hersteld',
    'restore_proposal_template' => 'Herstel sjabloon',
    'proposal_category' => 'Categorie',
    'proposal_categories' => 'Categorieën',
    'new_proposal_category' => 'Nieuwe categorie',
    'edit_proposal_category' => 'Wijzig categorie',
    'archive_proposal_category' => 'Archiveer categorie',
    'delete_proposal_category' => 'Verwijder categorie',
    'created_proposal_category' => 'De categorie is aangemaakt',
    'updated_proposal_category' => 'De categorie is gewijzigd',
    'archived_proposal_category' => 'De categorie is gearchiveerd',
    'deleted_proposal_category' => 'De categorie is verwijderd',
    'archived_proposal_categories' => 'Succesvol :count categorieën gearchiveerd',
    'deleted_proposal_categories' => 'Succesvol  :count categorieën verwijderd',
    'restored_proposal_category' => 'De categorie is hersteld',
    'restore_proposal_category' => 'Herstel categorie',
    'delete_status' => 'Status verwijderen',
    'standard' => 'Standaard',
    'icon' => 'Icoon',
    'proposal_not_found' => 'Het opgevraagde voorstel is niet beschikbaar',
    'create_proposal_category' => 'Categorie aanmaken',
    'clone_proposal_template' => 'Dupliceer sjabloon',
    'proposal_email' => 'Voorstelmail',
    'proposal_subject' => 'Nieuwe voorstel :number van :account',
    'proposal_message' => 'Om uw voorstel voor :amount te bekijken, klik op de link hieronder.',
    'emailed_proposal' => 'Het voorstel is gemaild',
    'load_template' => 'Sjabloon laden',
    'no_assets' => 'Geen afbeeldingen, slepen om te uploaden',
    'add_image' => 'Afbeelding toevoegen',
    'select_image' => 'Afbeelding selecteren',
    'upgrade_to_upload_images' => 'Voer een upgrade uit naar het enterprise plan om afbeeldingen te uploaden',
    'delete_image' => 'Afbeelding verwijderen',
    'delete_image_help' => 'Waarschuwing: als je de afbeelding verwijdert, wordt deze uit alle voorstellen verwijderd.',
    'amount_variable_help' => 'Opmerking: Het veld $amount op de factuur wordt gebruikt als gedeeltelijke betaling als dit is ingesteld, anders wordt het factuur saldo gebruikt.',
    'taxes_are_included_help' => 'Opmerking: inbegrepen heffingen/belastingen zijn ingeschakeld.',
    'taxes_are_not_included_help' => 'Opmerking: inbegrepen heffingen/belastingen zijn niet ingeschakeld.',
    'change_requires_purge' => 'Het aanzetten van deze instelling vereist :link van de accountgegevens.',
    'purging' => 'opschonen',
    'warning_local_refund' => 'De terugbetaling zal worden geregistreerd in de app, maar zal NIET worden verwerkt door de betalingsgateway.',
    'email_address_changed' => 'E-mailadres is gewijzigd',
    'email_address_changed_message' => 'Het e-mailadres voor uw account is gewijzigd van :old_email in :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporteren naar ZIP vereist de GMP-extensie',
    'email_history' => 'E-mailgeschiedenis',
    'loading' => 'Laden',
    'no_messages_found' => 'Geen berichten gevonden',
    'processing' => 'Verwerken',
    'reactivate' => 'Heractiveren',
    'reactivated_email' => 'Het e-mailadres is opnieuw geactiveerd',
    'emails' => 'E-mails',
    'opened' => 'Geopend',
    'bounced' => 'Bounced',
    'total_sent' => 'Totaal verstuurd',
    'total_opened' => 'Totaal geopend',
    'total_bounced' => 'Totaal gebounced',
    'total_spam' => 'Totaal spam',
    'platforms' => 'Platforms',
    'email_clients' => 'E-mailclients',
    'mobile' => 'Mobiel',
    'desktop' => 'Bureaublad',
    'webmail' => 'Webmail',
    'group' => 'Groep',
    'subgroup' => 'Subgroep',
    'unset' => 'Unset',
    'received_new_payment' => 'Je hebt een nieuwe betaling ontvangen!',
    'slack_webhook_help' => 'Ontvang betalingsmeldingen via :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accepteer',
    'accepted_terms' => 'Nieuwe servicevoorwaarden geaccepteerd',
    'invalid_url' => 'Ongeldige URL',
    'workflow_settings' => 'Workflow instellingen',
    'auto_email_invoice' => 'Automatisch e-mailen',
    'auto_email_invoice_help' => 'Verzend terugkerende facturen automatisch wanneer ze worden gemaakt.',
    'auto_archive_invoice' => 'Automatisch archiveren',
    'auto_archive_invoice_help' => 'Facturen automatisch archiveren wanneer ze worden betaald.',
    'auto_archive_quote' => 'Automatisch archiveren',
    'auto_archive_quote_help' => 'Offertes automatisch archiveren wanneer ze zijn omgezet.',
    'require_approve_quote' => 'Verplicht goedkeuring offerte',
    'require_approve_quote_help' => 'Verplicht klanten om offertes goed te keuren.',
    'allow_approve_expired_quote' => 'Toestaan verlopen offerte goedkeuren',
    'allow_approve_expired_quote_help' => 'Toestaan klanten verlopen offerte goedkeuren',
    'invoice_workflow' => 'Factuur workflow',
    'quote_workflow' => 'Offerte workflow',
    'client_must_be_active' => 'Fout: de klant moet actief zijn',
    'purge_client' => 'Wis klant',
    'purged_client' => 'De klant is gewist',
    'purge_client_warning' => 'Alle gerelateerde gegevens (facturen, taken, uitgaven, documenten, enz.) worden ook gewist.',
    'clone_product' => 'Dupliceer product',
    'item_details' => 'Onderdeel details',
    'send_item_details_help' => 'Verzend regelitemdetails naar de betalingsgateway.',
    'view_proposal' => 'Toon voorstel',
    'view_in_portal' => 'Toon in portaal',
    'cookie_message' => 'Deze website maakt gebruik van cookies om ervoor te zorgen dat u de beste ervaring op onze website krijgt.',
    'got_it' => 'Begrepen!',
    'vendor_will_create' => 'leverancier zal worden gemaakt',
    'vendors_will_create' => 'leveranciers zullen aangemaakt worden',
    'created_vendors' => 'Succesvol :count leverancier(s) aangemaakt',
    'import_vendors' => 'Leveranciers importeren',
    'company' => 'Bedrijf',
    'client_field' => 'Klant veld',
    'contact_field' => 'Contact veld',
    'product_field' => 'Productveld',
    'task_field' => 'Taak veld',
    'project_field' => 'Project veld',
    'expense_field' => 'Uitgave veld',
    'vendor_field' => 'Leverancier veld',
    'company_field' => 'Bedrijf veld',
    'invoice_field' => 'Factuur veld',
    'invoice_surcharge' => 'Factuurkost',
    'custom_task_fields_help' => 'Voeg een veld toe bij het maken van een taak.',
    'custom_project_fields_help' => 'Voeg een veld toe bij het maken van een project.',
    'custom_expense_fields_help' => 'Voeg een veld toe bij het maken van een uitgave.',
    'custom_vendor_fields_help' => 'Voeg een veld toe bij het maken van een leverancier.',
    'messages' => 'Berichten',
    'unpaid_invoice' => 'Onbetaalde factuur',
    'paid_invoice' => 'Betaalde factuur',
    'unapproved_quote' => 'Niet goedgekeurde offerte',
    'unapproved_proposal' => 'Niet goedgekeurd voorstel',
    'autofills_city_state' => 'Vult stad/staat automatisch aan',
    'no_match_found' => 'Geen overeenkomst gevonden',
    'password_strength' => 'Wachtwoordsterkte',
    'strength_weak' => 'Zwak',
    'strength_good' => 'Goed',
    'strength_strong' => 'Sterk',
    'mark' => 'Markeer',
    'updated_task_status' => 'De taak is gewijzigd',
    'background_image' => 'Achtergrondafbeelding',
    'background_image_help' => 'Gebruik de :link om uw afbeeldingen te beheren, we raden aan een klein bestand te gebruiken.',
    'proposal_editor' => 'voorstel editor',
    'background' => 'Achtergrond',
    'guide' => 'Gids',
    'gateway_fee_item' => 'Heffingsitem Gateway',
    'gateway_fee_description' => 'Heffingstoeslag Gateway',
    'gateway_fee_discount_description' => 'Heffingskorting Gateway',
    'show_payments' => 'Toon betalingen',
    'show_aging' => 'Toon toekomstige',
    'reference' => 'Referentie',
    'amount_paid' => 'Betaald bedrag',
    'send_notifications_for' => 'Stuur notificaties van',
    'all_invoices' => 'Alle facturen',
    'my_invoices' => 'Mijn facturen',
    'payment_reference' => 'Betalingsreferentie',
    'maximum' => 'Maximaal',
    'sort' => 'Sorteer',
    'refresh_complete' => 'Verversen afgerond',
    'please_enter_your_email' => 'Gelieve uw e-maildres in te vullen',
    'please_enter_your_password' => 'Gelieve uw wachtwoord in te voeren',
    'please_enter_your_url' => 'Gelieve uw URL in te voeren',
    'please_enter_a_product_key' => 'Gelieve een productcode in te voeren',
    'an_error_occurred' => 'Er is een fout opgetreden',
    'overview' => 'Overzicht',
    'copied_to_clipboard' => 'Waarde :value naar klembord gekopieerd',
    'error' => 'Fout',
    'could_not_launch' => 'Kon niet starten',
    'additional' => 'Extra',
    'ok' => 'OK',
    'email_is_invalid' => 'E-mailadres is incorrect',
    'items' => 'Artikelen',
    'partial_deposit' => 'Voorschot',
    'add_item' => 'Artikel toevoegen',
    'total_amount' => 'Totaal hoeveelheid',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Factuurstatus',
    'click_plus_to_add_item' => 'Klik op + om een artikel toe te voegen',
    'count_selected' => ':count geselecteerd',
    'dismiss' => 'Seponeren',
    'please_select_a_date' => 'Gelieve een datum selecteren',
    'please_select_a_client' => 'Gelieve een klant te selecteren',
    'language' => 'Taal',
    'updated_at' => 'Bijgewerkt',
    'please_enter_an_invoice_number' => 'Gelieve een factuurnummer in te voeren',
    'please_enter_a_quote_number' => 'Gelieve een offertenummer in te voeren',
    'clients_invoices' => ':client\'s facturen',
    'viewed' => 'Bekenen',
    'approved' => 'Goedgekeurd',
    'invoice_status_1' => 'Concept',
    'invoice_status_2' => 'Verstuurd',
    'invoice_status_3' => 'Bekenen',
    'invoice_status_4' => 'Goedgekeurd',
    'invoice_status_5' => 'Gedeeltelijk',
    'invoice_status_6' => 'Betaald',
    'marked_invoice_as_sent' => 'De factuur is gemarkeerd als verzonden',
    'please_enter_a_client_or_contact_name' => 'Gelieve een bedrijfsnaam of contactpersoon in te voeren',
    'restart_app_to_apply_change' => 'Herstart de applicatie om de wijziging toe te passen',
    'refresh_data' => 'Gegevens verversen',
    'blank_contact' => 'Leeg contact',
    'no_records_found' => 'Geen gegevens gevonden',
    'industry' => 'Industrie',
    'size' => 'Grootte',
    'net' => 'Betaaltermijn',
    'show_tasks' => 'Toon taken',
    'email_reminders' => 'E-mail herinneringen',
    'reminder1' => 'Eerste herinnering',
    'reminder2' => 'Tweede herinnering',
    'reminder3' => 'Derde herinnering',
    'send' => 'Verstuur',
    'auto_billing' => 'Automatisch incasseren',
    'button' => 'Knop',
    'more' => 'Meer',
    'edit_recurring_invoice' => 'Bewerk terugkerende factuur',
    'edit_recurring_quote' => 'Bewerk terugkerende offerte',
    'quote_status' => 'Offertestatus',
    'please_select_an_invoice' => 'Selecteer een factuur',
    'filtered_by' => 'Gefilterd op',
    'payment_status' => 'Betaalstatus',
    'payment_status_1' => 'In afwachting',
    'payment_status_2' => 'Ongeldig',
    'payment_status_3' => 'Mislukt',
    'payment_status_4' => 'Voltooid',
    'payment_status_5' => 'Deels terugbetaald',
    'payment_status_6' => 'Gecrediteerd',
    'send_receipt_to_client' => 'Verzend ontvangstbewijs naar de klant',
    'refunded' => 'Gecrediteerd',
    'marked_quote_as_sent' => 'De offerte is  gemarkeerd als verzonden',
    'custom_module_settings' => 'Aangepaste module-instellingen',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticketnummer',
    'new_ticket' => 'Nieuw ticket',
    'edit_ticket' => 'Bewerk ticket',
    'view_ticket' => 'Bekijk ticket',
    'archive_ticket' => 'Archiveer ticket',
    'restore_ticket' => 'Herstel ticket',
    'delete_ticket' => 'Verwijder ticket',
    'archived_ticket' => 'Het ticket is gearchiveerd',
    'archived_tickets' => 'De tickets zijn gearchiveerd',
    'restored_ticket' => 'Het ticket is teruggezet',
    'deleted_ticket' => 'Het ticket is verwijderd',
    'open' => 'Open',
    'new' => 'Nieuw',
    'closed' => 'Gesloten',
    'reopened' => 'Heropend',
    'priority' => 'Prioriteit',
    'last_updated' => 'Laatst bijgewerkt',
    'comment' => 'Opmerkingen',
    'tags' => 'Tags',
    'linked_objects' => 'Gelinkte objecten',
    'low' => 'Laag',
    'medium' => 'Middel',
    'high' => 'Hoog',
    'no_due_date' => 'Geen vervaldatum ingesteld',
    'assigned_to' => 'Toegewezen aan',
    'reply' => 'Antwoord',
    'awaiting_reply' => 'In afwachting van antwoord',
    'ticket_close' => 'Sluit ticket',
    'ticket_reopen' => 'Heropen ticket',
    'ticket_open' => 'Open ticket',
    'ticket_split' => 'Splits ticket',
    'ticket_merge' => 'Ticket samenvoegen',
    'ticket_update' => 'Werk ticket bij',
    'ticket_settings' => 'Ticket instellingen',
    'updated_ticket' => 'Ticket bijgewerkt',
    'mark_spam' => 'Markeer als spam',
    'local_part' => 'Lokaal gedeelte',
    'local_part_unavailable' => 'Naam reeds in gebruik',
    'local_part_available' => 'Naam beschikbaar',
    'local_part_invalid' => 'Ongeldige naam (alleen alfanumeriek, geen spaties',
    'local_part_help' => 'Personaliseer het eerste deel van het inkomende e-mailadres, vb. YOUR_NAME@support.invoiceninja',
    'from_name_help' => 'De \'van\'-naam is de herkenbare afzender die wordt getoond in plaats van het e-mailadres, zoals Helpdesk',
    'local_part_placeholder' => 'JOUW_NAAM',
    'from_name_placeholder' => 'Support centrum',
    'attachments' => 'Bijlagen',
    'client_upload' => 'Klant uploads',
    'enable_client_upload_help' => 'Laat klanten documenten/bijlagen uploaden',
    'max_file_size_help' => 'Maximale bestandsgrootte (KB) wordt beperkt door de post_max_size en upload_max_filesize variabelen zoals ingesteld in uw PHP.INI',
    'max_file_size' => 'Maximale bestandsgrootte',
    'mime_types' => 'MIME-types',
    'mime_types_placeholder' => '.pdf, .docx, .jpg',
    'mime_types_help' => 'Komma-gescheiden lijst met toegestane MIME-types, laat leeg voor alle',
    'ticket_number_start_help' => 'Het ticketnummer moet groter zijn dan het huidige ticket nummer',
    'new_ticket_template_id' => 'Nieuw ticket',
    'new_ticket_autoresponder_help' => 'Het selecteren van een sjabloon zal ertoe leiden dat een automatische reactie wordt gestuurd naar de klant/contact wanneer een nieuw ticket wordt aangemaakt',
    'update_ticket_template_id' => 'Bijgewerkt ticket',
    'update_ticket_autoresponder_help' => 'Het selecteren van een sjabloon zal ertoe leiden dat een automatische reactie wordt verstuurd naar de klant/contact wanneer een ticket wordt bijgewerkt',
    'close_ticket_template_id' => 'Gesloten ticket',
    'close_ticket_autoresponder_help' => 'Het selecteren van een sjabloon zal ertoe leiden dat een automatische reactie wordt verstuurd naar de klant/contact wanneer een ticket wordt gesloten',
    'default_priority' => 'Prioriteit',
    'alert_new_comment_id' => 'Nieuwe opmerking',
    'alert_comment_ticket_help' => 'Het selecteren van een sjabloon zal een notificatie versturen (naar de agent) zodra een opmerking is geplaatst.',
    'alert_comment_ticket_email_help' => 'E-mailadressen gescheiden met een komma waar een notificatie in BCC naar gestuurd zal worden bij nieuwe reacties.',
    'new_ticket_notification_list' => 'Additionele notificaties bij nieuwe tickets',
    'update_ticket_notification_list' => 'Additionele notificaties bij nieuwe opmerkingen',
    'comma_separated_values' => 'admin@voorbeeld.com, beheerder@voorbeeld.com',
    'alert_ticket_assign_agent_id' => 'Tickettoewijzing',
    'alert_ticket_assign_agent_id_hel' => 'Het selecteren van een sjabloon zal een notificatie versturen (naar de agent) zodra een ticket is toegewezen.',
    'alert_ticket_assign_agent_id_notifications' => 'Additionele notificaties bij tickettoewijzigingen',
    'alert_ticket_assign_agent_id_help' => 'E-mailadressen gescheiden met een komma waar een notificatie in BCC naar gestuurd zal worden bij nieuwe tickettoewijzingen.',
    'alert_ticket_transfer_email_help' => 'E-mailadressen gescheiden met een komma waar een notificatie in BCC naar gestuurd zal worden bij het overdragen van tickets.',
    'alert_ticket_overdue_agent_id' => 'Ticket over tijd',
    'alert_ticket_overdue_email' => 'Additionele notificaties bij achterstallige tickets',
    'alert_ticket_overdue_email_help' => 'E-mailadressen gescheiden met een komma waar een notificatie in BCC naar gestuurd zal worden bij achterstallige tickets.',
    'alert_ticket_overdue_agent_id_help' => 'Het selecteren van een sjabloon zal een notificatie versturen (naar de agent) zodra een ticket achterstallig wordt.',
    'ticket_master' => 'Ticketmaster',
    'ticket_master_help' => 'Heeft de mogelijkheid om tickets toe te wijzen en over te dragen. Toegewezen als de standaard agent voor alle tickets.',
    'default_agent' => 'Agent',
    'default_agent_help' => 'Zal bij selectie automatisch toegewezen worden aan alle binnenkomende tickets',
    'show_agent_details' => 'Toon details van de agent bij reacties',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Verwijder avatar',
    'ticket_not_found' => 'Ticket niet gevonden',
    'add_template' => 'Sjabloon toevoegen',
    'ticket_template' => 'Ticketsjabloon',
    'ticket_templates' => 'Ticketsjablonen',
    'updated_ticket_template' => 'Ticketsjabloon gewijzigd',
    'created_ticket_template' => 'Ticketsjabloon aangemaakt',
    'archive_ticket_template' => 'Archiveer sjabloon',
    'restore_ticket_template' => 'Herstel sjabloon',
    'archived_ticket_template' => 'Het sjabloon is gearchiveerd',
    'restored_ticket_template' => 'Het sjabloon is hersteld',
    'close_reason' => 'Laat ons weten waarom u dit ticket sluit',
    'reopen_reason' => 'Laat ons weten waarom u dit ticket heropent',
    'enter_ticket_message' => 'Gelieve een bericht in te geven om het ticket aan te passen',
    'show_hide_all' => 'Toon / verberg alles',
    'subject_required' => 'Onderwerp vereist',
    'mobile_refresh_warning' => 'Als u de mobiele app gebruikt, moet u mogelijk een volledige vernieuwing uitvoeren.',
    'enable_proposals_for_background' => 'Een achtergrondafbeelding uploaden :link om de voorstellenmodule in te schakelen.',
    'ticket_assignment' => 'Ticket :ticket_number is toegewezen aan :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number is bijgewerkt door klant :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number is aangemaakt.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number is bijgewerkt.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number is gesloten.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is nu achterstallig',
    'merge' => 'Samenvoegen',
    'merged' => 'Samengevoegd',
    'agent' => 'Agent',
    'parent_ticket' => 'Hoofdticket',
    'linked_tickets' => 'Gelinkte tickets',
    'merge_prompt' => 'Voer ticketnummer in om met samen te voegen',
    'merge_from_to' => 'Ticket #:old_ticket is samengevoegd met ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket :#old_ticket is gesloten en samengevoegd met ticket #:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket is gesloten en samengevoegd met dit ticket',
    'merge_placeholder' => 'Ticket #:ticket samenvoegen met het volgende ticket',
    'select_ticket' => 'Selecteer een ticket',
    'new_internal_ticket' => 'Nieuw intern ticket',
    'internal_ticket' => 'Intern ticket',
    'create_ticket' => 'Creëer ticket',
    'allow_inbound_email_tickets_external' => 'Nieuwe tickets per e-mail (klant)',
    'allow_inbound_email_tickets_external_help' => 'Laat klanten per e-mail nieuwe tickets aanmaken',
    'include_in_filter' => 'Opnemen in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Vergelijk',
    'hosted_login' => 'Hosted login',
    'selfhost_login' => 'Self-Host login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Bedankt voor uw geduld zolang we werken om deze functionaliteiten te implementeren.\n\nWe hopen dit in de komende maanden klaar te hebben.\n\nTot die tijd ondersteunen we',
    'legacy_mobile_app' => 'oude mobiele app',
    'today' => 'Vandaag',
    'current' => 'Huidige',
    'previous' => 'Vorige',
    'current_period' => 'Huidige Periode',
    'comparison_period' => 'Periode om mee te vergelijken',
    'previous_period' => 'Vorige Periode',
    'previous_year' => 'Vorig jaar',
    'compare_to' => 'Vergelijk met',
    'last_week' => 'Afgelopen week',
    'clone_to_invoice' => 'Dupliceer als factuur',
    'clone_to_quote' => 'Dupliceer als offerte',
    'convert' => 'Converteer',
    'last7_days' => 'Laatste 7 dagen',
    'last30_days' => 'Laatste 30 Dagen',
    'custom_js' => 'Aangepaste JS',
    'adjust_fee_percent_help' => 'Pas percentage aan om rekening te houden met de kosten',
    'show_product_notes' => 'Toon productdetails',
    'show_product_notes_help' => 'Voeg de <b>beschrijving en kosten</b> toe aan de productkeuzelijst',
    'important' => 'Belangrijk',
    'thank_you_for_using_our_app' => 'Bedankt voor het gebruik van onze app!',
    'if_you_like_it' => 'Als je het leuk vindt alsjeblieft ',
    'to_rate_it' => 'om een score te geven.',
    'average' => 'Gemiddeld',
    'unapproved' => 'Afgekeurd',
    'authenticate_to_change_setting' => 'Gelieve te authenticeren om deze instelling te wijzigen',
    'locked' => 'Vergrendeld',
    'authenticate' => 'Authenticeer',
    'please_authenticate' => 'Gelieve te authenticeren',
    'biometric_authentication' => 'Biometrische authenticatie',
    'auto_start_tasks' => 'Automatisch Startende Taken',
    'budgeted' => 'Begroot',
    'please_enter_a_name' => 'Geef a.u.b. een naam op',
    'click_plus_to_add_time' => 'Klik + om tijd toe te voegen',
    'design' => 'Ontwerp',
    'password_is_too_short' => 'Wachtwoord is te kort',
    'failed_to_find_record' => 'Geen gegeven gevonden',
    'valid_until_days' => 'Geldig tot',
    'valid_until_days_help' => 'Vult automatisch de waarde <b>Geldig tot</b> in op offertes voor dit aantal dagen in de toekomst. Laat leeg om uit te schakelen.',
    'usually_pays_in_days' => 'Dagen',
    'requires_an_enterprise_plan' => 'Vereist een enterprise plan',
    'take_picture' => 'Maak foto',
    'upload_file' => 'Upload bestand',
    'new_document' => 'Nieuw document',
    'edit_document' => 'Bewerk Document',
    'uploaded_document' => 'Document is geupload',
    'updated_document' => 'Het document is bijgewerkt',
    'archived_document' => 'Het document is gearchiveerd',
    'deleted_document' => 'Het document is verwijderd',
    'restored_document' => 'Het document is hersteld',
    'no_history' => 'Geen geschiedenis',
    'expense_status_1' => 'Gelogged',
    'expense_status_2' => 'In afwachting',
    'expense_status_3' => 'Gefactureerd',
    'no_record_selected' => 'Geen records geselecteerd',
    'error_unsaved_changes' => 'Bewaar of annuleer de wijzigingen',
    'thank_you_for_your_purchase' => 'Bedankt voor uw aankoop!',
    'redeem' => 'Verzilver',
    'back' => 'Terug',
    'past_purchases' => 'Voorbije aankopen',
    'annual_subscription' => 'Jaarlijks abonnement',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count gebruikers',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Vul een voornaam in aub',
    'please_enter_a_last_name' => 'Vul een naam in aub',
    'please_agree_to_terms_and_privacy' => 'Ga akkoord met de servicevoorwaarden en het privacybeleid om een account aan te maken.',
    'i_agree_to_the' => 'Ik ga akkoord met',
    'terms_of_service_link' => 'de servicevoorwaarden',
    'privacy_policy_link' => 'het privacybeleid',
    'view_website' => 'Bekijk website',
    'create_account' => 'Account aanmaken',
    'email_login' => 'Email login',
    'late_fees' => 'Late vergoedingen',
    'payment_number' => 'Betalingsnummer',
    'before_due_date' => 'Voor de vervaldatum',
    'after_due_date' => 'Na de vervaldatum',
    'after_invoice_date' => 'na de factuurdatum',
    'filtered_by_user' => 'Gefilterd door gebruiker',
    'created_user' => 'De gebruiker is aangemaakt',
    'primary_font' => 'Primair lettertype',
    'secondary_font' => 'Secundair lettertype',
    'number_padding' => 'Nummer afstand',
    'general' => 'Algemeen',
    'surcharge_field' => 'Extra toeslag veld',
    'company_value' => 'Bedrijfswaarde',
    'credit_field' => 'Credit veld',
    'payment_field' => 'Betaalveld',
    'group_field' => 'Groepsveld',
    'number_counter' => 'Nummerteller',
    'number_pattern' => 'Nummer patroon',
    'custom_javascript' => 'Zelfgeschreven JavaScript',
    'portal_mode' => 'portaalmodus',
    'attach_pdf' => 'PDF bijlvoegen',
    'attach_documents' => 'Document bijvoegen',
    'attach_ubl' => 'UBL bijvoegen',
    'email_style' => 'Email opmaak',
    'processed' => 'Verwerkt',
    'fee_amount' => 'Vergoedingsbedrag',
    'fee_percent' => 'Vergoedingspercentage',
    'fee_cap' => 'Maximale vergoeding',
    'limits_and_fees' => 'limiet/vergoedingen',
    'credentials' => 'Gegevens',
    'require_billing_address_help' => 'Verplicht de klant om zijn factuuradres op te geven',
    'require_shipping_address_help' => 'Verplicht de klant om zijn verzendadres op te geven',
    'deleted_tax_rate' => 'De BTW heffing is verwijderd',
    'restored_tax_rate' => 'De BTW heffing is teruggezet',
    'provider' => 'Provider',
    'company_gateway' => 'Betalingsgateway',
    'company_gateways' => 'Betalingsgateway',
    'new_company_gateway' => 'Nieuwe instantie aanmaken',
    'edit_company_gateway' => 'Huidige instantie bewerken',
    'created_company_gateway' => 'De nieuwe instantie is aangemaakt',
    'updated_company_gateway' => 'De nieuwe instantie is bijgewerkt',
    'archived_company_gateway' => 'De nieuwe instantie is gearchiveerd',
    'deleted_company_gateway' => 'De nieuwe instantie is verwijderd',
    'restored_company_gateway' => 'De nieuwe instantie is hersteld',
    'continue_editing' => 'Bewerk verder',
    'default_value' => 'Standaard waarde',
    'currency_format' => 'Munt formaat',
    'first_day_of_the_week' => 'Eerste dag van de week',
    'first_month_of_the_year' => 'Eerste maand van het jaar',
    'symbol' => 'Symbool',
    'ocde' => 'Code',
    'date_format' => 'Datum formaat',
    'datetime_format' => 'Datum/tijd opmaak',
    'send_reminders' => 'Verstuur herinneringen',
    'timezone' => 'Tijdzone',
    'filtered_by_group' => 'Filteren op groep',
    'filtered_by_invoice' => 'Filteren op factuur',
    'filtered_by_client' => 'Filteren op klant',
    'filtered_by_vendor' => 'Filteren op leverancier',
    'group_settings' => 'Groepsinstellingen',
    'groups' => 'Groep',
    'new_group' => 'Nieuwe groep',
    'edit_group' => 'Wijzig groep',
    'created_group' => 'Nieuwe groep aangemaakt',
    'updated_group' => 'Groep gewijzigd',
    'archived_group' => 'Groep gearchiveerd',
    'deleted_group' => 'Groep verwijderd',
    'restored_group' => 'De groep is hersteld',
    'upload_logo' => 'Upload logo',
    'uploaded_logo' => 'Het logo is opgeslagen',
    'saved_settings' => 'De instellingen zijn opgeslagen',
    'device_settings' => 'Apparaatinstellingen',
    'credit_cards_and_banks' => 'Credit Cards & Banken',
    'price' => 'Prijs',
    'email_sign_up' => 'Aanmelden voor email',
    'google_sign_up' => 'Aanmelden bij Google',
    'sign_up_with_google' => 'Aanmelden met Google',
    'long_press_multiselect' => 'Lang indrukken multiselect',
    'migrate_to_next_version' => 'Migreer naar de volgende versie van Invoice Ninja.',
    'migrate_intro_text' => 'We hebben gewerkt aan de volgende versie van Invoice Ninja. Klik op de knop hieronder om de migratie te starten.',
    'start_the_migration' => 'Start de migratie',
    'migration' => 'Migratie',
    'welcome_to_the_new_version' => 'Welkom bij de nieuwe versie van Invoice Ninja',
    'next_step_data_download' => 'Bij de volgende stap laten we u uw gegevens voor de migratie downloaden.',
    'download_data' => 'Klik op de knop hieronder om de data te downloaden. ',
    'migration_import' => 'Geweldig! Nu ben je klaar om je migratie te importeren. Ga naar je nieuwe installatie om je data te importeren. ',
    'continue' => 'Doorgaan',
    'company1' => 'Aangepast bedrijf 1',
    'company2' => 'Aangepast bedrijf 2',
    'company3' => 'Aangepast bedrijf 3',
    'company4' => 'Aangepast bedrijf 4',
    'product1' => 'Aangepast product 1',
    'product2' => 'Aangepast product 2',
    'product3' => 'Aangepast product 3',
    'product4' => 'Aangepast product 4',
    'client1' => 'Aangepast cliënt 1',
    'client2' => 'Aangepast cliënt 2',
    'client3' => 'Aangepast cliënt 3',
    'client4' => 'Aangepast cliënt 4',
    'contact1' => 'Aangepast Contact 1',
    'contact2' => 'Aangepast Contact 2',
    'contact3' => 'Aangepast Contact 3',
    'contact4' => 'Aangepast Contact 4',
    'task1' => 'Aangepaste Taak 1',
    'task2' => 'Aangepaste Taak 2',
    'task3' => 'Aangepaste Taak 3',
    'task4' => 'Aangepaste Taak 4',
    'project1' => 'Aangepast Project 1',
    'project2' => 'Aangepast Project 2',
    'project3' => 'Aangepast Project 3',
    'project4' => 'Aangepast Project 4',
    'expense1' => 'Aangepaste Uitgave 1',
    'expense2' => 'Aangepaste Uitgave 2',
    'expense3' => 'Aangepaste Uitgave 3',
    'expense4' => 'Aangepaste Uitgave 4',
    'vendor1' => 'Aangepaste Aanbieder 1',
    'vendor2' => 'Aangepaste Aanbieder 2',
    'vendor3' => 'Aangepaste Aanbieder 3',
    'vendor4' => 'Aangepaste Aanbieder 4',
    'invoice1' => 'Aangepaste Factuur 1',
    'invoice2' => 'Aangepaste Factuur 2',
    'invoice3' => 'Aangepaste Factuur 3',
    'invoice4' => 'Aangepaste Factuur 4',
    'payment1' => 'Aangepaste Betaling 1',
    'payment2' => 'Aangepaste Betaling 2',
    'payment3' => 'Aangepaste Betaling 3',
    'payment4' => 'Aangepaste Betaling 4',
    'surcharge1' => 'Aangepaste Toeslag 1',
    'surcharge2' => 'Aangepaste Toeslag 2',
    'surcharge3' => 'Aangepaste Toeslag 3',
    'surcharge4' => 'Aangepaste Toeslag 4',
    'group1' => 'Aangepaste Groep 1',
    'group2' => 'Aangepaste Groep 2',
    'group3' => 'Aangepaste Groep 3',
    'group4' => 'Aangepaste Groep 4',
    'number' => 'Nummer',
    'count' => 'Telling',
    'is_active' => 'Is actief',
    'contact_last_login' => 'Contact laatste Login',
    'contact_full_name' => 'Contact Volledige Naam',
    'contact_custom_value1' => 'Contact aangepaste waarde 1',
    'contact_custom_value2' => 'Contact aangepaste waarde 2',
    'contact_custom_value3' => 'Contact aangepaste waarde 3',
    'contact_custom_value4' => 'Contact aangepaste waarde 4',
    'assigned_to_id' => 'Toegekend aan ID',
    'created_by_id' => 'Gemaakt door ID',
    'add_column' => 'Voeg kolom toe',
    'edit_columns' => 'Wijzig kolom',
    'to_learn_about_gogle_fonts' => 'leer over Google Fonts',
    'refund_date' => 'Terugbetaling datum',
    'multiselect' => 'Multiselectie',
    'verify_password' => 'Verifieer wachtwoord',
    'applied' => 'Toegepast',
    'include_recent_errors' => 'Voeg recente fouten uit de logboeken toe',
    'your_message_has_been_received' => 'We hebben uw bericht ontvangen, en zullen zo spoedig mogelijk reageren. ',
    'show_product_details' => 'toon product details',
    'show_product_details_help' => 'Neem de beschrijving en kosten op in de vervolgkeuzelijst met producten',
    'pdf_min_requirements' => 'De PDF renderaar vereist :version',
    'adjust_fee_percent' => 'Pas Vergoedingspercentage Aan',
    'configure_settings' => 'Instellingen configureren',
    'about' => 'Over',
    'credit_email' => 'Krediet E-mail',
    'domain_url' => 'Domein URL',
    'password_is_too_easy' => 'Het wachtwoord moet een hoofdletter en een nummer bevatten',
    'client_portal_tasks' => 'Klantenportaal taken',
    'client_portal_dashboard' => 'Klantenportaal dashboard',
    'please_enter_a_value' => 'Voer alstublieft een waarde in',
    'deleted_logo' => 'Logo verwijderd',
    'generate_number' => 'Genereer nummer',
    'when_saved' => 'Als opgeslagen',
    'when_sent' => 'Als verzonden',
    'select_company' => 'Selecteer Bedrijf',
    'float' => 'Float',
    'collapse' => 'Inklappen',
    'show_or_hide' => 'Laten zien/Verbergen',
    'menu_sidebar' => 'Menu Zijbalk',
    'history_sidebar' => 'Geschiedenis Zijbalk',
    'tablet' => 'Tablet',
    'layout' => 'Indeling',
    'module' => 'Module',
    'first_custom' => 'Eerste aangepaste',
    'second_custom' => 'Tweede aangepaste',
    'third_custom' => 'Derde aangepaste',
    'show_cost' => 'Toon kosten',
    'show_cost_help' => 'Toon het kostenveld van een product om de opmaak / winst te volgen',
    'show_product_quantity' => 'Toon product hoeveelheid',
    'show_product_quantity_help' => 'Toon aantallen voor producten, anders de standaard versie',
    'show_invoice_quantity' => 'Toon factuur aantallen',
    'show_invoice_quantity_help' => 'Toon aantallen voor regelitem, anders de standaard versie',
    'default_quantity' => 'Standaard aantallen',
    'default_quantity_help' => 'Stel de producthoeveelheid automatisch in op 1',
    'one_tax_rate' => 'Eerste BTW-tarief',
    'two_tax_rates' => 'Tweede BTW-tarief',
    'three_tax_rates' => 'Derde BTW-tarief',
    'default_tax_rate' => 'Standaard BTW-tarief',
    'invoice_tax' => 'Factuur BTW-tarief',
    'line_item_tax' => 'Regelitem BTW-tarief',
    'inclusive_taxes' => 'Inclusief belasting',
    'invoice_tax_rates' => 'Factuur belastingtarief',
    'item_tax_rates' => 'Product belastingtarief',
    'configure_rates' => 'Tarieven instellen',
    'tax_settings_rates' => 'BTW-tarieven',
    'accent_color' => 'Accent Kleur',
    'comma_sparated_list' => 'Komma gescheiden lijst',
    'single_line_text' => 'Eenregelige tekst',
    'multi_line_text' => 'Multi-regelige tekst',
    'dropdown' => 'Dropdwon',
    'field_type' => 'Veld type',
    'recover_password_email_sent' => 'Een wachtwoord herstel mail is verzonden',
    'removed_user' => 'Gebruiker verwijderd',
    'freq_three_years' => 'Drie jaar',
    'military_time_help' => '24-uurs weergave',
    'click_here_capital' => 'Klik hier',
    'marked_invoice_as_paid' => 'Factuur succesvol gemarkeerd als verzonden',
    'marked_invoices_as_sent' => 'Facturen gemarkeerd als verzonden',
    'marked_invoices_as_paid' => 'Facturen succesvol gemarkeerd als verzonden',
    'activity_57' => 'Systeem kon de factuur niet mailen :invoice',
    'custom_value3' => 'Aangepaste waarde 3',
    'custom_value4' => 'Aangepaste waarde 4',
    'email_style_custom' => 'Aangepaste Email Stijl',
    'custom_message_dashboard' => 'Aangepast bericht Dashboard',
    'custom_message_unpaid_invoice' => 'Aangepast bericht Onbetaalde Factuur',
    'custom_message_paid_invoice' => 'Aangepast bericht Betaalde Factuur',
    'custom_message_unapproved_quote' => 'Aangepast bericht Niet goedgekeurde Offerte',
    'lock_sent_invoices' => 'Vergrendel verzonden facturen',
    'translations' => 'Vertalingen',
    'task_number_pattern' => 'Taaknummer patroon',
    'task_number_counter' => 'Taaknummer teller',
    'expense_number_pattern' => 'Uitgave nummer patroon',
    'expense_number_counter' => 'Uitgave nummer teller',
    'vendor_number_pattern' => 'Leverancier nummer patroon',
    'vendor_number_counter' => 'Leverancier nummer teller',
    'ticket_number_pattern' => 'Ticket nummer patroon',
    'ticket_number_counter' => 'Ticket nummer teller',
    'payment_number_pattern' => 'Betalingsnummer patroon',
    'payment_number_counter' => 'Betalingsnummer teller',
    'invoice_number_pattern' => 'Factuur nummer patroon',
    'quote_number_pattern' => 'Offertenummer teller',
    'client_number_pattern' => 'Kredietnummer patroon',
    'client_number_counter' => 'Kredietnummer teller',
    'credit_number_pattern' => 'Kredietnummer patroon',
    'credit_number_counter' => 'Kredietnummer teller',
    'reset_counter_date' => 'Teller datum resetten',
    'counter_padding' => 'Teller patroon',
    'shared_invoice_quote_counter' => 'Gedeelde factuur offerte teller',
    'default_tax_name_1' => 'Standaard BTW naam 1',
    'default_tax_rate_1' => 'Standaard BTW-tarief 1',
    'default_tax_name_2' => 'Standaard BTW naam 2',
    'default_tax_rate_2' => 'Standaard BTW-tarief 2',
    'default_tax_name_3' => 'Standaard BTW naam 3',
    'default_tax_rate_3' => 'Standaard BTW-tarief 3',
    'email_subject_invoice' => 'E-mail factuur onderwerp',
    'email_subject_quote' => 'E-mail offerte onderwerp',
    'email_subject_payment' => 'E-mail betaling onderwerp',
    'switch_list_table' => 'Overschakelen naar lijst tabel',
    'client_city' => 'Klant stad',
    'client_state' => 'Klant provincie',
    'client_country' => 'Land van de klant',
    'client_is_active' => 'Klant is actief',
    'client_balance' => 'Klanten balans',
    'client_address1' => 'Klant straat',
    'client_address2' => 'Klant apt/suite',
    'client_shipping_address1' => 'Klant leveringsadres',
    'client_shipping_address2' => 'Klant leverings Apt/Suite',
    'tax_rate1' => 'BTW-tarief 1',
    'tax_rate2' => 'BTW-tarief 2',
    'tax_rate3' => 'BTW-tarief 3',
    'archived_at' => 'Gearchiveerd op',
    'has_expenses' => 'Heeft uitgaves',
    'custom_taxes1' => 'Aangepaste Belastingen 1',
    'custom_taxes2' => 'Aangepaste Belastingen 2',
    'custom_taxes3' => 'Aangepaste Belastingen 3',
    'custom_taxes4' => 'Aangepaste Belastingen 4',
    'custom_surcharge1' => 'Aangepaste Toeslag 1',
    'custom_surcharge2' => 'Aangepaste Toeslag 2',
    'custom_surcharge3' => 'Aangepaste Toeslag 3',
    'custom_surcharge4' => 'Aangepaste Toeslag 4',
    'is_deleted' => 'Is verwijderd',
    'vendor_city' => 'Stad van de klant',
    'vendor_state' => 'Leverancier provincie',
    'vendor_country' => 'Land van de verkoper',
    'credit_footer' => 'Krediet voettekst',
    'credit_terms' => 'Kredietvoorwaarden',
    'untitled_company' => 'Naamloos bedrijf',
    'added_company' => 'Bedrijf toegevoegd',
    'supported_events' => 'Ondersteunde gebeurtenissen',
    'custom3' => 'Derde aangepaste',
    'custom4' => 'Vierde aangepaste',
    'optional' => 'Optioneel',
    'license' => 'Licentie',
    'invoice_balance' => 'Factuur balans',
    'saved_design' => 'Ontwerp opgeslagen',
    'client_details' => 'Klantgegevens',
    'company_address' => 'Bedrijfs-adres',
    'quote_details' => 'Offerte Details',
    'credit_details' => 'Kredietgegevens',
    'product_columns' => 'Product kolommen',
    'task_columns' => 'Taak kolommen',
    'add_field' => 'Veld toevoegen',
    'all_events' => 'Alle gebeurtenissen',
    'owned' => 'Eigendom',
    'payment_success' => 'Betaling is gelukt',
    'payment_failure' => 'Betalingsfout',
    'quote_sent' => 'Offerte Verzonden',
    'credit_sent' => 'Factuur verzonden',
    'invoice_viewed' => 'Factuur bekeken',
    'quote_viewed' => 'Offerte Bekeken',
    'credit_viewed' => 'Krediet bekeken',
    'quote_approved' => 'Offerte Goedgekeurd',
    'receive_all_notifications' => 'Ontvang alle notificaties',
    'purchase_license' => 'Licentie aanschaffen',
    'enable_modules' => 'Modules inschakelen',
    'converted_quote' => 'Offerte omgezet',
    'credit_design' => 'Krediet ontwerp',
    'includes' => 'Inclusief',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Aangepaste Ontwerpen',
    'designs' => 'Ontwerpen',
    'new_design' => 'Nieuw ontwerp',
    'edit_design' => 'Ontwerp aanpassen',
    'created_design' => 'Ontwerp aangemaakt',
    'updated_design' => 'Ontwerp bijgewerkt',
    'archived_design' => 'Ontwerp gearchiveerd',
    'deleted_design' => 'Ontwerp verwijderd',
    'removed_design' => 'Ontwerp verwijderd',
    'restored_design' => 'Ontwerp teruggehaald',
    'recurring_tasks' => 'Terugkerende Taken',
    'removed_credit' => 'Krediet is verwijders',
    'latest_version' => 'Laatste versie',
    'update_now' => 'Nu updaten',
    'a_new_version_is_available' => 'Een nieuwe versie van de web applicatie is beschikbaar',
    'update_available' => 'Update beschikbaar',
    'app_updated' => 'Update met succes voltooid',
    'integrations' => 'Integraties',
    'tracking_id' => 'Tracering Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Gedeeltelijke betaling',
    'partial_payment_email' => 'E-mail voor gedeeltelijke betaling',
    'clone_to_credit' => 'Klonen naar krediet',
    'emailed_credit' => 'Krediet is verzonden',
    'marked_credit_as_sent' => 'Krediet is gemarkeerd als verzonden',
    'email_subject_payment_partial' => 'E-mail gedeeltelijke betalingsonderwerp',
    'is_approved' => 'Is goedgekeurd',
    'migration_went_wrong' => 'Oeps, er is iets misgegaan! Zorg dat je een Invoice Ninja V5 instance hebt opgezet voordat je met de migratie begint.',
    'cross_migration_message' => 'Migratie tussen accounts is niet toegestaan. Lees er hier meer over: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'E-mail Krediet',
    'client_email_not_set' => 'Er is geen e-mailadres ingesteld voor de klant',
    'ledger' => 'Grootboek',
    'view_pdf' => 'Bekijk PDF',
    'all_records' => 'Alle gegevens',
    'owned_by_user' => 'Owned door gebruiker',
    'credit_remaining' => 'Resterend krediet',
    'use_default' => 'Gebruik standaard',
    'reminder_endless' => 'Eindeloze herinneringen',
    'number_of_days' => 'Aantal dagen',
    'configure_payment_terms' => 'Betalingsvoorwaarden configureren',
    'payment_term' => 'Betalingstermijn',
    'new_payment_term' => 'Nieuwe betalingstermijn',
    'deleted_payment_term' => 'betalingstermijn met succes verwijderd',
    'removed_payment_term' => 'betalingstermijn met succes verwijderd',
    'restored_payment_term' => 'betalingstermijn met succes hersteld',
    'full_width_editor' => 'Volledige breedte-editor',
    'full_height_filter' => 'Volledige Hoogte Filter',
    'email_sign_in' => 'Log in met e-mail',
    'change' => 'Aanpassen',
    'change_to_mobile_layout' => 'Verander naar de mobiele layout?',
    'change_to_desktop_layout' => 'Verander naar de bureaublad layout?',
    'send_from_gmail' => 'Verzonden vanaf Gmail',
    'reversed' => 'Teruggedraaid',
    'cancelled' => 'Geannuleerd',
    'quote_amount' => 'Offertebedrag',
    'hosted' => 'Gehost',
    'selfhosted' => 'Zelf-Gehost',
    'hide_menu' => 'Verberg menu',
    'show_menu' => 'Toon Menu',
    'partially_refunded' => 'Gedeeltelijk terugbetaald',
    'search_documents' => 'Documenten zoeken',
    'search_designs' => 'Ontwerpen zoeken',
    'search_invoices' => 'Facturen zoeken',
    'search_clients' => 'Klanten zoeken',
    'search_products' => 'Producten zoeken',
    'search_quotes' => 'Offertes zoeken',
    'search_credits' => 'Zoek Krediet',
    'search_vendors' => 'Zoek Leveranciers',
    'search_users' => 'Zoek Gebruikers',
    'search_tax_rates' => 'Zoek Belastingstarieven',
    'search_tasks' => 'Zoek Taken',
    'search_settings' => 'Zoek Instellingen',
    'search_projects' => 'Zoek Projecten',
    'search_expenses' => 'Zoek Uitgaven',
    'search_payments' => 'Zoek Betalingen',
    'search_groups' => 'Zoek Groepen',
    'search_company' => 'Zoek Bedrijf',
    'cancelled_invoice' => 'Factuur succesvol geannuleerd',
    'cancelled_invoices' => 'Facturen succesvol geannuleerd',
    'reversed_invoice' => 'Factuur succesvol teruggedraaid',
    'reversed_invoices' => 'Facturen succesvol teruggedraaid',
    'reverse' => 'Terugdraaien',
    'filtered_by_project' => 'Gefilterd op project',
    'google_sign_in' => 'Log in met Google',
    'activity_58' => ':gebruiker teruggedraaide factuur :factuur',
    'activity_59' => ':gebruiker geannuleerde factuur :factuur',
    'payment_reconciliation_failure' => 'Koppelen mislukt',
    'payment_reconciliation_success' => 'Koppelen gelukt',
    'gateway_success' => 'Gateway geslaagd',
    'gateway_failure' => 'Gateway gefaald',
    'gateway_error' => 'Gateway fout',
    'email_send' => 'E-mail verzonden',
    'email_retry_queue' => 'E-mail wachtrij voor opnieuw versturen',
    'failure' => 'Fout',
    'quota_exceeded' => 'Limiet bereikt',
    'upstream_failure' => 'Upload mislukt',
    'system_logs' => 'Systeem log',
    'copy_link' => 'Link kopiëren',
    'welcome_to_invoice_ninja' => 'Welkom bij Invoice Ninja',
    'optin' => 'Inschrijven',
    'optout' => 'Uitschrijven',
    'auto_convert' => 'Automatisch omzetten',
    'reminder1_sent' => '1ste herinnering verstuurd',
    'reminder2_sent' => '2de herinnering verstuurd',
    'reminder3_sent' => '3de herinnering verstuurd',
    'reminder_last_sent' => 'Laatste herinnering verstuurd',
    'pdf_page_info' => 'Pagina :current van :total',
    'emailed_credits' => 'Krediet is succesvol gemaild',
    'view_in_stripe' => 'Bekijk in Stripe',
    'rows_per_page' => 'Regels per pagina',
    'apply_payment' => 'Betaling toepassen',
    'unapplied' => 'Niet toegepast',
    'custom_labels' => 'Aangepaste labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record naam',
    'file_type' => 'Bestandstype',
    'height' => 'Hoogte',
    'width' => 'Breedte',
    'health_check' => 'Health Check',
    'last_login_at' => 'Voor het laatst ingelogd',
    'company_key' => 'Bedrijfssleutel',
    'storefront' => 'Storefront',
    'storefront_help' => 'Activeer third-party applicaties om facturen te maken',
    'count_records_selected' => ':count records geselecteerd',
    'count_record_selected' => ':count record geselecteerd',
    'client_created' => 'Klant aangemaakt',
    'online_payment_email' => 'Online betalingsmail',
    'manual_payment_email' => 'Handmatige betalingsmail',
    'completed' => 'Voltooid',
    'gross' => 'Bruto',
    'net_amount' => 'Netto bedrag',
    'net_balance' => 'Netto balans',
    'client_settings' => 'Klantinstellingen',
    'selected_invoices' => 'Geselecteerde facturen',
    'selected_payments' => 'Geselecteerde betalingen',
    'selected_quotes' => 'Geselecteerde offertes',
    'selected_tasks' => 'Geselecteerde taken',
    'selected_expenses' => 'Geselecteerde uitgaves',
    'past_due_invoices' => 'Verlopen facturen',
    'create_payment' => 'Creëer betaling',
    'update_quote' => 'Offerte bijwerken',
    'update_invoice' => 'Factuur bijwerken',
    'update_client' => 'Klant bijwerken',
    'update_vendor' => 'Leverancier bijwerken',
    'create_expense' => 'Creëer uitgave',
    'update_expense' => 'Uitgave bijwerken',
    'update_task' => 'Taak bijwerken',
    'approve_quote' => 'Offerte goedkeuren',
    'when_paid' => 'Wanneer betaald',
    'expires_on' => 'Verloopt op',
    'show_sidebar' => 'Laat zijbalk zien',
    'hide_sidebar' => 'Verberg zijbalk',
    'event_type' => 'Event Type',
    'copy' => 'Kopieer',
    'must_be_online' => 'Herstart alsjeblieft de applicatie wanneer er verbinding is met het internet',
    'crons_not_enabled' => 'De crons moeten geactiveerd worden',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Zoek :count webhooks',
    'search_webhook' => 'Zoek 1 webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'Nieuwe webhook',
    'edit_webhook' => 'Webhook bijwerken',
    'created_webhook' => 'Webhook succesvol aangemaakt',
    'updated_webhook' => 'Webhook succesvol bijgewerkt',
    'archived_webhook' => 'Webhook succesvol gearchiveerd',
    'deleted_webhook' => 'Webhook succesvol verwijderd',
    'removed_webhook' => 'Webhook succesvol verwijderd',
    'restored_webhook' => 'Webhook succesvol hersteld',
    'search_tokens' => 'Zoek :count tokens',
    'search_token' => 'Zoek 1 token',
    'new_token' => 'Nieuwe token',
    'removed_token' => 'Token succesvol verwijderd',
    'restored_token' => 'Token succesvol hersteld',
    'client_registration' => 'Klant registratie',
    'client_registration_help' => 'Zelfregistratie voor klanten in het portaal toestaan',
    'customize_and_preview' => 'Pas aan & Weergeven',
    'search_document' => 'Zoek 1 document',
    'search_design' => 'Zoek 1 ontwerp',
    'search_invoice' => 'Zoek 1 factuur',
    'search_client' => 'Zoek 1 klant',
    'search_product' => 'Zoek 1 product',
    'search_quote' => 'Zoek 1 offerte',
    'search_credit' => 'Zoek 1 krediet',
    'search_vendor' => 'Zoek 1 leverancier',
    'search_user' => 'Zoek 1 gebruiker',
    'search_tax_rate' => 'Zoek 1 BTW-tarief',
    'search_task' => 'Zoek 1 taak',
    'search_project' => 'Zoek 1 project',
    'search_expense' => 'Zoek 1 uitgave',
    'search_payment' => 'Zoek 1 betaling',
    'search_group' => 'Zoek 1 groep',
    'created_on' => 'Aangemaakt op',
    'payment_status_-1' => 'Niet toegepast',
    'lock_invoices' => 'Vergrendel facturen',
    'show_table' => 'Weergeef als tabel',
    'show_list' => 'Weergeef als lijst',
    'view_changes' => 'Bekijk wijzigingen',
    'force_update' => 'Forceer een update',
    'force_update_help' => 'De applicatie draait op de laatste versie, maar wellicht zijn er nog een aantal fixes beschikbaar.',
    'mark_paid_help' => 'Volg de uitgave dat betaald is',
    'mark_invoiceable_help' => 'Sta toe dat de uitgave gefactureerd kan worden',
    'add_documents_to_invoice_help' => 'Laat de documenten zien',
    'convert_currency_help' => 'Stel een ruilwaarde in van de valuta',
    'expense_settings' => 'Uitgave instellingen',
    'clone_to_recurring' => 'Maak een kopie voor herhaling',
    'crypto' => 'Crypto',
    'user_field' => 'Gebruiker Veld',
    'variables' => 'Variabelen',
    'show_password' => 'Wachtwoord weergeven',
    'hide_password' => 'Wachtwoord verbergen',
    'copy_error' => 'Fout kopiëren',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Automatisch betalen ingeschakeld',
    'total_taxes' => 'Totale belasting',
    'line_taxes' => 'Regelitem belastingen',
    'total_fields' => 'Totaal velden',
    'stopped_recurring_invoice' => 'Herhalend factuur succesvol stopgezet',
    'started_recurring_invoice' => 'Herhalend factuur succesvol gestart',
    'resumed_recurring_invoice' => 'Herhalend factuur succesvol hervat',
    'gateway_refund' => 'Gateway terugbetaling',
    'gateway_refund_help' => 'Verwerk een terugbetaling via de betalingsgateway',
    'due_date_days' => 'Verloopdatum',
    'paused' => 'Gepauzeerd',
    'day_count' => 'Dag :count',
    'first_day_of_the_month' => 'Eerste dag van de maand',
    'last_day_of_the_month' => 'Laatste dag van de maand',
    'use_payment_terms' => 'Gebruik betalingseisen',
    'endless' => 'Eindeloos',
    'next_send_date' => 'Volgende verzenddatum',
    'remaining_cycles' => 'Resterende keren',
    'created_recurring_invoice' => 'Herhalend factuur succesvol aangemaakt',
    'updated_recurring_invoice' => 'Herhalend factuur succesvol bijgewerkt',
    'removed_recurring_invoice' => 'Herhalend factuur succesvol verwijderd',
    'search_recurring_invoice' => 'Zoek 1 herhalend factuur',
    'search_recurring_invoices' => 'Zoek :count herhalende facturen',
    'send_date' => 'Verzenddatum',
    'auto_bill_on' => 'Automatische betaling aan',
    'minimum_under_payment_amount' => 'Minimum onder het te betalen bedrag',
    'allow_over_payment' => 'Toestaan te betalen boven het te betalen bedrag',
    'allow_over_payment_help' => 'Draag bij aan extra betalen om fooi te accepteren',
    'allow_under_payment' => 'Toestaan te betalen onder het te betalen bedrag',
    'allow_under_payment_help' => 'Ondersteun het betalen van een minimaal gedeeltelijk / aanbetalingsbedrag',
    'test_mode' => 'Test modus',
    'calculated_rate' => 'Berekend tarief',
    'default_task_rate' => 'Standaard taak tarief',
    'clear_cache' => 'Maak cache leeg',
    'sort_order' => 'Sorteer volgorde',
    'task_status' => 'Status',
    'task_statuses' => 'Taak status',
    'new_task_status' => 'Nieuwe taak status',
    'edit_task_status' => 'Taak status aanpassen',
    'created_task_status' => 'Succesvol een taak status aangemaakt',
    'archived_task_status' => 'Succesvol een taak status gearchiveerd',
    'deleted_task_status' => 'Succesvol een taak status verwijderd',
    'removed_task_status' => 'Succesvol een taak status verwijderd',
    'restored_task_status' => 'Succesvol een taak status hersteld',
    'search_task_status' => 'Zoek 1 taak status',
    'search_task_statuses' => 'Zoek :count taak statussen',
    'show_tasks_table' => 'Taken tabel tonen',
    'show_tasks_table_help' => 'Weergeef de taken wanneer een factuur wordt aangemaakt',
    'invoice_task_timelog' => 'Factuur taak tijdlog',
    'invoice_task_timelog_help' => 'Voeg de tijd omschrijvingen toe aan de factuur producten',
    'auto_start_tasks_help' => 'Start taken voordat het wordt opgeslagen',
    'configure_statuses' => 'Status instellen',
    'task_settings' => 'Taak instellingen',
    'configure_categories' => 'Categorieën instellen',
    'edit_expense_category' => 'Bewerk uitgavencategorie',
    'removed_expense_category' => 'De uitgavencategorie is verwijderd',
    'search_expense_category' => 'Zoek 1 uitgavencategorie',
    'search_expense_categories' => 'Zoek :count uitgave categorieën',
    'use_available_credits' => 'Gebruik beschikbaar krediet',
    'show_option' => 'Toon optie',
    'negative_payment_error' => 'Het kredietbedrag mag niet hoger zijn als het te betalen bedrag',
    'should_be_invoiced_help' => 'Maak het mogelijk de uitgave te factureren',
    'configure_gateways' => 'Configureer Gateways',
    'payment_partial' => 'Gedeeltelijke betaling',
    'is_running' => 'Word uitgevoerd',
    'invoice_currency_id' => 'Factuur valuta ID',
    'tax_name1' => 'BTW naam 1',
    'tax_name2' => 'BTW naam 2',
    'transaction_id' => 'Transactie ID',
    'invoice_late' => 'Factuur te laat',
    'quote_expired' => 'Offerte verlopen',
    'recurring_invoice_total' => 'Factuur totaal',
    'actions' => 'Acties',
    'expense_number' => 'Uitgave nummer',
    'task_number' => 'Taaknummer',
    'project_number' => 'Projectnummer',
    'view_settings' => 'Instellingen tonen',
    'company_disabled_warning' => 'Waarschuwing: dit bedrijf is nog niet geactiveerd',
    'late_invoice' => 'Late factuur',
    'expired_quote' => 'Verlopen offerte',
    'remind_invoice' => 'Herinnering Factuur',
    'client_phone' => 'Klant telefoon',
    'required_fields' => 'Verreisde velden',
    'enabled_modules' => 'Ingeschakelde modules',
    'activity_60' => ':contact heeft de offerte :quote bekeken',
    'activity_61' => ':user heeft de klant :client aangepast',
    'activity_62' => ':user heeft de leverancier :vendor gewijzigd',
    'activity_63' => ':user heeft de eerste herinnering voor factuur :invoice naar :contact verzonden',
    'activity_64' => ':user heeft de tweede herinnering voor factuur :invoice naar :contact verzonden',
    'activity_65' => ':user heeft de derde herinnering voor factuur :invoice naar :contact verzonden',
    'activity_66' => ':user heeft eindeloze herinneringen voor factuur :invoice naar :contact verzonden',
    'expense_category_id' => 'Uitgave categorie ID',
    'view_licenses' => 'Bekijk Licenties',
    'fullscreen_editor' => 'Editor volledig scherm',
    'sidebar_editor' => 'Zijbalk Editor',
    'please_type_to_confirm' => 'Typ ":value" om te bevestigen',
    'purge' => 'Wissen',
    'clone_to' => 'Dupliceer naar',
    'clone_to_other' => 'Dupliceert naar andere',
    'labels' => 'Labels',
    'add_custom' => 'Aangepast toevoegen',
    'payment_tax' => 'Betalingsbelasting',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Verzonden facturen zijn vergrendeld',
    'paid_invoices_are_locked' => 'Betaalde facturen zijn vergrendeld',
    'source_code' => 'Broncode',
    'app_platforms' => 'App-platforms',
    'archived_task_statuses' => 'Succesvol taakstatussen :value gearchiveerd',
    'deleted_task_statuses' => 'Succesvol taak statussen :value verwijderd',
    'restored_task_statuses' => 'Succesvol taak statussen :value hersteld',
    'deleted_expense_categories' => 'Succesvol uitgave categorieën :value verwijderd',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => ':value aan krediet succesvol hersteld',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Succesvol begonnen met importeren',
    'duplicate_column_mapping' => 'Dubbele kolommapping',
    'uses_inclusive_taxes' => 'Gebruik inclusieve belastingen',
    'is_amount_discount' => 'Is bedrag korting',
    'map_to' => 'Map naar',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'Geen bestand geselecteerd',
    'import_type' => 'Importeer type',
    'draft_mode' => 'Concept modus',
    'draft_mode_help' => 'Toon aanpassingen sneller maar minder nauwkeurig',
    'show_product_discount' => 'Toon product korting',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'BTW naam 3',
    'debug_mode_is_enabled' => 'Foutopsporingsmodus is ingeschakeld',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recente taken',
    'recent_expenses' => 'Recente uitgaven',
    'upcoming_expenses' => 'Aankomende uitgaven',
    'search_payment_term' => 'Zoek betalingstermijn 1',
    'search_payment_terms' => 'Zoek :count betalingstermijnen',
    'save_and_preview' => 'Opslaan en bekijk voorbeeld',
    'save_and_email' => 'Opslaan en verstuur email',
    'converted_balance' => 'Omgekeerd balans',
    'is_sent' => 'Is verzonden',
    'document_upload' => 'Document uploaden',
    'document_upload_help' => 'Laat klanten documenten uploaden',
    'expense_total' => 'Totale uitgave',
    'enter_taxes' => 'Voer belastingen in',
    'by_rate' => 'Op tarief',
    'by_amount' => 'Op bedrag',
    'enter_amount' => 'Voer bedrag in',
    'before_taxes' => 'Voor BTW',
    'after_taxes' => 'Na BTW',
    'color' => 'Kleur',
    'show' => 'Tonen',
    'empty_columns' => 'Lege kolommen',
    'project_name' => 'Project naam',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'Dit kwartaal',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registratie link',
    'show_product_cost' => 'Laat product kosten zien',
    'complete' => 'Voltooien',
     'next' => 'Volgende',
     'next_step' => 'Volgende stap',
     'notification_credit_sent_subject' => 'Krediet :invoice is verzonden naar :client',
     'notification_credit_viewed_subject' => 'Krediet :invoice is bekeken door :client',
     'notification_credit_sent' => 'De volgende klant :client heeft een email ontvangen voor een krediet :invoice van :amount',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Voer uw e-mailadres in om uw wachtwoord opnieuw in te stellen.',
     'password_reset' => 'Wachtwoord opnieuw instellen',
     'account_login_text' => 'Welkom terug! Blij je te zien.',
     'request_cancellation' => 'Annulering aanvragen',
     'delete_payment_method' => 'Verwijder betalingsmethode',
     'about_to_delete_payment_method' => 'U staat op het punt om de betalingsmethode te verwijderen.',
     'action_cant_be_reversed' => 'Actie kan niet terug gedraaid worden',
     'profile_updated_successfully' => 'Het profiel is succesvol bijgewerkt.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Factuur status',
     'email_already_register' => 'Dit emailadres is al aan een account gelinkt',
     'locations' => 'Locaties',
     'freq_indefinitely' => 'Oneindig',
     'cycles_remaining' => 'RESTERENDE CYCLI',
     'i_understand_delete' => 'Ik begrijp het, verwijder',
     'download_files' => 'Download bestanden',
     'download_timeframe' => 'Gebruik deze link om uw bestanden te downloaden, de link vervalt over 1 uur.',
     'new_signup' => 'Nieuwe aanmelding',
     'new_signup_text' => 'Een nieuw account is aangemaakt door :user - :email vanaf IP-adres :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Factuur # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Toon logboek',
     'send_fail_logs_to_our_server' => 'Rapporteer fouten in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update jouw persoonlijke informatie',
     'name_website_logo' => 'Naam, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Persoonlijk adres',
     'enter_your_personal_address' => 'Voer uw persoonlijk adres in',
     'enter_your_shipping_address' => 'Voer uw verzendadres in',
     'list_of_invoices' => 'Lijst van facturen',
     'with_selected' => 'Met geselecteerde',
     'invoice_still_unpaid' => 'Deze factuur is nog niet betaald. Klik op de knop om de betaling te vervolledigen',
     'list_of_recurring_invoices' => 'Lijst van terugkerende facturen',
     'details_of_recurring_invoice' => 'Hier zijn een paar details over terugkerende facturen',
     'cancellation' => 'Annulering',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'Lijst met betalingen',
     'payment_details' => 'Details van de betaling',
     'list_of_payment_invoices' => 'Lijst met facturen waarop de betaling betrekking heeft',
     'list_of_payment_methods' => 'Lijst met betalingsmethodes',
     'payment_method_details' => 'Details van betalingsmethodes',
     'permanently_remove_payment_method' => 'Verwijder deze betalingsmethode definitief',
     'warning_action_cannot_be_reversed' => 'Waarschuwing! Deze aanpassing kan niet terug worden gedraaid!',
     'confirmation' => 'Bevestiging',
     'list_of_quotes' => 'Offertes',
     'waiting_for_approval' => 'Wachten op goedkeuren',
     'quote_still_not_approved' => 'Deze offerte is nog steeds niet goedgekeurd',
     'list_of_credits' => 'Kredieten',
     'required_extensions' => 'Vereiste extensies',
     'php_version' => 'PHP versie',
     'writable_env_file' => 'Aanpasbaar .env bestand',
     'env_not_writable' => '.env bestand kan niet aangepast worden door de huidige gebruiker.',
     'minumum_php_version' => 'Minimale PHP versie',
     'satisfy_requirements' => 'Zorg ervoor dat aan alle vereisten is voldaan.',
     'oops_issues' => 'Oeps, er klopt iets niet!',
     'open_in_new_tab' => 'Open in nieuw tabblad',
     'complete_your_payment' => 'Voltooi betaling',
     'authorize_for_future_use' => 'Autoriseer de betalingsmethode voor toekomstig gebruik',
     'page' => 'Pagina',
     'per_page' => 'Per pagina',
     'of' => 'Of',
     'view_credit' => 'Toon krediet',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'Geen resultaten gevonden.',
     'payment_failed_subject' => 'Betaling mislukt voor klant :klant',
     'payment_failed_body' => 'Een betaling gedaan door de klant :client is mislukt met bericht :bericht',
     'register' => 'Registreer',
     'register_label' => 'Maak binnen enkele seconden uw account aan',
     'password_confirmation' => 'Bevestig uw wachtwoord',
     'verification' => 'Verificatie',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Opgegeven maand is niet geldig.',
     'year_invalid' => 'Opgegeven jaar is niet geldig.',
     'https_required' => 'HTTP is vereist, anders zal het formulier mislukken',
     'if_you_need_help' => 'Als u hulp nodig heeft, kunt u een bericht sturen naar onze',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Bron',
     'document_details' => 'Details van het document',
     'hash' => 'Hash',
     'resources' => 'Bronnen',
     'allowed_file_types' => 'Toegestane bestandstypen:',
     'common_codes' => 'Gemeenschappelijke codes en hun betekenis',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download geselecteerde',
     'to_pay_invoices' => 'Om facturen te betalen moet u',
     'add_payment_method_first' => 'Voeg betalingsmethode toe',
     'no_items_selected' => 'Geen artikelen geselecteerd.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Accountsaldo',
     'thanks' => 'Dank u wel',
     'minimum_required_payment' => 'Minimaal vereiste betaling is :amount',
     'under_payments_disabled' => 'Bedrijf ondersteunt geen onderbetalingen.',
     'over_payments_disabled' => 'Bedrijf ondersteunt geen over betalingen.',
     'saved_at' => 'Opgeslagen op :time',
     'credit_payment' => 'Krediet toegepast op factuur :invoice_number',
     'credit_subject' => 'Nieuw krediet :nnumber van :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptogeld',
     'payment_type_Credit' => 'Krediet',
     'store_for_future_use' => 'Bewaar voor toekomstig gebruik',
     'pay_with_credit' => 'Betaal met krediet',
     'payment_method_saving_failed' => 'Betalingsmethode kan niet opgeslagen worden voor toekomstig gebruik.',
     'pay_with' => 'Betaal met',
     'n/a' => 'Nvt',
     'by_clicking_next_you_accept_terms' => 'Door op "Volgende stap" te klikken, accepteert u de voorwaarden.',
     'not_specified' => 'Niet gespecificeerd',
     'before_proceeding_with_payment_warning' => 'Voordat u doorgaat met betalen, moet u de volgende velden invullen',
     'after_completing_go_back_to_previous_page' => 'Ga na voltooiing terug naar de vorige pagina.',
     'pay' => 'Betaal',
     'instructions' => 'Instructies',
     'notification_invoice_reminder1_sent_subject' => 'Herinnering 1 voor factuur :factuur is verzonden naar :klant',
     'notification_invoice_reminder2_sent_subject' => 'Herinnering 2 voor factuur :factuur is verzonden naar :klant',
     'notification_invoice_reminder3_sent_subject' => 'Herinnering 3 voor factuur :factuur is verzonden naar :klant',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Toegewezen gebruiker',
     'setup_steps_notice' => 'Zorg ervoor dat u elke sectie test om door te gaan naar de volgende stap.',
     'setup_phantomjs_note' => 'Opmerking over Phantom JS. Lees verder.',
     'minimum_payment' => 'Minimum betaling',
     'no_action_provided' => 'Geen actie voorzien. Als u denkt dat dit niet klopt, neem dan contact op met uw support.',
     'no_payable_invoices_selected' => 'Geen te betalen facturen geselecteerd. Zorg ervoor dat u niet probeert om een conceptfactuur of factuur met geen openstaande betaling te betalen.',
     'required_payment_information' => 'Vereiste betalingsgegevens',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Kan krediet :factuur niet verzenden',
     'save_payment_method_details' => 'Bewaar betaalmethode',
     'new_card' => 'Nieuwe betaalkaart',
     'new_bank_account' => 'Nieuwe bankrekening',
     'company_limit_reached' => 'Limiet van maximaal 10 bedrijven per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Kredietnummer is al in gebruik',
     'credit_not_found' => 'Krediet niet gevonden',
     'invoices_dont_match_client' => 'Geselecteerde facturen zijn niet van één enkele klant',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Factuur-ID :number kan niet worden terugbetaald',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'Deze gebruiker kan niet aan dit bedrijf worden gekoppeld. Misschien hebben ze al een gebruiker geregistreerd op een ander account?',
     'migration_completed' => 'Migratie is voltooid',
     'migration_completed_description' => 'Uw migratie is voltooid. Controleer uw gegevens nadat u zich heeft aangemeld.',
     'api_404' => '404 | Hier valt niets te zien!',
     'large_account_update_parameter' => 'Kan geen groot account laden zonder een bijgewerkt_op parameter',
     'no_backup_exists' => 'Er bestaat geen back-up voor deze activiteit',
     'company_user_not_found' => 'Bedrijfsgebruikersrecord niet gevonden',
     'no_credits_found' => 'Geen krediet gevonden.',
     'action_unavailable' => 'De opgevraagde actie :action is niet beschikbaar.',
     'no_documents_found' => 'Geen documenten gevonden',
     'no_group_settings_found' => 'Geen groep instellingen gevonden',
     'access_denied' => 'Onvoldoende rechten om deze bron te openen / wijzigen',
     'invoice_cannot_be_marked_paid' => 'Factuur kan niet als betaald worden gemarkeerd',
     'invoice_license_or_environment' => 'Ongeldige licentie of ongeldige omgeving :omgeving',
     'route_not_available' => 'Route niet beschikbaar',
     'invalid_design_object' => 'Ongeldig aangepast ontwerpobject',
     'quote_not_found' => 'Offerte/s niet gevonden',
     'quote_unapprovable' => 'Deze offerte kan niet worden goedgekeurd omdat deze is verlopen.',
     'scheduler_has_run' => 'Planner is uitgevoerd',
     'scheduler_has_never_run' => 'Planner is nog nooit uitgevoerd',
     'self_update_not_available' => 'Zelfupdate is niet beschikbaar op dit systeem.',
     'user_detached' => 'Gebruiker losgekoppeld van bedrijf',
     'create_webhook_failure' => 'Maken van webhook is mislukt',
     'payment_message_extended' => 'Bedankt voor uw betaling van :amount voor :invoice',
     'online_payments_minimum_note' => 'Opmerking: Online betalingen worden alleen ondersteund als het bedrag groter is dan € 1 of het equivalent in een andere valuta.',
     'payment_token_not_found' => 'Betalingstoken niet gevonden. Probeer het opnieuw. Als het probleem zich blijft voordoen, probeer het dan met een andere betaalmethode',
     'vendor_address1' => 'Leverancier straatnaam',
     'vendor_address2' => 'Leverancier Apt / Suite',
     'partially_unapplied' => 'Gedeeltelijk niet toegepast',
     'select_a_gmail_user' => 'Selecteer een gebruiker die is geverifieerd met Gmail',
     'list_long_press' => 'Lijst lang indrukken',
     'show_actions' => 'Toon acties',
     'start_multiselect' => 'Start Multi select',
     'email_sent_to_confirm_email' => 'Er is een e-mail verzonden om het e-mailadres te bevestigen',
     'converted_paid_to_date' => '"Reeds betaald" omzetten',
     'converted_credit_balance' => 'Omgerekend creditsaldo',
     'converted_total' => 'Totaal omzetten',
     'reply_to_name' => 'Antwoordnaam',
     'payment_status_-2' => 'Gedeeltelijk niet toegepast',
     'color_theme' => 'Kleuren thema',
     'start_migration' => 'Start migratie',
     'recurring_cancellation_request' => 'Verzoek om periodieke annulering van facturen van :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hallo',
     'group_documents' => 'Groepeer documenten',
     'quote_approval_confirmation_label' => 'Weet u zeker dat u deze offerte wilt goedkeuren?',
     'migration_select_company_label' => 'Selecteer bedrijven om te migreren',
     'force_migration' => 'Forceer migratie',
     'require_password_with_social_login' => 'Vereis wachtwoord met sociale login',
     'stay_logged_in' => 'Blijf ingelogd',
     'session_about_to_expire' => 'Waarschuwing: uw sessie loopt bijna af',
     'count_hours' => ':count uren',
     'count_day' => '1 dag',
     'count_days' => ':count dagen',
     'web_session_timeout' => 'Time-out van websessie',
     'security_settings' => 'Veiligheidsinstellingen',
     'resend_email' => 'Email opnieuw verzenden',
     'confirm_your_email_address' => 'Bevestig je e-mailadres',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave boekhouding',
     'zoho' => 'Zoho',
     'accounting' => 'Boekhouding',
     'required_files_missing' => 'Geef alle CSV\'s op.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Gebruik laatste e-mail',
     'activate_company' => 'Activeer bedrijf',
     'activate_company_help' => 'Schakel e-mails, terugkerende facturen en meldingen in',
     'an_error_occurred_try_again' => 'Er is een fout opgetreden, probeer het opnieuw',
     'please_first_set_a_password' => 'Stel eerst een wachtwoord in',
     'changing_phone_disables_two_factor' => 'Waarschuwing: als u uw telefoonnummer wijzigt, wordt 2FA uitgeschakeld',
     'help_translate' => 'Help vertalen',
     'please_select_a_country' => 'Selecteer een land',
     'disabled_two_factor' => '2FA succesvol uitgeschakeld',
     'connected_google' => 'Account succesvol verbonden',
     'disconnected_google' => 'Account succesvol losgekoppeld',
     'delivered' => 'Afgeleverd',
     'spam' => 'Spam',
     'view_docs' => 'Bekijk documenten',
     'enter_phone_to_enable_two_factor' => 'Geef een mobiel telefoonnummer op om tweefactor authenticatie in te schakelen',
     'send_sms' => 'Verzend SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Verbind met Google',
     'disconnect_google' => 'Verwijder Google',
     'disable_two_factor' => 'Schakel twee factor authenticatie uit',
     'invoice_task_datelog' => 'Factuur taak datumlog',
     'invoice_task_datelog_help' => 'Voeg datumdetails toe aan de factuurregelitems',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
